@@ -24,7 +24,6 @@
  */
 /* #define BIND     1 */
 /* #define BSD42    1 */
-/* #define SUN40    1 */
 
 /*
  *  Linux
@@ -125,12 +124,6 @@
  */
 #define MHRC    1
 
-/*
- * Use sendmail as transport agent.  Currently, this is
- * the only transport agent that nmh works correctly with.
- */
-#define SENDMTS 1
-
 /*
  * Compile in support for MIME.
  */
@@ -143,7 +136,7 @@
  * profile entry to override this.  Check mhn(1) man page for
  * details.
  */
-#define FTP     1
+#define BUILTIN_FTP 1
 
 /*
  * If you enable POP support, this is the the port name
@@ -155,7 +148,7 @@
 /*
  * Define the default creation modes for folders and messages.
  */
-#define DEFAULT_FOLDER_MODE "0711"
+#define DEFAULT_FOLDER_MODE "0700"
 #define DEFAULT_MESSAGE_MODE "0644"
 
 /*
@@ -182,9 +175,14 @@
  * the mail transport agent (typically sendmail), nmh will open a
  * socket connection to the mail port on the machine specified in
  * the `mts.conf' file (default is localhost), and speak SMTP directly.
- * This requires support for sockets, of course.
  */
-#undef SMTP
+#undef SMTPMTS
+
+/*
+ * Use sendmail as transport agent.  Post messages by piping
+ * them directly to sendmail.
+ */
+#undef SENDMTS
 
 /*
  * Define this to compile client-side support for pop into
