@@ -27,7 +27,7 @@ etcpath (char *file)
 #endif
 
 #ifdef MHRC
-    m_getdefs();
+    context_read();
 #endif
 
     switch (*file) {
@@ -81,24 +81,37 @@ struct swit anoyes[] = {
  * nmh constants
  */
 
-char *components = "components";
-char *current = "cur";
-char *defalt = "inbox";
-char *digestcomps = "digestcomps";
-char *distcomps = "distcomps";
-char *draft = "draft";
-char *forwcomps = "forwcomps";
-char *inbox = "inbox";
+/* initial profile for new users */
 char *mh_defaults = nmhetcdir (/mh.profile);
+
+/* default name of user profile */
 char *mh_profile = ".mh_profile";
+
+/* name of current message "sequence" */
+char *current = "cur";
+
+/* component files */
+char *components = "components";
+char *replcomps = "replcomps";
+char *forwcomps = "forwcomps";
+char *distcomps = "distcomps";
+char *rcvdistcomps = "rcvdistcomps";
+char *digestcomps = "digestcomps";
+
+/* format files */
 char *mhlformat = "mhl.format";
 char *mhlforward = "mhl.forward";
-char *nsequence = "Sequence-Negation";
+
+char *draft = "draft";
+
+char *inbox = "Inbox";
+char *defaultfolder = "inbox";
+
 char *pfolder = "Current-Folder";
-char *psequence = "Previous-Sequence";
-char *rcvdistcomps = "rcvdistcomps";
-char *replcomps = "replcomps";
 char *usequence = "Unseen-Sequence";
+char *psequence = "Previous-Sequence";
+char *nsequence = "Sequence-Negation";
+
 char *mhlibdir = NMHLIBDIR;
 char *mhetcdir = NMHETCDIR;
 
@@ -106,12 +119,20 @@ char *mhetcdir = NMHETCDIR;
  * nmh not-so constants
  */
 
+/*
+ * Default name for the nmh context file.
+ */
 char *context = "context";
 
-#ifndef	NOMHSEQ
-char *mh_seq = ".mh_sequences";
-#else
+/*
+ * Default name of file for public sequences.  If NULL,
+ * then nmh will use private sequences by default, unless the
+ * user defines a value using the "mh-sequences" profile entry.
+ */
+#ifdef NOPUBLICSEQ
 char *mh_seq = NULL;
+#else
+char *mh_seq = ".mh_sequences";
 #endif
 
 /* 
@@ -203,21 +224,17 @@ char *mshproc = nmhbindir (/msh);
 char *packproc = nmhbindir (/packf);
 
 /*
- * This is the delivery program called through send to
- * actually deliver mail to users.  This is the interface to
- * the MTS.
+ * This is the delivery program called by send to actually
+ * deliver mail to users.  This is the interface to the MTS.
  */
 
-#if BERK && SENDMTS && !SMTP
-char *postproc = nmhlibdir (/spost);
-#else
 char *postproc = nmhlibdir (/post);
-#endif /* BERK */
 
 /*
  * This is program is called by slocal to handle
  * the action `folder' or `+'.
  */
+
 char *rcvstoreproc = nmhlibdir (/rcvstore);
 
 /* 
@@ -255,14 +272,6 @@ char *showmimeproc = nmhbindir (/mhn);
 
 char *showproc = DEFAULT_PAGER;
 
-/* 
- * This program is called under stand-alone nmh to deliver a message to
- * a local user.  Under other MTS's it can be used to emulate a
- * MMDF-II .maildelivery mechanism.
- */
-
-char *slocalproc = nmhlibdir (/slocal);
-
 /* 
  * This program is called by vmh as the back-end to the window management
  * protocol
