@@ -35,44 +35,45 @@ int atooi(char *);
 char **brkstring (char *, char *, char *);
 void closefds(int);
 char *concat (char *, ...);
-char *copy(char *, char *);
+int context_del (char *);
+char *context_find (char *);
+int context_foil (char *);
+void context_read (void);
+void context_replace (char *, char *);
+void context_save (void);
+char *copy (char *, char *);
 char **copyip (char **, char **);
 void cpydata (int, int, char *, char *);
 void cpydgst (int, int, char *, char *);
 void discard (FILE *);
 void done (int);
 int fdcompare (int, int);
+int folder_addmsg (struct msgs **, char *, int, int, int);
 int folder_delmsgs (struct msgs *, int);
+void folder_free (struct msgs *);
+int folder_pack (struct msgs **, int);
+struct msgs *folder_read (char *);
+struct msgs *folder_realloc (struct msgs *, int, int);
 int gans (char *, struct swit *);
 char **getans (char *, struct swit *);
 int getanswer (char *);
 char *getcpy (char *);
+char *getfolder(int);
 int m_atoi (char *);
 char *m_backup (char *);
 int m_convert (struct msgs *, char *);
-int m_delete (char *);
 char *m_draft (char *, char *, int, int *);
 void m_eomsbr (int (*)());
-char *m_find(char *);
-void m_foil (char *);
-void m_freefolder (struct msgs *);
-void m_getdefs(void);
 int m_getfld (int, unsigned char *, unsigned char *, int, FILE *);
-char *m_getfolder(void);
 int m_gmprot (void);
 char *m_maildir (char *);
 char *m_mailpath (char *);
 char *m_name (int);
-struct msgs *m_packfolder (struct msgs *, int);
 int m_putenv (char *, char *);
 void m_readefs (struct node **, FILE *, char *, int);
-struct msgs *m_readfolder (char *);
-struct msgs *m_remsg ();
-void m_replace (char *, char *);
 char *m_scratch (char *, char *);
 char *m_tmpfil (char *);
 void m_unknown(FILE *);
-void m_update(void);
 int makedir (char *);
 char *new_fs (char *, char *, char *);
 char *path(char *, int);
@@ -102,7 +103,7 @@ void seq_setprev (struct msgs *);
 void seq_setunseen (struct msgs *, int);
 int showfile (char **, char *);
 int smatch(char *, struct swit *);
-char *sprintb (char *, unsigned, char *);
+char *snprintb (char *, size_t, unsigned, char *);
 int ssequal (char *, char *);
 int stringdex (char *, char *);
 char *trimcpy (char *);
@@ -116,8 +117,13 @@ int get_returnpath (char *, char *);
 #endif
 
 /*
- * prototypes for compat functions in library
+ * prototypes for compatibility functions in library
  */
+#ifndef HAVE_SNPRINTF
+int snprintf (char *, size_t, const char *, ...);
+int vsnprintf (char *, size_t, const char *, va_list);
+#endif
+
 #ifndef HAVE_STRERROR
 char *strerror (int);
 #endif
@@ -129,5 +135,4 @@ char *strerror (int);
  */
 char *LocalName(void);
 char *SystemName(void);
-char *UucpChan(void);
 char *OfficialName(char *);
