@@ -54,8 +54,12 @@ discard (FILE *io)
 #ifdef _FSTDIO
     fpurge (io);
 #else
+# ifdef LINUX_STDIO
+    io->_IO_write_ptr = io->_IO_write_base;
+# else
     if ((io->_ptr = io->_base))
 	io->_cnt = 0;
+# endif
 #endif
 }
 
