@@ -233,7 +233,7 @@ fmt_compile(char *fstring, struct format **fmt)
     for (i = 0; i < sizeof(wantcomp)/sizeof(wantcomp[0]); i++)
 	wantcomp[i] = 0;
 
-    memset((char *) &fmt_mnull, 0, sizeof fmt_mnull);
+    memset((char *) &fmt_mnull, 0, sizeof(fmt_mnull));
 
     /* it takes at least 4 char to generate one format so we
      * allocate a worst-case format array using 1/4 the length
@@ -392,7 +392,7 @@ do_name(char *sp, int preprocess)
 	}
 	if (! (cm->c_type & CT_DATE)) {
 	    cm->c_tws = (struct tws *)
-				calloc((size_t) 1, sizeof *cm->c_tws);
+				calloc((size_t) 1, sizeof(*cm->c_tws));
 	    fp->f_type = preprocess;
 	    PUTCOMP(sp);
 	    cm->c_type |= CT_DATE;
