@@ -7,6 +7,10 @@
 
 #include <h/mh.h>
 
+/*
+ * error codes for sequence
+ * and message range processing
+ */
 #define	BADMSG	(-2)
 #define	BADRNG	(-3)
 #define	BADNEW	(-4)
@@ -35,35 +39,42 @@ m_convert (struct msgs *mp, char *name)
     register char *bp, *cp;
     int found, range, err, flags;
 
-    switch (err = attr (mp, cp = name)) {
-	case NOTOK: 
-	    return 0;
+    /* check if user defined sequence */
+    err = attr (mp, cp = name);
 
-	case OK: 
-	    break;
-
-	default: 
-	    if (err < 0)
-		goto badmsg;
-	    return 1;
-    }
+    if (err == -1)
+	return 0;
+    else if (err < 0)
+	goto badmsg;
+    else if (err > 0)
+	return 1;
+    /*
+     * else err == 0, so continue
+     */
 
     found = 0;
-    flags = mp->msgflags & MHPATH ? EXISTS | SELECT_EMPTY : EXISTS;
+    if (mp->msgflags & MHPATH)
+	flags = EXISTS | SELECT_EMPTY;
+    else
+	flags = EXISTS;
 
-    if ((mp->msgflags & MHPATH) && strcmp (cp, "new") == 0)
+    if ((mp->msgflags & MHPATH) && !strcmp (cp, "new")) {
 	if ((err = first = getnew (mp)) <= 0)
 	    goto badmsg;
 	else
 	    goto single;
-    if (strcmp (cp, "all") == 0)
+    }
+
+    if (!strcmp (cp, "all"))
 	cp = "first-last";
+
     if ((err = first = m_conv (mp, cp, FIRST)) <= 0)
 	goto badmsg;
-    if (*(cp = delimp) && *cp != '-' && *cp != ':') {
+
+    cp = delimp;
+    if (*cp != '\0' && *cp != '-' && *cp != ':') {
 badelim: ;
-	advise (NULL, "illegal argument delimiter: `%c'(0%o)",
-		*delimp, *delimp);
+	advise (NULL, "illegal argument delimiter: `%c'(0%o)", *delimp, *delimp);
 	return 0;
     }
 
@@ -81,8 +92,7 @@ badmsg:;
 		    break;
 
 		case BADRNG: 
-		    advise (NULL, "message %s out of range 1-%d",
-			    cp, mp->hghmsg);
+		    advise (NULL, "message %s out of range 1-%d", cp, mp->hghmsg);
 		    break;
 
 		case BADLST: 
@@ -140,7 +150,7 @@ rangerr:;
 	    for (last = first;
 		    last >= mp->lowmsg && last <= mp->hghmsg;
 		    last += convdir)
-		if (mp->msgstats[last] & EXISTS)
+		if (does_exist (mp, last))
 		    if (--range <= 0)
 			break;
 	    if (last < mp->lowmsg)
@@ -153,16 +163,17 @@ rangerr:;
 		first = range;
 	    }
 	} else {
-	    if (!(mp->msgflags & MHPATH))
+	    if (!(mp->msgflags & MHPATH)) {
 		if (first > mp->hghmsg
 			|| first < mp->lowmsg
-			|| !(mp->msgstats[first] & EXISTS)) {
-		    if (strcmp (name, "cur") == 0 || strcmp (name, ".") == 0)
+			|| !(does_exist (mp, first))) {
+		    if (!strcmp (name, "cur") || !strcmp (name, "."))
 			advise (NULL, "no %s message", name);
 		    else
 			advise (NULL, "message %d doesn't exist", first);
 		    return 0;
 		}
+	    }
 single:;
 	    last = first;
 	    if (mp->msgflags & MHPATH)
@@ -188,6 +199,18 @@ single:;
     return 1;
 }
 
+/*
+ * Convert the various message names to
+ * there numeric value.
+ *
+ * n     (integer)
+ * prev
+ * next
+ * first
+ * last
+ * cur
+ * .     (same as cur)
+ */
 
 static int
 m_conv (struct msgs *mp, char *str, int call)
@@ -202,9 +225,16 @@ m_conv (struct msgs *mp, char *str, int call)
 	while (isdigit (*bp))
 	    bp++;
 	delimp = bp;
-	return ((i = atoi (cp)) <= mp->hghmsg ? i
-		: *delimp || call == LAST ? mp->hghmsg + 1
-		: mp->msgflags & MHPATH ? BADRNG : BADNUM);
+	i = atoi (cp);
+
+	if (i <= mp->hghmsg)
+	    return i;
+	else if (*delimp || call == LAST)
+	    return mp->hghmsg + 1;
+	else if (mp->msgflags & MHPATH)
+	    return BADRNG;
+	else
+	    return BADNUM;
     }
 
     bp = buf;
@@ -214,36 +244,35 @@ m_conv (struct msgs *mp, char *str, int call)
     while ((*cp >= 'a' && *cp <= 'z') || *cp == '.')
 #endif /* LOCALE */
 	*bp++ = *cp++;
-    *bp++ = 0;
+    *bp++ = '\0';
     delimp = cp;
 
-    if (strcmp (buf, "first") == 0)
+    if (!strcmp (buf, "first"))
 	return (mp->hghmsg || !(mp->msgflags & MHPATH)
 		? mp->lowmsg : BADMSG);
 
-    if (strcmp (buf, "last") == 0) {
+    if (!strcmp (buf, "last")) {
 	convdir = -1;
-	return (mp->hghmsg || !(mp->msgflags & MHPATH)
-		? mp->hghmsg : BADMSG);
+	return (mp->hghmsg || !(mp->msgflags & MHPATH) ? mp->hghmsg : BADMSG);
     }
 
-    if (strcmp (buf, "cur") == 0 || strcmp (buf, ".") == 0)
+    if (!strcmp (buf, "cur") || !strcmp (buf, "."))
 	return (mp->curmsg > 0 ? mp->curmsg : BADMSG);
 
-    if (strcmp (buf, "prev") == 0) {
+    if (!strcmp (buf, "prev")) {
 	convdir = -1;
 	for (i = (mp->curmsg <= mp->hghmsg) ? mp->curmsg - 1 : mp->hghmsg;
 		i >= mp->lowmsg; i--) {
-	    if (mp->msgstats[i] & EXISTS)
+	    if (does_exist (mp, i))
 		return i;
 	}
 	return BADMSG;
     }
 
-    if (strcmp (buf, "next") == 0) {
+    if (!strcmp (buf, "next")) {
 	for (i = (mp->curmsg >= mp->lowmsg) ? mp->curmsg + 1 : mp->lowmsg;
 		i <= mp->hghmsg; i++) {
-	    if (mp->msgstats[i] & EXISTS)
+	    if (does_exist (mp, i))
 		return i;
 	}
 	return BADMSG;
@@ -252,56 +281,85 @@ m_conv (struct msgs *mp, char *str, int call)
     return BADLST;
 }
 
+/*
+ * Handle user defined sequences.
+ * They can take the following forms:
+ *
+ * seq
+ * seq:prev
+ * seq:next
+ * seq:first
+ * seq:last
+ * seq:+n
+ * seq:-n
+ * seq:n
+ */
 
 static int
 attr (struct msgs *mp, char *cp)
 {
-    char *bp = NULL;
-    int found,
-        inverted,
-        range = 0,		/* no range */
-	first = 0;
-    register int i, j;
     register char *dp;
+    char *bp = NULL;
+    register int i, j;
+    int found,
+	inverted = 0,
+	range = 0,		/* no range */
+	first = 0;
 
-    if (strcmp (cp, "cur") == 0)/* hack for "cur-xyz", etc. */
-	return OK;
+    /* hack for "cur-name", "cur-n", etc. */
+    if (!strcmp (cp, "cur"))
+	return 0;
     if (ssequal ("cur:", cp))	/* this code need to be rewritten... */
-	return OK;
+	return 0;
 
-    dp = m_find (nsequence);
-    if ((inverted = (dp && *dp && ssequal (dp, cp))))
+    /* Check for sequence negation */
+    if ((dp = context_find (nsequence)) && *dp != '\0' && ssequal (dp, cp)) {
+	inverted = 1;
 	cp += strlen (dp);
+    }
+
+    convdir = 1;	/* convert direction */
 
-    convdir = 1;
     for (dp = cp; *dp && isalnum(*dp); dp++)
 	continue;
+
     if (*dp == ':') {
 	bp = dp++;
-
 	range = 1;
-	if (isalpha (*dp)) {	/* optimize? */
-	    if (strcmp (dp, "prev") == 0) {
+
+	/*
+	 * seq:prev  (or)
+	 * seq:next  (or)
+	 * seq:first (or)
+	 * seq:last
+	 */
+	if (isalpha (*dp)) {
+	    if (!strcmp (dp, "prev")) {
 		convdir = -1;
 		first = (mp->curmsg > 0) && (mp->curmsg <= mp->hghmsg)
 			? mp->curmsg - 1
 			: mp->hghmsg;
 	    }
-	    else if (strcmp (dp, "next") == 0) {
+	    else if (!strcmp (dp, "next")) {
 		convdir = 1;
 		first = (mp->curmsg >= mp->lowmsg)
 			    ? mp->curmsg + 1
 			    : mp->lowmsg;
 	    }
-	    else if (strcmp (dp, "first") == 0) {
+	    else if (!strcmp (dp, "first")) {
 		convdir = 1;
 	    }
-	    else if (strcmp (dp, "last") == 0) {
+	    else if (!strcmp (dp, "last")) {
 		convdir = -1;
 	    }
 	    else
 		return BADLST;
-	} else {			/* a numeric range */
+	} else {
+	    /*
+	     * seq:n  (or)
+	     * seq:+n (or)
+	     * seq:-n
+             */
 	    if (*dp == '+')
 		dp++;
 	    else if (*dp == '-') {
@@ -316,7 +374,7 @@ attr (struct msgs *mp, char *cp)
 		return BADLST;
 	}
 
-	*bp = '\0';		/* terminate sequence name */
+	*bp = '\0';	/* temporarily terminate sequence name */
     }
 
     i = seq_getnum (mp, cp);	/* get index of sequence */
@@ -324,12 +382,13 @@ attr (struct msgs *mp, char *cp)
     if (bp)
 	*bp = ':';		/* restore sequence name */
     if (i == -1)
-	return OK;
+	return 0;
+
+    found = 0;	/* count the number we select for this argument */
 
-    found = 0;
     for (j = first ? first : (convdir > 0) ? mp->lowmsg : mp->hghmsg;
 		j >= mp->lowmsg && j <= mp->hghmsg; j += convdir) {
-	if ((mp->msgstats[j] & EXISTS)
+	if (does_exist (mp, j)
 		&& inverted ? !in_sequence (mp, i, j) : in_sequence (mp, i, j)) {
 	    if (!is_selected (mp, j)) {
 		set_selected (mp, j);
@@ -340,15 +399,21 @@ attr (struct msgs *mp, char *cp)
 		    mp->hghsel = j;
 	    }
 	    found++;
+
+	    /*
+	     * If we have a range, then break out
+	     * once we've found enough.
+             */
 	    if (range && found >= range)
-		break;		/* we've done enough */
+		break;
 	}
     }
+
     if (found > 0)
 	return found;
 
     if (first)
 	return BADMSG;
     advise (NULL, "sequence %s %s", cp, inverted ? "full" : "empty");
-    return NOTOK;
+    return -1;
 }
