@@ -656,7 +656,8 @@ get_returnpath (char *rp, char *dd)
     char *ap, *bp, *cp, *dp;
 
     ap = unixbuf;
-    bp = cp = strchr(ap, ' ');
+    if (!(bp = cp = strchr(ap, ' ')))
+	return 0;
 
     /*
      * Check for "remote from" in envelope to see
