@@ -1,6 +1,6 @@
 
 /*
- * m_readefs.c -- read a nmh configuration files
+ * m_readefs.c -- read a nmh configuration file
  *             -- (profile/context/mhn.defaults)
  *
  * $Id$
@@ -33,7 +33,6 @@ static struct procstr procs[] = {
     { "sendproc",      &sendproc },
     { "showmimeproc",  &showmimeproc },
     { "showproc",      &showproc },
-    { "slocalproc",    &slocalproc },
     { "vmhproc",       &vmhproc },
     { "whatnowproc",   &whatnowproc },
     { "whomproc",      &whomproc },
@@ -76,9 +75,9 @@ m_readefs (struct node **npp, FILE *ib, char *file, int ctx)
 		    }
 		    np->n_field = trimcpy (cp);
 		    free (cp);
-		}
-		else
+		} else {
 		    np->n_field = trimcpy (field);
+		}
 		np->n_context = ctx;
 		for (ps = procs; ps->procname; ps++)
 		    if (strcmp (np->n_name, ps->procname) == 0) {
