@@ -24,7 +24,7 @@ makedir (char *dir)
     register char *c;
     char path[PATH_MAX];
 
-    m_update();		/* update the context file */
+    context_save();	/* save the context file */
     fflush(stdout);
 
     if (getuid () == geteuid ()) {
@@ -72,9 +72,8 @@ makedir (char *dir)
 	}
     }
 
-    if ((cp = m_find ("folder-protect")) == NULL)
+    if (!(cp = context_find ("folder-protect")))
 	cp = foldprot;
     chmod (dir, atooi (cp));
     return 1;
 }
-
