@@ -16,6 +16,6 @@ print_help (char *str, struct swit *swp)
     printf ("Usage: %s\n", str);
     printf ("  switches are:\n");
     print_sw (ALL, swp, "-");
-    if ((s = m_find(invo_name)))
+    if ((s = context_find (invo_name)))
 	printf ("\nProfile: %s\n", s);
 }
