@@ -1,6 +1,7 @@
 
 /*
- * seq_setunseen.c -- add/delete messages to/from Unseen-Sequence
+ * seq_setunseen.c -- add/delete all messages which have the UNSEEN
+ *                 -- bit set to/from the Unseen-Sequence
  *
  * $Id$
  */
@@ -26,7 +27,7 @@ seq_setunseen (struct msgs *mp, int seen)
      * Get the list of sequences for Unseen-Sequence
      * and split them.
      */
-    if ((cp = m_find (usequence)) == NULL
+    if ((cp = context_find (usequence)) == NULL
 	    || (ap = brkstring (dp = getcpy (cp), " ", "\n")) == NULL
 	    || *ap == NULL) {
 	if (dp)
