@@ -1,6 +1,6 @@
 
 /*
- * showfile.c -- invoke the lproc command
+ * showfile.c -- invoke the `lproc' command
  *
  * $Id$
  */
@@ -15,7 +15,7 @@ showfile (char **arg, char *file)
     int isdraft, vecp;
     char *vec[MAXARGS];
 
-    m_update();		/* update the context file */
+    context_save();	/* save the context file */
     fflush(stdout);
 
     /*
