@@ -63,7 +63,7 @@ main (int argc, char **argv)
 #endif
     invo_name = r1bindex (argv[0], '/');
     mts_init (invo_name);
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -125,7 +125,7 @@ main (int argc, char **argv)
 
     if (!noalias) {
 	/* allow Aliasfile: profile entry */
-	if ((cp = m_find ("Aliasfile"))) {
+	if ((cp = context_find ("Aliasfile"))) {
 	    char *dp = NULL;
 
 	    for (ap = brkstring(dp = getcpy(cp), " ", "\n"); ap && *ap; ap++)
