@@ -546,9 +546,7 @@ hmalloc (struct passwd *pw)
     p->h_gid = pw->pw_gid;
     p->h_home = getcpy (pw->pw_dir);
     p->h_shell = getcpy (pw->pw_shell);
-#ifdef BSD42
     p->h_ngrps = 0;
-#endif /* BSD42 */
     p->h_next = NULL;
     if (hometail != NULL)
 	hometail->h_next = p;
