@@ -36,7 +36,7 @@ static void make_comp (char **);
 int
 main (int argc, char **argv)
 {
-    int inplace = 0, datesw = 1;
+    int inplace = 1, datesw = 1;
     int msgp = 0, msgnum;
     char *cp, *maildir, *comp = NULL;
     char *text = NULL, *folder = NULL, buf[100], **ap;
@@ -47,7 +47,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -115,19 +115,19 @@ main (int argc, char **argv)
 	datesw = 0;
 #endif	/* UCI */
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
     if (!msgp)
 	msgs[msgp++] = "cur";
     if (!folder)
-	folder = m_getfolder ();
+	folder = getfolder (1);
     maildir = m_maildir (folder);
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -145,12 +145,11 @@ main (int argc, char **argv)
 	if (is_selected(mp, msgnum))
 	    annotate (m_name (msgnum), comp, text, inplace, datesw);
 
-    m_replace (pfolder, folder);	/* update current folder */
-    if (mp->lowsel != mp->curmsg)
-	seq_setcur (mp, mp->lowsel);
+    context_replace (pfolder, folder);	/* update current folder  */
+    seq_setcur (mp, mp->lowsel);	/* update current message */
     seq_save (mp);	/* synchronize message sequences */
-    m_freefolder (mp);	/* free folder/message structure */
-    m_update ();	/* update the context file       */
+    folder_free (mp);	/* free folder/message structure */
+    context_save ();	/* save the context file         */
     done (0);
 }
 
