@@ -42,6 +42,7 @@ static void burst (struct msgs **, int, struct smsg *, int, int, int);
 static void cpybrst (FILE *, FILE *, char *, char *, int);
 
 
+int
 main (int argc, char **argv)
 {
     int inplace = 0, quietsw = 0, verbosw = 0;
@@ -55,7 +56,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -112,19 +113,19 @@ main (int argc, char **argv)
 	    msgs[msgp++] = cp;
     }
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
     if (!msgp)
 	msgs[msgp++] = "cur";
     if (!folder)
-	folder = m_getfolder ();
+	folder = getfolder (1);
     maildir = m_maildir (folder);
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -162,8 +163,7 @@ main (int argc, char **argv)
     }
 
     free ((char *) smsgs);
-
-    m_replace (pfolder, folder);	/* update current folder */
+    context_replace (pfolder, folder);	/* update current folder */
 
     /*
      * If -inplace is given, then the first message burst becomes
@@ -180,8 +180,8 @@ main (int argc, char **argv)
     }
 
     seq_save (mp);	/* synchronize message sequences */
-    m_freefolder (mp);	/* free folder/message structure */
-    m_update ();	/* update the context file       */
+    context_save ();	/* save the context file         */
+    folder_free (mp);	/* free folder/message structure */
     done (0);
 }
 
@@ -207,14 +207,14 @@ find_delim (int msgnum, struct smsg *smsgs)
 	adios (msgnam, "unable to read message");
 
     for (msgp = 0, pos = 0L; msgp <= MAXFOLDER;) {
-	while (fgets (buffer, sizeof(buffer), in) != NULL && buffer[0] == '\n')
+	while (fgets (buffer, sizeof(buffer), in) && buffer[0] == '\n')
 	    pos += (long) strlen (buffer);
 	if (feof (in))
 	    break;
 	fseek (in, pos, SEEK_SET);
 	smsgs[msgp].s_start = pos;
 
-	for (c = 0; fgets (buffer, sizeof(buffer), in) != NULL; c = buffer[0]) {
+	for (c = 0; fgets (buffer, sizeof(buffer), in); c = buffer[0]) {
 	    if (strncmp (buffer, delim3, ld3) == 0
 		    && (msgp == 1 || c == '\n')
 		    && ((cc = peekc (in)) == '\n' || cc == EOF))
@@ -244,7 +244,7 @@ find_delim (int msgnum, struct smsg *smsgs)
 
 
 /*
- * Burst out all the messages in the digest
+ * Burst out the messages in the digest into the folder
  */
 
 static void
@@ -262,9 +262,14 @@ burst (struct msgs **mpp, int msgnum, struct smsg *smsgs, int numburst,
 	adios (msgnam, "unable to read message");
 
     mode = fstat (fileno(in), &st) != NOTOK ? (st.st_mode & 0777) : m_gmprot();
-
     mp = *mpp;
-    if ((mp = m_remsg (mp, 0, mp->hghmsg + numburst)) == NULL)
+
+    /*
+     * See if we have enough space in the folder
+     * structure for all the new messages.
+     */
+    if ((mp->hghmsg + numburst > mp->hghoff) &&
+	!(mp = folder_realloc (mp, 0, mp->hghmsg + numburst)))
 	adios (NULL, "unable to allocate folder storage");
     *mpp = mp;
 
@@ -289,14 +294,14 @@ burst (struct msgs **mpp, int msgnum, struct smsg *smsgs, int numburst,
 	for (i = mp->hghmsg; j > msgnum; i--, j--) {
 	    strcpy (f1, m_name (i));
 	    strcpy (f2, m_name (j));
-	    if (mp->msgstats[j] & EXISTS) {
+	    if (does_exist (mp, j)) {
 		if (verbosw)
 		    printf ("message %d becomes message %d\n", j, i);
 
 		if (rename (f2, f1) == NOTOK)
 		    admonish (f1, "unable to rename %s to", f2);
 		mp->msgstats[i] = mp->msgstats[j];
-		mp->msgstats[j] = 0;
+		clear_msg_flags (mp, j);
 		mp->msgflags |= SEQMOD;
 	    }
 	}
@@ -310,8 +315,7 @@ burst (struct msgs **mpp, int msgnum, struct smsg *smsgs, int numburst,
 	strcpy (f1, m_name (i));
 	strcpy (f2, m_scratch ("", invo_name));
 	if (verbosw && i != msgnum)
-	    printf ("message %d of digest %d becomes message %d\n",
-		    j, msgnum, i);
+	    printf ("message %d of digest %d becomes message %d\n", j, msgnum, i);
 
 	if ((out = fopen (f2, "w")) == NULL)
 	    adios (f2, "unable to write message");
@@ -340,6 +344,11 @@ burst (struct msgs **mpp, int msgnum, struct smsg *smsgs, int numburst,
 #define	S2  1
 #define	S3  2
 
+/*
+ * Copy a mesage which is being burst out of a digest.
+ * It will remove any "bit-stuffing" in the message.
+ */
+
 static void
 cpybrst (FILE *in, FILE *out, char *ifile, char *ofile, int len)
 {
@@ -380,7 +389,7 @@ cpybrst (FILE *in, FILE *out, char *ifile, char *ofile, int len)
 			break;
 
 		    default: 
-			state = c == '\n' ? S1 : S2;
+			state = (c == '\n') ? S1 : S2;
 			fputc ('-', out);
 			fputc (c, out);
 			break;
