@@ -80,7 +80,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -178,10 +178,10 @@ main (int argc, char **argv)
 
     cwd = getcpy (pwd ());
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
 
-    if ((dfolder || m_find ("Draft-Folder")) && !folder && msg && !file) {
+    if ((dfolder || context_find ("Draft-Folder")) && !folder && msg && !file) {
 	file = msg;
 	msg = NULL;
     }
@@ -192,14 +192,14 @@ main (int argc, char **argv)
 	if (!msg)
 	    msg = "cur";
 	if (!folder)
-	    folder = m_getfolder ();
+	    folder = getfolder (1);
 	maildir = m_maildir (folder);
 
 	if (chdir (maildir) == NOTOK)
 	    adios (maildir, "unable to change directory to");
 
 	/* read folder and create message structure */
-	if (!(mp = m_readfolder (folder)))
+	if (!(mp = folder_read (folder)))
 	    adios (NULL, "unable to read folder %s", folder);
 
 	if (mp->hghmsg == 0)
@@ -276,7 +276,7 @@ try_it_again: ;
     close (out);
 
 edit_it: ;
-    m_update ();	/* update the context file */
+    context_save ();	/* save the context file */
 
     if (nwhat)
 	done (0);
