@@ -69,7 +69,7 @@ static struct swit aqrl[] = {
 int
 main (int argc, char **argv)
 {
-    int anot = 0, inplace = 0, nedit = 0;
+    int anot = 0, inplace = 1, nedit = 0;
     int nwhat = 0, i, in, isdf = 0, out;
     char *cp, *cwd, *maildir, *msgnam, *dfolder = NULL;
     char *dmsg = NULL, *ed = NULL, *file = NULL, *folder = NULL;
@@ -82,7 +82,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     }
@@ -186,7 +186,7 @@ main (int argc, char **argv)
 
     cwd = getcpy (pwd ());
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
     if (file && (msg || folder))
 	adios (NULL, "can't mix files and folders/msgs");
@@ -243,12 +243,12 @@ try_it_again: ;
     if (!msg)
 	msg = "cur";
     if (!folder)
-	folder = m_getfolder ();
+	folder = getfolder (1);
     maildir = m_maildir (folder);
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
@@ -267,11 +267,10 @@ go_to_it: ;
 	adios (msgnam, "unable to open message");
 
     if (!file) {
-	m_replace (pfolder, folder);	/* update current folder   */
-	if (mp->lowsel != mp->curmsg)
-	    seq_setcur (mp, mp->lowsel);
-	seq_save (mp);
-	m_update ();			/* update the context file */
+	context_replace (pfolder, folder);/* update current folder  */
+	seq_setcur (mp, mp->lowsel);	  /* update current message */
+	seq_save (mp);			  /* synchronize sequences  */
+	context_save ();		  /* save the context file  */
     }
 
     if (nwhat)
