@@ -57,7 +57,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     }
@@ -129,8 +129,7 @@ main (int argc, char **argv)
     for (datep = 0; dates[datep]; datep++)
 	status += process (dates[datep], width);
 
-    m_update ();	/* update the context file */
-
+    context_save ();	/* save the context file */
     done (status);
 }
 
