@@ -28,28 +28,33 @@ static struct swit switches[] = {
     { "all", 0 },
 #define NOALLSW         2
     { "noall", 0 },
-#define ALPHASW         3
+#define SHOWZERO        3
+    { "showzero", 0 },
+#define NOSHOWZERO      4
+    { "noshowzero", 0 },
+#define ALPHASW         5
     { "alpha", 0 },
-#define NOALPHASW       4
+#define NOALPHASW       6
     { "noalpha", 0 },
-#define TOTAL           5
+#define TOTAL           7
     { "total", 0 },
-#define NOTOTAL         6
+#define NOTOTAL         8
     { "nototal", 0 },
-#define RECURSE         7
+#define RECURSE         9
     { "recurse", 0 },
-#define NORECURSE       8
+#define NORECURSE       10
     { "norecurse", 0 },
-#define VERSIONSW	9
+#define VERSIONSW	11
     { "version", 0 },
-#define HELPSW          10
+#define HELPSW          12
     { "help", 4 },
-    { NULL, NULL }
+    { NULL, 0 }
 };
 
 struct Folder {
     char *name;		/* name of folder */
     int priority;
+    int private;	/* is the sequence, public or private   */
     int nMsgs;		/* number of messages in folder         */
     int nSeq;		/* number of messages in given sequence */
 };
@@ -64,13 +69,16 @@ static int nFoldersAlloced = 0;
 static char **foldersToDo;
 static int nFoldersToDo;
 
-static int allFolders = FALSE;	/* show all folders or just with given seq? */
+static int toplevel   = FALSE;  /* scan all folders in top level?           */
 static int alphaOrder = FALSE;	/* want alphabetical order only             */
 static int recurse    = FALSE;	/* show nested folders?                     */
+static int showzero   = TRUE;	/* show folders even if no messages in seq? */
 static int Total      = TRUE;	/* display info on number of messages in    *
 				 * sequence found, and total num messages   */
 
 static char *sequence;		/* name of sequence we are searching for    */
+static char curfolder[BUFSIZ];	/* name of the current folder               */
+static char *maildir;		/* base nmh mail directory                  */
 
 /*
  * Type for a compare function for qsort.  This keeps
@@ -86,9 +94,13 @@ void GetFolderOrder(void);
 void ScanMailDir(void);
 void AddFolder(char *, int);
 void BuildFolderList(char *);
+void BuildFolderListRecurse(char *, struct stat *);
 void PrintFolders(void);
+static int num_digits (int);
 void AllocFolders(struct Folder **, int *, int);
 int AssignPriority(char *);
+static void do_readonly_folders(void);
+
 
 
 int
@@ -103,11 +115,20 @@ main(int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex(argv[0], '/');
-    if ((cp = m_find(invo_name)) != NULL) {
+
+    /*
+     * If program was invoked with name ending
+     * in `s', then add switch `-all'.
+     */
+    if (argv[0][strlen (argv[0]) - 1] == 's')
+	toplevel = TRUE;
+
+    if ((cp = context_find(invo_name)) != NULL) {
 	ap = brkstring(cp = getcpy(cp), " ", "\n");
 	ap = copyip(ap, arguments);
-    } else
+    } else {
 	ap = arguments;
+    }
     lastArg = copyip(argv + 1, ap);
     argp = arguments;
     argc = lastArg - argp;
@@ -136,24 +157,35 @@ main(int argc, char **argv)
 		    adios (NULL, "missing argument to %s", argp[-2]);
 		sequence = cp;
 		break;
+
 	    case ALLSW:
-		allFolders = TRUE;
+		toplevel = TRUE;
 		break;
 	    case NOALLSW:
-		allFolders = FALSE;
+		toplevel = FALSE;
 		break;
+
+	    case SHOWZERO:
+		showzero = TRUE;
+		break;
+	    case NOSHOWZERO:
+		showzero = FALSE;
+		break;
+
 	    case ALPHASW:
 		alphaOrder = TRUE;
 		break;
 	    case NOALPHASW:
 		alphaOrder = FALSE;
 		break;
+
 	    case TOTAL:
 		Total = TRUE;
 		break;
 	    case NOTOTAL:
 		Total = FALSE;
 		break;
+
 	    case RECURSE:
 		recurse = TRUE;
 		break;
@@ -168,12 +200,18 @@ main(int argc, char **argv)
 	}
     }
 
+    if (!context_find ("path"))
+        free (path ("./", TFOLDER));
+
     /*
      * If we didn't specify a sequence, we search
      * for the `unseen' sequence.
      */
     if (!sequence)
-	sequence = m_find(usequence);
+	sequence = context_find(usequence);
+
+    strcpy(curfolder, getfolder(1));	/* get current folder     */
+    maildir = m_maildir ("");		/* get nmh base directory */
 
     GetFolderOrder();
     ScanMailDir();
@@ -193,7 +231,7 @@ GetFolderOrder(void)
     int priority = 1;
     struct Folder *o;
 
-    if (!(p = m_find("Flist-Order")))
+    if (!(p = context_find("Flist-Order")))
 	return;
     for (;;) {
 	while (isspace(*p))
@@ -215,8 +253,11 @@ GetFolderOrder(void)
 }
 
 /*
- * Scan the given list of folders, or the top
- * level of our Mail directory.
+ * Begin building the list of folders
+ * to search by scanning
+ *   1) The given list of folders (or)
+ *   2) The top level of our Mail directory (or)
+ *   3) The current folder.
  */
 
 void
@@ -233,68 +274,102 @@ ScanMailDir(void)
     if (nFoldersToDo > 0) {
 	for (i = 0; i < nFoldersToDo; ++i)
 	    BuildFolderList(foldersToDo[i]);
-	return;
-    }
+    } else if (toplevel) {
+	/*
+	 * Do the readonly folders
+	 */
+	do_readonly_folders();
 
-    /*
-     * Else, scan the top level of the Mail directory
-     */
-    if (!(home = getenv("HOME")) || (chdir(home) < 0))
-	adios(NULL, "Can't change to home directory.");
-    if (!(path = m_find("path")))
-	adios(NULL, "Can't find Mail directory.");
-    if (!(dir = opendir(path)))
-	adios(NULL, "Can't open Path");
+	/*
+	 * Now scan all of top level folders of nmh directory
+	 */
+	if (!(home = getenv("HOME")) || (chdir(home) < 0))
+	    adios(NULL, "Can't change to home directory.");
+	if (!(path = context_find ("path")))
+	    adios(NULL, "Can't find Mail directory.");
+	if (!(dir = opendir(path)))
+	    adios(NULL, "Can't open Path");
 
-    while ((dp = readdir(dir))) {
-	if (dp->d_name[0] == '.')
-	    continue;
-	BuildFolderList(dp->d_name);
+	while ((dp = readdir(dir))) {
+	    if (dp->d_name[0] == '.')
+		continue;
+	    BuildFolderList(dp->d_name);
+	}
+    } else {
+	/*
+	 * Else scan current folder
+	 */
+	BuildFolderList(curfolder);
     }
 }
 
 /*
- * Build list of folders
+ * Initial building of folder list for top level folders
  */
 
 void
 BuildFolderList(char *dirName)
 {
+    struct stat st;
+
+    /* Make sure we have a directory */
+    if ((stat(m_mailpath(dirName), &st) == -1) || !S_ISDIR(st.st_mode))
+	return;
+
+    /* Add this folder to the list */
+    AddFolder(dirName, showzero);
+
+    /*
+     * If recursing and directory has subfolders,
+     * then build folder list for subfolders.
+     */
+    if (recurse && st.st_nlink > 2)
+	BuildFolderListRecurse(dirName, &st);
+}
+
+/*
+ * Recursive building of folder list for subfolders
+ */
+
+void
+BuildFolderListRecurse(char *dirName, struct stat *s)
+{
+    int nlinks;
     DIR *dir;
     struct dirent *dp;
-    struct stat s;
+    struct stat st;
     char name[PATH_MAX];
 
-    if (stat(m_mailpath(dirName), &s) == -1)
-	return;
-
     /*
-     * If we have a directory, then add it to
-     * our list of folders, else we return.
+     * Keep track of number of directories we've seen so we can
+     * stop stat'ing entries in this directory once we've seen
+     * them all.  This optimization will fail if you have extra
+     * directories beginning with ".", since we don't bother to
+     * stat them.  But that shouldn't generally be a problem.
      */
-    if (S_ISDIR(s.st_mode))
-	AddFolder(dirName, allFolders);
-    else
-	return;
-
-    /*
-     * If we are not recursing, or directory has no
-     * subdirectories, then we can return.
-     */
-    if (!recurse || s.st_nlink == 2)
-	return;
+    nlinks = s->st_nlink;
 
     if (!(dir = opendir(m_mailpath(dirName))))
 	adios(NULL, "Error while scanning Mail directory");
 
-    while ((dp = readdir(dir))) {
+    while (nlinks && (dp = readdir(dir))) {
+	if (!strcmp(dp->d_name, ".") || !strcmp(dp->d_name, "..")) {
+	    nlinks--;
+	    continue;
+	}
 	if (dp->d_name[0] == '.')
 	    continue;
 	strcpy(name, dirName);
 	if (*dirName)
 	    strcat(name, "/");
 	strcat(name, dp->d_name);
-	BuildFolderList(name);
+	if ((stat(m_mailpath(name), &st) != -1) && S_ISDIR(st.st_mode)) {
+	    /* Add this folder to the list */
+	    AddFolder(name, showzero);
+	    nlinks--;
+	    if (st.st_nlink > 2)
+		BuildFolderListRecurse(name, &st);
+	}
     }
     closedir(dir);
 }
@@ -312,26 +387,8 @@ AddFolder(char *name, int force)
     struct Folder *f;
     struct msgs *mp;
 
-#if 0
-    char buf[1024];
-    struct stat s;
-#endif
-
-#if 0
-    /*
-     * Attempt a shortcut to avoid reading this directory
-     * if we're only looking for unseen messages, by
-     * checking if a sequence file exists in this folder.
-     */
-    if (!force) {
-	sprintf(buf, "%s/%s", name, mh_seq);
-	if (stat(buf, &s) < 0)
-	    return;
-    }
-#endif
-
     /* read folder and create message structure */
-    if (!(mp = m_readfolder (name))) {
+    if (!(mp = folder_read (name))) {
 	advise(NULL, "Can't read folder %s.", name);
 	return;
     }
@@ -351,29 +408,87 @@ AddFolder(char *name, int force)
 	AllocFolders(&folders, &nFoldersAlloced, nFolders + 1);
 	f = &folders[nFolders++];
 	f->name = getcpy(name);
+	f->private = (seqnum != -1) ? is_seq_private(mp, seqnum) : 0;
 	f->nMsgs = mp->nummsg;
 	f->nSeq = nSeq;
 	f->priority = AssignPriority(f->name);
     }
 
-    m_freefolder (mp);	/* free folder/message structure */
+    folder_free (mp);	/* free folder/message structure */
 }
 
+/*
+ * Print the folder/sequence information
+ */
+
 void
 PrintFolders(void)
 {
-    int i;
+    char tmpname[BUFSIZ];
+    int i, len, maxlen = 0;
+    int maxnum = 0, maxseq = 0;
+    int has_private = 0;
+
+    if (!Total) {
+	for (i = 0; i < nFolders; ++i)
+	    printf("%s\n", folders[i].name);
+	return;
+    }
+
+    /*
+     * Find the width we need for various fields
+     */
+    for (i = 0; i < nFolders; ++i) {
+	/* find the length of longest folder name */
+	len = strlen(folders[i].name);
+	if (len > maxlen)
+	    maxlen = len;
+
+	/* find the maximum number of messages in sequence */
+	if (folders[i].nSeq > maxseq)
+	    maxseq = folders[i].nSeq;
+
+	/* find the maximum total messages */
+	if (folders[i].nMsgs > maxnum)
+	    maxnum = folders[i].nMsgs;
+
+	/* check if this sequence is private in any of the folders */
+	if (folders[i].private)
+	    has_private = 1;
+    }
 
     for (i = 0; i < nFolders; ++i) {
-	if (Total) {
-	    printf("+%-12s %3d in sequence %s, out of %3d\n", folders[i].name,
-		   folders[i].nSeq, sequence, folders[i].nMsgs);
-	} else {
-	    printf("%s\n", folders[i].name);
-	}
+	/* Add `+' to end of name of current folder */
+	if (strcmp(curfolder, folders[i].name))
+	    sprintf(tmpname, "%s", folders[i].name);
+	else
+	    sprintf(tmpname, "%s+", folders[i].name);
+
+	printf("%-*s has %*d in sequence %s%s; out of %*d\n",
+		maxlen+1, tmpname,
+		num_digits(maxseq), folders[i].nSeq,
+		sequence,
+		!has_private ? "" : folders[i].private ? " (private)" : "          ",
+		num_digits(maxnum), folders[i].nMsgs);
     }
 }
 
+/*
+ * Calculate the number of digits in positive integer
+ */
+static int
+num_digits (int n)
+{
+    int ndigits = 0;
+
+    while (n) {
+	n /= 10;
+	ndigits++;
+    }
+
+    return ndigits;
+}
+
 /*
  * Put them in priority order.
  */
@@ -437,3 +552,24 @@ AssignPriority(char *name)
     }
     return best;
 }
+
+/*
+ * Do the read only folders
+ */
+
+static void
+do_readonly_folders (void)
+{
+    int atrlen;
+    char atrcur[BUFSIZ];
+    register struct node *np;
+
+    sprintf (atrcur, "atr-%s-", current);
+    atrlen = strlen (atrcur);
+
+    context_read ();
+    for (np = m_defs; np; np = np->n_next)
+        if (ssequal (atrcur, np->n_name)
+                && !ssequal (maildir, np->n_name + atrlen))
+            BuildFolderList (np->n_name + atrlen);
+}
