@@ -13,49 +13,51 @@
 static struct swit switches[] = {
 #define	ALLSW           0
     { "all", 0 },
-#define	CREATSW         1
+#define NALLSW		1
+    { "noall", 0 },
+#define	CREATSW         2
     { "create", 0 },
-#define	NCREATSW        2
+#define	NCREATSW        3
     { "nocreate", 0 },
-#define	FASTSW          3
+#define	FASTSW          4
     { "fast", 0 },
-#define	NFASTSW         4
+#define	NFASTSW         5
     { "nofast", 0 },
-#define	HDRSW           5
+#define	HDRSW           6
     { "header", 0 },
-#define	NHDRSW          6
+#define	NHDRSW          7
     { "noheader", 0 },
-#define	PACKSW          7
+#define	PACKSW          8
     { "pack", 0 },
-#define	NPACKSW         8
+#define	NPACKSW         9
     { "nopack", 0 },
-#define	VERBSW          9
+#define	VERBSW         10
     { "verbose", 0 },
-#define	NVERBSW        10
+#define	NVERBSW        11
     { "noverbose", 0 },
-#define	RECURSW        11
+#define	RECURSW        12
     { "recurse", 0 },
-#define	NRECRSW        12
+#define	NRECRSW        13
     { "norecurse", 0 },
-#define	TOTALSW        13
+#define	TOTALSW        14
     { "total", 0 },
-#define	NTOTLSW        14
+#define	NTOTLSW        15
     { "nototal", 0 },
-#define	PRNTSW         15
-    { "print", 0 },
-#define	NPRNTSW        16
-    { "noprint", -4 },
-#define	LISTSW         17
+#define	LISTSW         16
     { "list", 0 },
-#define	NLISTSW        18
+#define	NLISTSW        17
     { "nolist", 0 },
-#define	PUSHSW         19
+#define	PRNTSW         18
+    { "print", 0 },
+#define	NPRNTSW        19
+    { "noprint", -4 },
+#define	PUSHSW         20
     { "push", 0 },
-#define	POPSW          20
+#define	POPSW          21
     { "pop", 0 },
-#define VERSIONSW      21
+#define VERSIONSW      22
     { "version", 0 },
-#define	HELPSW         22
+#define	HELPSW         23
     { "help", 4 },
     { NULL, 0 }
 };
@@ -68,18 +70,20 @@ static int fpack         = 0;	/* are we packing the folder?               */
 static int fverb         = 0;	/* print actions taken while packing folder */
 static int fheader       = 0;	/* should we output a header?               */
 static int frecurse      = 0;	/* recurse through subfolders               */
-static int ftotonly      = 0;	/* should we only output the totals?        */
+static int ftotal        = 0;	/* should we output the totals?             */
+static int all           = 0;	/* should we output all folders             */
+
 static int total_msgs    = 0;	/* total number of messages                 */
 static int total_folders = 0;	/* total number of folders                  */
 
 static int start    = 0;
 static int foldp    = 0;
 
-static char *mhdir;
+static char *nmhdir;
 static char *stack = "Folder-Stack";
 static char folder[BUFSIZ];
 
-#define NUMFOLDERS 256
+#define NUMFOLDERS 100
 
 /*
  * This is how many folders we currently can hold in the array
@@ -88,7 +92,11 @@ static char folder[BUFSIZ];
 static int maxfolders;
 static char **folds;
 
-struct Folder {
+/*
+ * Structure to hold information about
+ * folders as we scan them.
+ */
+struct FolderInfo {
     char *name;
     int nummsg;
     int curmsg;
@@ -98,27 +106,31 @@ struct Folder {
     int error;		/* error == 1 for unreadable folder     */
 };
 
-static struct Folder fi;
+/*
+ * Dynamically allocated space to hold
+ * all the folder information.
+ */
+static struct FolderInfo *fi;
+static int maxFolderInfo;
 
 /*
  * static prototypes
  */
 static void dodir (char *);
 static int get_folder_info (char *, char *);
-static void print_header (void);
-static void print_folder_info (struct Folder *, char *);
-static void print_totals (void);
+static void print_folders (void);
+static int num_digits (int);
 static int sfold (struct msgs *, char *);
 static void addir (char *);
 static void addfold (char *);
 static int compare (char *, char *);
-static void do_readonly (void);
+static void readonly_folders (void);
 
 
 int
 main (int argc, char **argv)
 {
-    int all = 0, printsw = 0, listsw = 0;
+    int printsw = 0, listsw = 0;
     int pushsw = 0, popsw = 0;
     char *cp, *dp, *msg = NULL, *argfolder = NULL;
     char **ap, **argp, buf[100], *arguments[MAXARGS];
@@ -128,14 +140,20 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
+
+    /*
+     * If program was invoked with name ending
+     * in `s', then add switch `-all'.
+     */
     if (argv[0][strlen (argv[0]) - 1] == 's')
 	all = 1;
-    if ((cp = m_find (invo_name))) {
+
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -160,6 +178,10 @@ main (int argc, char **argv)
 		    all = 1;
 		    continue;
 
+		case NALLSW:
+		    all = 0;
+		    continue;
+
 		case CREATSW: 
 		    fcreat = 1;
 		    continue;
@@ -203,11 +225,10 @@ main (int argc, char **argv)
 		    continue;
 
 		case TOTALSW: 
-		    ftotonly = 1;
-		    all = 1;
+		    ftotal = 1;
 		    continue;
 		case NTOTLSW: 
-		    ftotonly = 0;
+		    ftotal = -1;
 		    continue;
 
 		case PRNTSW: 
@@ -247,9 +268,9 @@ main (int argc, char **argv)
 		msg = cp;
     }
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
-    mhdir = concat (m_maildir (""), "/", NULL);
+    nmhdir = concat (m_maildir (""), "/", NULL);
 
     /*
      * If we aren't working with the folder stack
@@ -263,23 +284,23 @@ main (int argc, char **argv)
 	if (!argfolder) {
 	    /* If no folder is given, the current folder and */
 	    /* the top of the folder stack are swapped.      */
-	    if ((cp = m_find (stack))) {
+	    if ((cp = context_find (stack))) {
 		dp = getcpy (cp);
 		ap = brkstring (dp, " ", "\n");
 		argfolder = getcpy(*ap++);
 	    } else {
 		adios (NULL, "no other folder");
 	    }
-	    for (cp = getcpy (m_getfolder ()); *ap; ap++)
+	    for (cp = getcpy (getfolder (1)); *ap; ap++)
 		cp = add (*ap, add (" ", cp));
 	    free (dp);
-	    m_replace (stack, cp);	/* update folder stack */
+	    context_replace (stack, cp);	/* update folder stack */
 	} else {
 	    /* update folder stack */
-	    m_replace (stack,
-		    (cp = m_find (stack))
-		    ? concat (m_getfolder (), " ", cp, NULL)
-		    : getcpy (m_getfolder ()));
+	    context_replace (stack,
+		    (cp = context_find (stack))
+		    ? concat (getfolder (1), " ", cp, NULL)
+		    : getcpy (getfolder (1)));
 	}
     }
 
@@ -287,7 +308,7 @@ main (int argc, char **argv)
     if (popsw) {
 	if (argfolder)
 	    adios (NULL, "sorry, no folders allowed with -pop");
-	if ((cp = m_find (stack))) {
+	if ((cp = context_find (stack))) {
 	    dp = getcpy (cp);
 	    ap = brkstring (dp, " ", "\n");
 	    argfolder = getcpy(*ap++);
@@ -299,9 +320,9 @@ main (int argc, char **argv)
 	    cp = getcpy (*ap++);
 	    for (; *ap; ap++)
 		cp = add (*ap, add (" ", cp));
-	    m_replace (stack, cp);		/* update folder stack */
+	    context_replace (stack, cp);	/* update folder stack */
 	} else {
-	    m_delete (stack);	/* delete folder stack entry from context */
+	    context_del (stack);	/* delete folder stack entry from context */
 	}
 	free (dp);
     }
@@ -309,15 +330,15 @@ main (int argc, char **argv)
 	cp = m_maildir(argfolder);
 	if (access (cp, F_OK) == NOTOK)
 	    adios (cp, "unable to find folder");
-	m_replace (pfolder, argfolder);	/* update current folder   */
-	m_update ();			/* update the context file */
+	context_replace (pfolder, argfolder);	/* update current folder   */
+	context_save ();		/* save the context file   */
 	argfolder = NULL;
     }
 
     /* Listing the folder stack */
     if (listsw) {
-	printf ("%s", argfolder ? argfolder : m_getfolder ());
-	if ((cp = m_find (stack))) {
+	printf ("%s", argfolder ? argfolder : getfolder (1));
+	if ((cp = context_find (stack))) {
 	    dp = getcpy (cp);
 	    for (ap = brkstring (dp, " ", "\n"); *ap; ap++)
 		printf (" %s", *ap);
@@ -334,39 +355,45 @@ main (int argc, char **argv)
     if ((folds = malloc (maxfolders * sizeof(char *))) == NULL)
 	adios (NULL, "unable to allocate storage for folder names");
 
-    /* Do all folders at either top or first level */
-    if (all) {
-	if (!fshort && !ftotonly && (fheader >= 0))
-	    print_header();
-	if (argfolder) {
-	    strcpy (folder, argfolder);
-	    if (get_folder_info (argfolder, msg)) {
-		m_replace (pfolder, argfolder);	/* update current folder   */
-		m_update ();			/* update the context file */
-	    }
-	    if (!frecurse)	/* recurse wasn't done in get_folder_info(), */
-		dodir (folder);	/* so just list all level-1 sub-folders      */
-	} else {
-	    /* no folder given, so do them all */
+    /* Allocate initial space to record folder information */
+    maxFolderInfo = NUMFOLDERS;
+    if ((fi = malloc (maxFolderInfo * sizeof(*fi))) == NULL)
+	adios (NULL, "unable to allocate storage for folder info");
+
+    /*
+     * Scan the folders
+     */
+    if (all || ftotal > 0) {
+	/*
+	 * If no folder is given, do them all
+	 */
+	if (!argfolder) {
 	    if (msg)
 		admonish (NULL, "no folder given for message %s", msg);
-	    do_readonly ();
-	    strcpy (folder, (cp = m_find (pfolder)) ? cp : "");
+	    readonly_folders (); /* do any readonly folders */
+	    strcpy (folder, (cp = context_find (pfolder)) ? cp : "");
 	    dodir (".");
+	} else {
+	    strcpy (folder, argfolder);
+	    if (get_folder_info (argfolder, msg)) {
+		context_replace (pfolder, argfolder);/* update current folder */
+		context_save ();		     /* save the context file */
+	    }
+	    /*
+	     * recurse wasn't done in get_folder_info(),
+	     * so just list all level-1 sub-folders
+	     */
+	    if (!frecurse)
+		dodir (folder);
 	}
-	if (!fshort)
-	    print_totals();	/* print folder/message totals */
-
     } else {
-	if (!fshort && (fheader > 0))
-	    print_header();
-	strcpy (folder, argfolder ? argfolder : m_getfolder ());
+	strcpy (folder, argfolder ? argfolder : getfolder (1));
 
 	/*
 	 * Check if folder exists.  If not, then see if
 	 * we should create it, or just exit.
 	 */
-	if (stat (strcpy (buf, m_maildir (folder)), &st) == NOTOK) {
+	if (stat (strcpy (buf, m_maildir (folder)), &st) == -1) {
 	    if (errno != ENOENT)
 		adios (buf, "error on folder");
 	    if (fcreat == 0) {
@@ -383,14 +410,25 @@ main (int argc, char **argv)
 		adios (NULL, "unable to create folder %s", buf);
 	}
 
-	if (get_folder_info (folder, msg) && argfolder)
-	    m_replace (pfolder, argfolder);	/* update current folder */
+	if (get_folder_info (folder, msg) && argfolder) {
+	    /* update current folder */
+	    context_replace (pfolder, argfolder);
+	    }
     }
 
-    m_update ();	/* update the context file */
+    /*
+     * Print out folder information
+     */
+    print_folders();
+
+    context_save ();	/* save the context file */
     done (0);
 }
 
+/*
+ * Base routine for scanning a folder
+ */
+
 static void
 dodir (char *dir)
 {
@@ -400,10 +438,13 @@ dodir (char *dir)
     char buffer[BUFSIZ];
 
     start = foldp;
-    if (chdir (mhdir) == NOTOK)
-	adios (mhdir, "unable to change directory to");
+
+    /* change directory to base of nmh directory */
+    if (chdir (nmhdir) == NOTOK)
+	adios (nmhdir, "unable to change directory to");
 
     addir (strcpy (buffer, dir));
+
     for (i = start; i < foldp; i++) {
 	get_folder_info (folds[i], NULL);
 	fflush (stdout);
@@ -416,20 +457,33 @@ dodir (char *dir)
 static int
 get_folder_info (char *fold, char *msg)
 {
-    int	retval = 1;
+    int	i, retval = 1;
     register char *mailfile;
-    register struct msgs *mp = NULL;
+    struct msgs *mp = NULL;
 
-    fi.name = fold;
-    fi.error = 0;
+    i = total_folders++;
+
+    /*
+     * if necessary, reallocate the space
+     * for folder information
+     */
+    if (total_folders >= maxFolderInfo) {
+	maxFolderInfo += NUMFOLDERS;
+	if ((fi = realloc (fi, maxFolderInfo * sizeof(*fi))) == NULL)
+	    adios (NULL, "unable to re-allocate storage for folder info");
+    }
+
+    fi[i].name = fold;
+    fi[i].error = 0;
 
     mailfile = m_maildir (fold);
-    if (chdir (mailfile) == 0) {
-	if (!fshort || msg || fpack) {
+
+    if (!chdir (mailfile)) {
+	if ((ftotal > 0) || !fshort || msg || fpack) {
 	    /*
 	     * create message structure and get folder info
 	     */
-	    if (!(mp = m_readfolder (fold))) {
+	    if (!(mp = folder_read (fold))) {
 		admonish (NULL, "unable to read folder %s", fold);
 		return 0;
 	    }
@@ -438,100 +492,171 @@ get_folder_info (char *fold, char *msg)
 		retval = 0;
 
 	    if (fpack) {
-		mp = m_packfolder (mp, fverb);
-		seq_save (mp);	/* synchronize the sequences */
-		m_update ();	/* update the context file   */
+		if (folder_pack (&mp, fverb) == -1)
+		    done (1);
+		seq_save (mp);		/* synchronize the sequences */
+		context_save ();	/* save the context file     */
 	    }
 
-	    if (!fshort) {
-		total_folders++;
+	    if ((ftotal > 0) || !fshort) {
 		total_msgs += mp->nummsg;
 
-		fi.nummsg = mp->nummsg;
-		fi.curmsg = mp->curmsg;
-		fi.lowmsg = mp->lowmsg;
-		fi.hghmsg = mp->hghmsg;
-		fi.others = other_files (mp);
+		fi[i].nummsg = mp->nummsg;
+		fi[i].curmsg = mp->curmsg;
+		fi[i].lowmsg = mp->lowmsg;
+		fi[i].hghmsg = mp->hghmsg;
+		fi[i].others = other_files (mp);
 	    }
 
-	    /* free folder/message structure */
-	    m_freefolder (mp);
+	    folder_free (mp); /* free folder/message structure */
 	}
     } else {
-	fi.error = 1;
+	fi[i].error = 1;
     }
 
-    if (!ftotonly || fshort || fi.error) {
-	/* print summary of folder */
-	print_folder_info (&fi, fold);
-    }
-
-    if (frecurse && (fshort || fi.others) && (fi.error == 0))
+    if (frecurse && (fshort || fi[i].others) && (fi[i].error == 0))
 	dodir (fold);
     return retval;
 }
 
-
 /*
- * Print the header
+ * Print folder information
  */
 
 static void
-print_header (void)
+print_folders (void)
 {
-    printf ("\t\tFolder  %*s# of messages (%*srange%*s); cur%*smsg  (other files)\n",
-	DMAXFOLDER, "", DMAXFOLDER - 2, "", DMAXFOLDER - 2, "", DMAXFOLDER - 2, "");
+    int i, len, hasempty = 0, curprinted;
+    int maxlen = 0, maxnummsg = 0, maxlowmsg = 0;
+    int maxhghmsg = 0, maxcurmsg = 0;
+    int nummsgdigits, lowmsgdigits;
+    int hghmsgdigits, curmsgdigits;
+    char tmpname[BUFSIZ];
+
+    /*
+     * compute width needed for printing various fields
+     */
+    for (i = 0; i < total_folders; i++) {
+	/* length of folder name */
+	len = strlen (fi[i].name);
+	if (len > maxlen)
+	    maxlen = len;
+
+	/* maximum number of messages */
+	if (fi[i].nummsg > maxnummsg)
+	    maxnummsg = fi[i].nummsg;
+
+	/* maximum low message */
+	if (fi[i].lowmsg > maxlowmsg)
+	    maxlowmsg = fi[i].lowmsg;
+
+	/* maximum high message */
+	if (fi[i].hghmsg > maxhghmsg)
+	    maxhghmsg = fi[i].hghmsg;
+
+	/* maximum current message */
+	if (fi[i].curmsg >= fi[i].lowmsg &&
+	    fi[i].curmsg <= fi[i].hghmsg &&
+	    fi[i].curmsg > maxcurmsg)
+	    maxcurmsg = fi[i].curmsg;
+
+	/* check for empty folders */
+	if (fi[i].hghmsg == 0)
+	    hasempty = 1;
+    }
+    nummsgdigits = num_digits (maxnummsg);
+    lowmsgdigits = num_digits (maxlowmsg);
+    hghmsgdigits = num_digits (maxhghmsg);
+    curmsgdigits = num_digits (maxcurmsg);
+
+    if (hasempty && nummsgdigits < 2)
+	nummsgdigits = 2;
+
+    /*
+     * Print the header
+     */
+    if (fheader > 0 || (all && !fshort && fheader >= 0))
+	printf ("%-*s %*s %-*s; %-*s %*s\n",
+		maxlen+1, "FOLDER",
+		nummsgdigits + 13, "# MESSAGES",
+		lowmsgdigits + hghmsgdigits + 4, " RANGE",
+		curmsgdigits + 4, "CUR",
+		9, "(OTHERS)");
+
+    /*
+     * Print folder information
+     */
+    if (all || fshort || ftotal < 1) {
+	for (i = 0; i < total_folders; i++) {
+	    /* Add `+' to end of name, if folder is current */
+	    if (strcmp (folder, fi[i].name))
+		sprintf (tmpname, "%s", fi[i].name);
+	    else
+		sprintf (tmpname, "%s+", fi[i].name);
+
+	    if (fi[i].error) {
+		printf ("%-*s is unreadable\n", maxlen+1, tmpname);
+		continue;
+	    }
+
+	    if (fshort) {
+		printf ("%s\n", fi[i].name);
+		continue;
+	    }
+
+	    printf ("%-*s ", maxlen+1, tmpname);
+
+	    curprinted = 0; /* remember if we print cur */
+	    if (fi[i].hghmsg == 0) {
+		printf ("has %*s messages%*s",
+			nummsgdigits, "no",
+			fi[i].others ? lowmsgdigits + hghmsgdigits + 5 : 0, "");
+	    } else {
+		printf ("has %*d message%s  (%*d-%*d)",
+			nummsgdigits, fi[i].nummsg,
+			(fi[i].nummsg == 1) ? " " : "s",
+			lowmsgdigits, fi[i].lowmsg,
+			hghmsgdigits, fi[i].hghmsg);
+		if (fi[i].curmsg >= fi[i].lowmsg && fi[i].curmsg <= fi[i].hghmsg) {
+		    curprinted = 1;
+		    printf ("; cur=%*d", curmsgdigits, fi[i].curmsg);
+		}
+	    }
+
+	    if (fi[i].others)
+		printf (";%*s (others)", curprinted ? 0 : curmsgdigits + 6, "");
+	    printf (".\n");
+	}
+    }
+
+    /*
+     * Print folder/message totals
+     */
+    if (ftotal > 0 || (all && !fshort && ftotal >= 0)) {
+	if (all)
+	    printf ("\n");
+	printf ("TOTAL = %d message%c in %d folder%s.\n",
+		total_msgs, total_msgs != 1 ? 's' : ' ',
+		total_folders, total_folders != 1 ? "s" : "");
+    }
+
+    fflush (stdout);
 }
 
 /*
- * Print summary of folder information
+ * Return the number of digits needed for a positive integer
  */
-
-static void
-print_folder_info (struct Folder *fi, char *fold)
+int
+num_digits (int n)
 {
-    int hack = 0;
+    int ndigits = 0;
 
-    if (fi->error) {
-	printf ("%22s%c is unreadable\n", fold, strcmp (folder, fold) ? ' ' : '+');
-	return;
+    while (n) {
+	n /= 10;
+	ndigits++;
     }
 
-    if (fshort) {
-	printf ("%s\n", fold);
-	return;
-    }
-
-    printf ("%22s%c ", fold, strcmp (folder, fold) ? ' ' : '+');
-
-    if (fi->hghmsg == 0)
-	printf ("has   no messages%*s",
-		fi->others ? DMAXFOLDER * 2 + 4 : 0, "");
-    else {
-	printf ("has %*d message%s (%*d-%*d)",
-		DMAXFOLDER, fi->nummsg, (fi->nummsg == 1) ? " " : "s",
-		DMAXFOLDER, fi->lowmsg, DMAXFOLDER, fi->hghmsg);
-	if (fi->curmsg >= fi->lowmsg && fi->curmsg <= fi->hghmsg)
-	    printf ("; cur=%*d", DMAXFOLDER, hack = fi->curmsg);
-    }
-
-    if (fi->others)
-	printf (";%*s (others)", hack ? 0 : DMAXFOLDER + 6, "");
-    printf (".\n");
-}
-
-/*
- * Print folder/message totals
- */
-
-static void
-print_totals (void)
-{
-    if (!ftotonly)
-	printf ("\n\t\t     ");
-    printf ("TOTAL= %*d message%c in %d folder%s.\n",
-	DMAXFOLDER, total_msgs, total_msgs != 1 ? 's' : ' ',
-	total_folders, total_folders != 1 ? "s" : "");
+    return ndigits;
 }
 
 /*
@@ -552,7 +677,7 @@ sfold (struct msgs *mp, char *msg)
     seq_setprev (mp);		/* set the previous-sequence     */
     seq_setcur (mp, mp->lowsel);/* set current message           */
     seq_save (mp);		/* synchronize message sequences */
-    m_update ();		/* update the context file       */
+    context_save ();		/* save the context file         */
 
     return 1;
 }
@@ -561,10 +686,11 @@ sfold (struct msgs *mp, char *msg)
 static void
 addir (char *name)
 {
-    register char *base, *cp;
+    int nlink;
+    char *base, *cp;
     struct stat st;
-    register struct dirent *dp;
-    register DIR * dd;
+    struct dirent *dp;
+    DIR * dd;
 
     cp = name + strlen (name);
     *cp++ = '/';
@@ -573,26 +699,42 @@ addir (char *name)
     base = strcmp (name, "./") ? name : name + 2; /* hack */
 
    /* short-cut to see if directory has any sub-directories */
-    if (stat (name, &st) != NOTOK && st.st_nlink == 2)
+    if (stat (name, &st) != -1 && st.st_nlink == 2)
         return;
  
     if (!(dd = opendir (name))) {
 	admonish (name, "unable to read directory ");
 	return;
     }
-    while ((dp = readdir (dd)))
-	if (strcmp (dp->d_name, ".") && strcmp (dp->d_name, "..")) {
-	    if (cp + NLENGTH(dp) + 2 >= name + BUFSIZ)
-		continue;
-	    strcpy (cp, dp->d_name);
-	    if (stat (name, &st) != NOTOK && S_ISDIR(st.st_mode))
-		addfold (base);
-	}
-    closedir (dd);
 
+    /*
+     * Keep track of the number of directories we've seen
+     * so we can quit stat'ing early, if we've seen them all.
+     */
+    nlink = st.st_nlink;
+
+    while (nlink && (dp = readdir (dd))) {
+	if (!strcmp (dp->d_name, ".") || !strcmp (dp->d_name, "..")) {
+	    nlink--;
+	    continue;
+	}
+	if (cp + NLENGTH(dp) + 2 >= name + BUFSIZ)
+	    continue;
+	strcpy (cp, dp->d_name);
+	if (stat (name, &st) != -1 && S_ISDIR(st.st_mode)) {
+	    addfold (base);
+	    nlink--;
+	}
+    }
+
+    closedir (dd);
     *--cp = '\0';
 }
 
+/*
+ * Add the folder name into the
+ * list in a sorted fashion.
+ */
 
 static void
 addfold (char *fold)
@@ -638,7 +780,7 @@ compare (char *s1, char *s2)
  */
 
 static void
-do_readonly (void)
+readonly_folders (void)
 {
     int	atrlen;
     char atrcur[BUFSIZ];
@@ -647,9 +789,9 @@ do_readonly (void)
     sprintf (atrcur, "atr-%s-", current);
     atrlen = strlen (atrcur);
 
-    m_getdefs ();
+    context_read ();
     for (np = m_defs; np; np = np->n_next)
 	if (ssequal (atrcur, np->n_name)
-		&& !ssequal (mhdir, np->n_name + atrlen))
+		&& !ssequal (nmhdir, np->n_name + atrlen))
 	    get_folder_info (np->n_name + atrlen, NULL);
 }
