@@ -122,7 +122,7 @@ static void mhl_draft(int, char *, int, int, char *, char *, int);
 int
 main (int argc, char **argv)
 {
-    int msgp = 0, anot = 0, inplace = 0, mime = 0;
+    int msgp = 0, anot = 0, inplace = 1, mime = 0;
     int issue = 0, volume = 0, dashflg = 1;
     int nedit = 0, nwhat = 0, i, in;
     int out, isdf = 0, msgnum;
@@ -141,7 +141,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     }
@@ -294,7 +294,7 @@ main (int argc, char **argv)
 
     cwd = getcpy (pwd ());
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
     if (file && (msgp || folder))
 	adios (NULL, "can't mix files and folders/msgs");
@@ -342,12 +342,12 @@ try_it_again: ;
     if (!msgp)
 	msgs[msgp++] = "cur";
     if (!folder)
-	folder = m_getfolder ();
+	folder = getfolder (1);
     maildir = m_maildir (folder);
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
@@ -366,14 +366,14 @@ go_to_it: ;
 	if (issue == 0) {
 	    sprintf (buf, IFORMAT, digest);
 	    if (volume == 0
-		    && (cp = m_find (buf))
+		    && (cp = context_find (buf))
 		    && ((issue = atoi (cp)) < 0))
 		issue = 0;
 	    issue++;
 	}
 	if (volume == 0)
 	    sprintf (buf, VFORMAT, digest);
-	    if ((cp = m_find (buf)) == NULL || (volume = atoi (cp)) <= 0)
+	    if ((cp = context_find (buf)) == NULL || (volume = atoi (cp)) <= 0)
 		volume = 1;
 	if (!form)
 	    form = digestcomps;
@@ -414,17 +414,16 @@ go_to_it: ;
     if (digest) {
 	sprintf (buf, IFORMAT, digest);
 	sprintf (value, "%d", issue);
-	m_replace (buf, getcpy (value));
+	context_replace (buf, getcpy (value));
 	sprintf (buf, VFORMAT, digest);
 	sprintf (value, "%d", volume);
-	m_replace (buf, getcpy (value));
+	context_replace (buf, getcpy (value));
     }
 
-    m_replace (pfolder, folder);	/* update current folder   */
-    if (mp->lowsel != mp->curmsg)
-	seq_setcur (mp, mp->lowsel);
-    seq_save (mp);
-    m_update ();			/* update the context file */
+    context_replace (pfolder, folder);	/* update current folder   */
+    seq_setcur (mp, mp->lowsel);	/* update current message  */
+    seq_save (mp);			/* synchronize sequences   */
+    context_save ();			/* save the context file   */
 
 edit_it: ;
     if (nwhat)
