@@ -41,12 +41,6 @@
 #include <errno.h>
 #include <signal.h>
 
-#ifndef	MF
-# define MFminc(a) (a)
-#else
-# define MFminc(a)  0
-#endif
-
 #ifndef	POP
 # define POPminc(a) (a)
 #else
@@ -65,12 +59,6 @@
 # define APOPminc(a)  0
 #endif
 
-#ifndef	TMA
-# define TMAminc(a) (a)
-#else
-# define TMAminc(a)  0
-#endif
-
 static struct swit switches[] = {
 #define	AUDSW                      0
     { "audit audit-file", 0 },
@@ -80,55 +68,55 @@ static struct swit switches[] = {
     { "changecur", 0 },
 #define	NCHGSW                     3
     { "nochangecur", 0 },
-#define	DECRSW                     4
-    { "decrypt", TMAminc (-7) },
-#define	NDECRSW                    5
-    { "nodecrypt", TMAminc (-9) },
-#define	MSW                        6
+#define	MSW                        4
     { "file name", 0 },
-#define	FORMSW                     7
+#define	FORMSW                     5
     { "form formatfile", 0 },
-#define	FMTSW                      8
+#define	FMTSW                      6
     { "format string", 5 },
-#define	HOSTSW                     9
+#define	HOSTSW                     7
     { "host hostname", POPminc (-4) },
-#define	USERSW                    10
+#define	USERSW                     8
     { "user username", POPminc (-4) },
-#define	PACKSW                    11
+#define	PACKSW                     9
     { "pack file", POPminc (-4) },
-#define	NPACKSW                   12
+#define	NPACKSW                   10
     { "nopack", POPminc (-6) },
-#define	APOPSW                    13
+#define	APOPSW                    11
     { "apop", APOPminc (-4) },
-#define	NAPOPSW                   14
+#define	NAPOPSW                   12
     { "noapop", APOPminc (-6) },
-#define	RPOPSW                    15
+#define	RPOPSW                    13
     { "rpop", RPOPminc (-4) },
-#define	NRPOPSW                   16
+#define	NRPOPSW                   14
     { "norpop", RPOPminc (-6) },
-#define	SILSW                     17
+#define	SILSW                     15
     { "silent", 0 },
-#define	NSILSW                    18
+#define	NSILSW                    16
     { "nosilent", 0 },
-#define	TRNCSW                    19
+#define	TRNCSW                    17
     { "truncate", 0 },
-#define	NTRNCSW                   20
+#define	NTRNCSW                   18
     { "notruncate", 0 },
-#define	UUCPSW                    21
-    { "uucp", MFminc (-4) },
-#define	NUUCPSW                   22
-    { "nouucp", MFminc (-6) },
-#define	WIDTHSW                   23
+#define	WIDTHSW                   19
     { "width columns", 0 },
-#define VERSIONSW                 24
+#define VERSIONSW                 20
     { "version", 0 },
-#define	HELPSW                    25
+#define	HELPSW                    21
     { "help", 4 },
     { NULL, 0 }
 };
 
 extern int errno;
 
+/*
+ * flags for the mail source
+ */
+#define INC_FILE  0
+#define INC_POP   1
+
+static inc_type;
+
 #ifdef POP
 int snoop = 0;
 extern char response[];
@@ -164,15 +152,11 @@ static int pop_pack(char *);
 static int map_count(void);
 #endif
 
-#ifdef MF
-void get_uucp_mail(void);
-#endif
-
 
 int
 main (int argc, char **argv)
 {
-    int chgflag = 1, trnflag = 1, decflag = 1;
+    int chgflag = 1, trnflag = 1;
     int noisy = 1, width = 0, locked = 0;
     int rpop = 0, i, hghnum, msgnum;
     char *cp, *maildir, *folder = NULL;
@@ -186,10 +170,6 @@ main (int argc, char **argv)
     struct stat st, s1;
     FILE *in, *aud = NULL;
 
-#ifdef MF
-    int uucp = 1;
-#endif
-
 #ifdef POP
     int nmsgs, nbytes, p = 0;
     char *pass = NULL;
@@ -222,7 +202,7 @@ main (int argc, char **argv)
     if ((tmphost = getenv("MAILHOST")) != NULL)
 	pophost = tmphost;
     else if ((po = hes_getmailhost(getusr())) != NULL &&
-	    strcmp(po->po_type, "POP") == 0)
+	     strcmp(po->po_type, "POP") == 0)
 	pophost = po->po_host;
 # endif /* HESIOD */
     /*
@@ -236,7 +216,7 @@ main (int argc, char **argv)
 	snoop++;
 #endif /* POP */
 
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -248,124 +228,106 @@ main (int argc, char **argv)
     while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
-		case AMBIGSW: 
-		    ambigsw (cp, switches);
-		    done (1);
-		case UNKWNSW: 
-		    adios (NULL, "-%s unknown", cp);
+	    case AMBIGSW: 
+		ambigsw (cp, switches);
+		done (1);
+	    case UNKWNSW: 
+		adios (NULL, "-%s unknown", cp);
 
-		case HELPSW: 
-		    sprintf (buf, "%s [+folder] [switches]", invo_name);
-		    print_help (buf, switches);
-		    done (1);
-		case VERSIONSW:
-		    print_version(invo_name);
-		    done (1);
+	    case HELPSW: 
+		snprintf (buf, 100, "%s [+folder] [switches]", invo_name);
+		print_help (buf, switches);
+		done (1);
+	    case VERSIONSW:
+		print_version(invo_name);
+		done (1);
 
-		case AUDSW: 
-		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULL, "missing argument to %s", argp[-2]);
-		    audfile = getcpy (m_maildir (cp));
-		    continue;
-		case NAUDSW: 
-		    audfile = NULL;
-		    continue;
+	    case AUDSW: 
+		if (!(cp = *argp++) || *cp == '-')
+		    adios (NULL, "missing argument to %s", argp[-2]);
+		audfile = getcpy (m_maildir (cp));
+		continue;
+	    case NAUDSW: 
+		audfile = NULL;
+		continue;
 
-		case CHGSW: 
-		    chgflag++;
-		    continue;
-		case NCHGSW: 
-		    chgflag = 0;
-		    continue;
+	    case CHGSW: 
+		chgflag++;
+		continue;
+	    case NCHGSW: 
+		chgflag = 0;
+		continue;
 
-		case TRNCSW: 
-		    trnflag++;
-		    continue;
-		case NTRNCSW: 
-		    trnflag = 0;
-		    continue;
+	    case TRNCSW: 
+		trnflag++;
+		continue;
+	    case NTRNCSW: 
+		trnflag = 0;
+		continue;
 
-		case MSW: 
-		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULL, "missing argument to %s", argp[-2]);
-		    from = path (cp, TFILE);
-		    trnflag = 0;	/* don't truncate */
-		    continue;
+	    case MSW: 
+		if (!(cp = *argp++) || *cp == '-')
+		    adios (NULL, "missing argument to %s", argp[-2]);
+		from = path (cp, TFILE);
+		trnflag = 0;	/* don't truncate */
+		continue;
 
-		case SILSW: 
-		    noisy = 0;
-		    continue;
-		case NSILSW: 
-		    noisy++;
-		    continue;
+	    case SILSW: 
+		noisy = 0;
+		continue;
+	    case NSILSW: 
+		noisy++;
+		continue;
 
-		case FORMSW: 
-		    if (!(form = *argp++) || *form == '-')
-			adios (NULL, "missing argument to %s", argp[-2]);
-		    format = NULL;
-		    continue;
-		case FMTSW: 
-		    if (!(format = *argp++) || *format == '-')
-			adios (NULL, "missing argument to %s", argp[-2]);
-		    form = NULL;
-		    continue;
+	    case FORMSW: 
+		if (!(form = *argp++) || *form == '-')
+		    adios (NULL, "missing argument to %s", argp[-2]);
+		format = NULL;
+		continue;
+	    case FMTSW: 
+		if (!(format = *argp++) || *format == '-')
+		    adios (NULL, "missing argument to %s", argp[-2]);
+		form = NULL;
+		continue;
 
-		case WIDTHSW: 
-		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULL, "missing argument to %s", argp[-2]);
-		    width = atoi (cp);
-		    continue;
+	    case WIDTHSW: 
+		if (!(cp = *argp++) || *cp == '-')
+		    adios (NULL, "missing argument to %s", argp[-2]);
+		width = atoi (cp);
+		continue;
 
-		case DECRSW:
-		    decflag++;
-		    continue;
-		case NDECRSW:
-		    decflag = 0;
-		    continue;
-
-		case UUCPSW: 
-#ifdef MF
-		    uucp++;
-#endif /* MF */
-		    continue;
-		case NUUCPSW: 
-#ifdef MF
-		    uucp = 0;
-#endif /* MF */
-		    continue;
-
-		case HOSTSW:
-		    if (!(host = *argp++) || *host == '-')
-			adios (NULL, "missing argument to %s", argp[-2]);
-		    continue;
-		case USERSW:
-		    if (!(user = *argp++) || *user == '-')
-			adios (NULL, "missing argument to %s", argp[-2]);
-		    continue;
-		case PACKSW:
+	    case HOSTSW:
+		if (!(host = *argp++) || *host == '-')
+		    adios (NULL, "missing argument to %s", argp[-2]);
+		continue;
+	    case USERSW:
+		if (!(user = *argp++) || *user == '-')
+		    adios (NULL, "missing argument to %s", argp[-2]);
+		continue;
+	    case PACKSW:
 #ifndef	POP
-		    if (!(cp = *argp++) || *cp == '-')
-			adios (NULL, "missing argument to %s", argp[-2]);
+		if (!(cp = *argp++) || *cp == '-')
+		    adios (NULL, "missing argument to %s", argp[-2]);
 #else /* POP */
-		    if (!(packfile = *argp++) || *packfile == '-')
-			adios (NULL, "missing argument to %s", argp[-2]);
+		if (!(packfile = *argp++) || *packfile == '-')
+		    adios (NULL, "missing argument to %s", argp[-2]);
 #endif /* POP */
-		    continue;
-		case NPACKSW:
+		continue;
+	    case NPACKSW:
 #ifdef POP
-		    packfile = NULL;
+		packfile = NULL;
 #endif /* POP */
-		    continue;
-		case APOPSW:
-		    rpop = -1;
-		    continue;
-		case RPOPSW:
-		    rpop = 1;
-		    continue;
-		case NAPOPSW:
-		case NRPOPSW:
-		    rpop = 0;
-		    continue;
+		continue;
+	    case APOPSW:
+		rpop = -1;
+		continue;
+	    case RPOPSW:
+		rpop = 1;
+		continue;
+	    case NAPOPSW:
+	    case NRPOPSW:
+		rpop = 0;
+		continue;
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
@@ -390,23 +352,23 @@ main (int argc, char **argv)
 #endif /* POP */
 
     /*
-     * Are we getting the mail from an
-     * alternate file?
+     * Where are we getting the new mail?
      */
-    if (from) {
-	newmail = from;
+    if (from)
+	inc_type = INC_FILE;
 #ifdef POP
-	host = NULL;
-#endif /* POP */
-	if (stat (newmail, &s1) == NOTOK || s1.st_size == 0)
-	    adios (NULL, "no mail to incorporate");
-    }
+    else if (host)
+	inc_type = INC_POP;
+#endif
+    else
+	inc_type = INC_FILE;
+
 #ifdef POP
     /*
      * Are we getting the mail from
      * a POP server?
      */
-    else if (host) {
+    if (inc_type == INC_POP) {
 	if (user == NULL)
 	    user = getusr ();
 	if (rpop > 0)
@@ -437,18 +399,20 @@ main (int argc, char **argv)
 	}
     }
 #endif /* POP */
+
     /*
-     * we will get the mail from the standard maildrop
+     * We will get the mail from a file
+     * (typically the standard maildrop)
      */
-    else {
-	if (((newmail = getenv ("MAILDROP")) && *newmail)
-		|| ((newmail = m_find ("maildrop")) && *newmail))
+
+    if (inc_type == INC_FILE) {
+	if (from)
+	    newmail = from;
+	else if ((newmail = getenv ("MAILDROP")) && *newmail)
+	    newmail = m_mailpath (newmail);
+	else if ((newmail = context_find ("maildrop")) && *newmail)
 	    newmail = m_mailpath (newmail);
 	else {
-#ifdef MF
-	    if (uucp && umincproc && *umincproc)
-		get_uucp_mail ();
-#endif /* MF */
 	    newmail = concat (MAILDIR, "/", MAILFIL, NULL);
 	}
 	if (stat (newmail, &s1) == NOTOK || s1.st_size == 0)
@@ -456,14 +420,15 @@ main (int argc, char **argv)
     }
 
 #ifdef POP
-    if (host && packfile)
-	goto go_to_it;		/* skip the folder setup */
+    /* skip the folder setup */
+    if ((inc_type == INC_POP) && packfile)
+	goto go_to_it;
 #endif /* POP */
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
-    if (!folder && !(folder = m_find (inbox)))
-	folder = defalt;
+    if (!folder)
+	folder = getfolder (0);
     maildir = m_maildir (folder);
 
     if (stat (maildir, &st) == NOTOK) {
@@ -481,45 +446,44 @@ main (int argc, char **argv)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
 #ifdef POP
-go_to_it: ;
-    if (host == NULL) {
+ go_to_it: ;
 #endif /* POP */
-    if (access (newmail, W_OK) == NOTOK) {
-	trnflag = 0;
-	if ((in = fopen (newmail, "r")) == NULL)
-	    adios (newmail, "unable to read");
-    } else {
-	locked++;
-	if (trnflag) {
-	    SIGNAL (SIGHUP, SIG_IGN);
-	    SIGNAL (SIGINT, SIG_IGN);
-	    SIGNAL (SIGQUIT, SIG_IGN);
-	    SIGNAL (SIGTERM, SIG_IGN);
+
+    if (inc_type == INC_FILE) {
+	if (access (newmail, W_OK) != NOTOK) {
+	    locked++;
+	    if (trnflag) {
+		SIGNAL (SIGHUP, SIG_IGN);
+		SIGNAL (SIGINT, SIG_IGN);
+		SIGNAL (SIGQUIT, SIG_IGN);
+		SIGNAL (SIGTERM, SIG_IGN);
+	    }
+
+#ifdef MAILGROUP
+	    setgid(return_gid);	/* Reset gid to lock mail file */
+#endif /* MAILGROUP */
+
+	    /* lock and fopen the mail spool */
+	    if ((in = lkfopen (newmail, "r")) == NULL)
+		adios (NULL, "unable to lock and fopen %s", newmail);
+
+#ifdef MAILGROUP
+	    setgid(getgid());	/* Return us to normal privileges */
+#endif /* MAILGROUP */
+	    fstat (fileno(in), &s1);
+	} else {
+	    trnflag = 0;
+	    if ((in = fopen (newmail, "r")) == NULL)
+		adios (newmail, "unable to read");
 	}
-
-#ifdef MAILGROUP
-	setgid(return_gid);	/* Reset gid to lock mail file */
-#endif /* MAILGROUP */
-
-	/* lock and fopen the mail spool */
-	if ((in = lkfopen (newmail, "r")) == NULL)
-	    adios (NULL, "unable to lock and fopen %s", newmail);
-
-#ifdef MAILGROUP
-	setgid(getgid());	/* Return us to normal privileges */
-#endif /* MAILGROUP */
-	fstat (fileno(in), &s1);
     }
-#ifdef POP
-    }			/* host == NULL */
-#endif /* POP */
 
 #ifdef MAILGROUP
-	setgid(getgid());	/* Return us to normal privileges */
+    setgid(getgid());	/* Return us to normal privileges */
 #endif /* MAILGROUP */
 
     if (audfile) {
@@ -527,23 +491,23 @@ go_to_it: ;
 	    advise (NULL, "Creating Receive-Audit: %s", audfile);
 	if ((aud = fopen (audfile, "a")) == NULL)
 	    adios (audfile, "unable to append to");
-	else
-	    if (i == NOTOK)
-		chmod (audfile, m_gmprot ());
-#ifndef	POP
-	fprintf (aud, from ? "<<inc>> %s  -ms %s\n" : "<<inc>> %s\n",
-		dtimenow (0), from);
-#else /* POP */
+	else if (i == NOTOK)
+	    chmod (audfile, m_gmprot ());
+
+#ifdef POP
 	fprintf (aud, from ? "<<inc>> %s -ms %s\n"
-			: host ? "<<inc>> %s -host %s -user %s%s\n"
-			: "<<inc>> %s\n",
+		 : host ? "<<inc>> %s -host %s -user %s%s\n"
+		 : "<<inc>> %s\n",
 		 dtimenow (0), from ? from : host, user,
 		 rpop < 0 ? " -apop" : rpop > 0 ? " -rpop" : "");
+#else /* POP */
+	fprintf (aud, from ? "<<inc>> %s  -ms %s\n" : "<<inc>> %s\n",
+		 dtimenow (0), from);
 #endif /* POP */
     }
 
 #ifdef MHE
-    if (m_find ("mhe")) {
+    if (context_find ("mhe")) {
 	cp = concat (maildir, "/++", NULL);
 	i = stat (cp, &st);
 	if ((mhe = fopen (cp, "a")) == NULL)
@@ -566,7 +530,7 @@ go_to_it: ;
     /*
      * Get the mail from a POP server
      */
-    if (host) {
+    if (inc_type == INC_POP) {
 	if (packfile) {
 	    packfile = path (packfile, TFILE);
 	    if (stat (packfile, &st) == NOTOK) {
@@ -579,13 +543,13 @@ go_to_it: ;
 	    }
 	    msgnum = map_count ();
 	    if ((pd = mbx_open (packfile, mbx_style, getuid(), getgid(), m_gmprot()))
-		    == NOTOK)
+		== NOTOK)
 		adios (packfile, "unable to open");
 	    if ((pf = fdopen (pd, "w+")) == NULL)
 		adios (NULL, "unable to fdopen %s", packfile);
 	} else {
 	    hghnum = msgnum = mp->hghmsg;
-	    if ((mp = m_remsg (mp, 0, mp->hghmsg + nmsgs)) == NULL)
+	    if (!(mp = folder_realloc (mp, 0, mp->hghmsg + nmsgs)))
 		adios (NULL, "unable to allocate folder storage");
 	}
 
@@ -621,51 +585,41 @@ go_to_it: ;
 		fseek (pf, 0L, SEEK_SET);
 	    }
 	    switch (p = scan (pf, msgnum, 0, nfs, width,
-			packfile ? 0 : msgnum == mp->hghmsg + 1 && chgflag,
-			1,	/* check UNSEEN? */
-			0, stop - start, noisy)) {
-		case SCNEOF: 
-		    printf ("%*d  empty\n", DMAXFOLDER, msgnum);
-		    break;
+			      packfile ? 0 : msgnum == mp->hghmsg + 1 && chgflag,
+			      1, NULL, stop - start, noisy)) {
+	    case SCNEOF: 
+		printf ("%*d  empty\n", DMAXFOLDER, msgnum);
+		break;
 
-		case SCNFAT:
-		    trnflag = 0;
-		    noisy++;
-		    /* advise (cp, "unable to read"); already advised */
-		    /* fall thru */
+	    case SCNFAT:
+		trnflag = 0;
+		noisy++;
+		/* advise (cp, "unable to read"); already advised */
+		/* fall thru */
 
-		case SCNERR:
-		case SCNNUM: 
-		    break;
+	    case SCNERR:
+	    case SCNNUM: 
+		break;
 
-		case SCNMSG: 
-		case SCNENC:
-		default: 
-		    if (aud)
-			fputs (scanl, aud);
+	    case SCNMSG: 
+	    case SCNENC:
+	    default: 
+		if (aud)
+		    fputs (scanl, aud);
 # ifdef MHE
-		    if (mhe)
-			fputs (scanl, mhe);
+		if (mhe)
+		    fputs (scanl, mhe);
 # endif /* MHE */
-		    if (noisy)
-			fflush (stdout);
-		    if (!packfile) {
-			mp->msgstats[msgnum] = EXISTS;
-# ifdef TMA
-			if (p == SCNENC) {
-			    if (mp->lowsel == 0 || msgnum < mp->lowsel)
-				mp->lowsel = msgnum;
-			    if (mp->hghsel == 0 || msgnum > mp->hghsel)
-				mp->hghsel = msgnum;
-			    set_selected (mp, msgnum);
-			    mp->numsel++;
-			}
-# endif /* TMA */
-			set_unseen (mp, msgnum);
-			mp->msgflags |= SEQMOD;
-		    }
-		    break;
+		if (noisy)
+		    fflush (stdout);
+		if (!packfile) {
+		    clear_msg_flags (mp, msgnum);
+		    set_exists (mp, msgnum);
+		    set_unseen (mp, msgnum);
+		    mp->msgflags |= SEQMOD;
 		}
+		break;
+	    }
 	    if (packfile) {
 		fseek (pf, stop, SEEK_SET);
 		fwrite (mmdlm2, 1, strlen (mmdlm2), pf);
@@ -690,6 +644,7 @@ go_to_it: ;
 	    if (trnflag && pop_dele (i) == NOTOK)
 		adios (NULL, "%s", response);
 	}
+
 	if (pop_quit () == NOTOK)
 	    adios (NULL, "%s", response);
 	if (packfile) {
@@ -697,28 +652,40 @@ go_to_it: ;
 	    pd = NOTOK;
 	}
     }
-    else {
 #endif /* POP */
 
     /*
      * Get the mail from file (usually mail spool)
      */
-    m_unknown (in);		/* the MAGIC invocation... */
-    hghnum = msgnum = mp->hghmsg;
-    for (i = 0;;) {
-	if (msgnum >= mp->hghoff)
-	    if ((mp = m_remsg (mp, 0, mp->hghoff + MAXFOLDER)) == NULL) {
-		advise (NULL, "unable to allocate folder storage");
-		i = NOTOK;
-		break;
+    if (inc_type == INC_FILE) {
+	m_unknown (in);		/* the MAGIC invocation... */
+	hghnum = msgnum = mp->hghmsg;
+	for (i = 0;;) {
+	    if (msgnum >= mp->hghoff) {
+		if (!(mp = folder_realloc (mp, 0, mp->hghoff + MAXFOLDER))) {
+		    advise (NULL, "unable to allocate folder storage");
+		    i = NOTOK;
+		    break;
+		}
 	    }
 
-	switch (i = scan (in, msgnum + 1, msgnum + 1, nfs, width,
-		    msgnum == hghnum && chgflag,
-		    1,	/* check UNSEEN? */
-		    0,
-		    0L,
-		    noisy)) {
+#if 0
+	    /* copy file from spool to tmp file */
+	    tmpfilenam = m_scratch ("", invo_name);
+	    if ((fd = creat (tmpfilenam, m_gmprot ())) == NOTOK)
+		adios (tmpfilenam, "unable to create");
+	    chmod (tmpfilenam, m_gmprot ());
+	    if (!(in2 = fdopen (fd, "r+")))
+		adios (tmpfilenam, "unable to access");
+	    cpymsg (in, in2);
+
+	    /* link message into folder */
+	    newmsg = folder_addmsg(mp, tmpfilenam);
+#endif
+
+	    /* create scanline for new message */
+	    switch (i = scan (in, msgnum + 1, msgnum + 1, nfs, width,
+			      msgnum == hghnum && chgflag, 1, NULL, 0L, noisy)) {
 	    case SCNFAT:
 	    case SCNEOF: 
 		break;
@@ -752,83 +719,80 @@ go_to_it: ;
 
 		msgnum++;
 		mp->hghmsg++;
-		mp->msgstats[msgnum] = EXISTS;
-#ifdef TMA
-		if (i == SCNENC) {
-		    if (mp->lowsel == 0 || mp->lowsel > msgnum)
-			mp->lowsel = msgnum;
-		    if (mp->hghsel == 0 || mp->hghsel < msgnum)
-			mp->hghsel = msgnum;
-		    set_selected (mp, msgnum);
-		    mp->numsel++;
-		}
-#endif /* TMA */
+		clear_msg_flags (mp, msgnum);
+		set_exists (mp, msgnum);
 		set_unseen (mp, msgnum);
 		mp->msgflags |= SEQMOD;
 		continue;
+	    }
+	    break;
 	}
-	break;
     }
-#ifdef POP
-    }
-#endif /* POP */
 
-#ifndef	POP
-    if (i < 0) {		/* error } */
-#else
+#ifdef POP
     if (p < 0) {		/* error */
+#else
+    if (i < 0) {		/* error */
 #endif
-	if (locked)
+
+	if (locked) {
 #ifdef MAILGROUP
-	{
-	  setgid(return_gid);	/* Be sure we can unlock mail file */
-#endif	/* MAILGROUP */
+	    /* Be sure we can unlock mail file */
+	    setgid(return_gid);
+#endif /* MAILGROUP */
 
 	    lkfclose (in, newmail);
+
 #ifdef MAILGROUP
-	    setgid(getgid());	/* And then return us to normal privileges */
-	 }
-#endif	/* MAILGROUP */
-	else
+	    /* And then return us to normal privileges */
+	    setgid(getgid());
+#endif /* MAILGROUP */
+	} else {
 	    fclose (in);
+	}
 	adios (NULL, "failed");
     }
 
     if (aud)
 	fclose (aud);
+
 #ifdef MHE
     if (mhe)
 	fclose (mhe);
 #endif /* MHE */
+
     if (noisy)
 	fflush (stdout);
+
 #ifdef POP
-    if (host && packfile)
+    if ((inc_type == INC_POP) && packfile)
 	done (0);
 #endif /* POP */
 
-#ifdef POP
-    if (host == NULL)
-#endif /* POP */
-    if (trnflag) {
-	if (stat (newmail, &st) != NOTOK && s1.st_mtime != st.st_mtime)
-	    advise (NULL, "new messages have arrived!\007");
-	else {
-	    if ((i = creat (newmail, 0600)) != NOTOK)
-		close (i);
-	    else
-		admonish (newmail, "error zero'ing");
-	    unlink(map_name(newmail));
+    /*
+     * truncate file we are incorporating from
+     */
+    if (inc_type == INC_FILE) {
+	if (trnflag) {
+	    if (stat (newmail, &st) != NOTOK && s1.st_mtime != st.st_mtime)
+		advise (NULL, "new messages have arrived!\007");
+	    else {
+		if ((i = creat (newmail, 0600)) != NOTOK)
+		    close (i);
+		else
+		    admonish (newmail, "error zero'ing");
+		unlink(map_name(newmail));
+	    }
+	} else {
+	    if (noisy)
+		printf ("%s not zero'd\n", newmail);
 	}
-    } else {
-	if (noisy)
-	    printf ("%s not zero'd\n", newmail);
     }
 
     if (msgnum == hghnum) {
 	admonish (NULL, "no messages incorporated");
     } else {
-	m_replace (pfolder, folder);	/* update current folder */
+	context_replace (pfolder, folder);	/* update current folder */
 	if (chgflag)
 	    mp->curmsg = hghnum + 1;
 	mp->hghmsg = msgnum;
@@ -838,99 +802,63 @@ go_to_it: ;
 	    seq_setcur (mp, mp->curmsg);
     }
 
-#ifdef POP
-    if (host == NULL)
-#endif /* POP */
-    if (locked)
+    /*
+     * unlock the mail spool
+     */
+    if (inc_type == INC_FILE) {
+	if (locked) {
 #ifdef MAILGROUP
-    {
-      setgid(return_gid);	/* Be sure we can unlock mail file */
-#endif	/* MAILGROUP */
+	    setgid(return_gid);	/* Be sure we can unlock mail file */
+#endif /* MAILGROUP */
+
+	    lkfclose (in, newmail);
 
-        lkfclose (in, newmail);
 #ifdef MAILGROUP
-        setgid(getgid());	/* And then return us to normal privileges */
-     }
-#endif	/* MAILGROUP */
-    else
-	fclose (in);
+	    setgid(getgid());	/* And then return us to normal privileges */
+#endif /* MAILGROUP */
+	} else {
+	    fclose (in);
+	}
+    }
 
     seq_setunseen (mp, 0);	/* set the Unseen-Sequence */
-    seq_save (mp);
-    m_update ();		/* update the context file */
-
-#ifdef TMA
-    if (decflag && mp->numsel > 0) {
-	if (noisy) {
-	    printf ("\nIncorporating encrypted mail into %s...\n\n", folder);
-	    fflush (stdout);
-	}
-
-	tmastart (0);
-	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	    if (is_selected (mp, msgnum) && decipher (msgnum) == OK) {
-		if ((in = fopen (cp = m_name (msgnum), "r")) == NULL) {
-		    admonish (cp, "unable to open message");
-		    free (cp);
-		    continue;
-		}
-		switch (scan (in, msgnum, 0, nfs, width,
-			msgnum == mp->curmsg,
-			1,	/* check UNSEEN? */
-			0,
-			fstat (fileno (in), &st) != NOTOK ? (long) st.st_size
-			    : 0L,
-			noisy)) {
-		    case SCNEOF: 
-			printf ("%*d  empty\n", DMAXFOLDER, msgnum);
-			break;
-
-		    default: 
-			break;
-		}
-		fclose (in);
-		free (cp);
-	    }
-	tmastop ();
-
-	if (noisy)
-	    fflush (stdout);
-    }
-#endif	/* TMA */
-
+    seq_save (mp);		/* synchronize sequences   */
+    context_save ();		/* save the context file   */
     done (0);
 }
 
 
-#ifdef MF
-void
-get_uucp_mail (void)
+#if 0
+
+/*
+ * Copy message message from spool into
+ * temporary file.  Massage the "From " line
+ * while copying.
+ */
+
+cpymsg (FILE *in, FILE *out)
 {
-    pid_t child_id;
-    char buffer[BUFSIZ];
-    struct stat st;
+    int state;
+    char *tmpbuf, name[NAMESZ];
 
-    sprintf (buffer, "%s/%s", UUCPDIR, UUCPFIL);
-    if (stat (buffer, &st) == NOTOK || st.st_size == 0)
-	return;
-
-    switch (child_id = vfork()) {
-	case NOTOK: 
-	    admonish ("fork", "unable to");
+    for (;;) {
+	state = m_getfld (state, name, tmpbuf, rlwidth, in);
+	switch (state) {
+	case FLD:
+	case FLDPLUS:
 	    break;
-
-	case OK: 
-	    execlp (umincproc, r1bindex (umincproc, '/'), NULL);
-	    fprintf (stderr, "unable to exec ");
-	    perror (umincproc);
-	    _exit (-1);
-
-	default: 
-	    pidXwait(child_id, umincproc);
+	case BODY:
 	    break;
+	case LENERR:
+	case FMTERR:
+	    break;
+	case FILEEOF:
+	    break;
+	default:
+	}
     }
 }
-#endif	/* MF */
+#endif /* if 0 */
 
 
 #ifdef POP
@@ -943,7 +871,6 @@ done (int status)
     exit (status);
 }
 
-
 static int
 pop_action (char *s)
 {
@@ -951,14 +878,13 @@ pop_action (char *s)
     stop += strlen (s) + 1;
 }
 
-
 static int
 pop_pack (char *s)
 {
     int j;
     char buffer[BUFSIZ];
 
-    sprintf (buffer, "%s\n", s);
+    snprintf (buffer, BUFSIZ, "%s\n", s);
     for (j = 0; (j = stringdex (mmdlm1, buffer)) >= 0; buffer[j]++)
 	continue;
     for (j = 0; (j = stringdex (mmdlm2, buffer)) >= 0; buffer[j]++)
