@@ -59,7 +59,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -147,21 +147,26 @@ main (int argc, char **argv)
 	    listsw++;
     }
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
     if (!msgp)
 	msgs[msgp++] = listsw ? "all" :"cur";
     if (!folder)
-	folder = m_getfolder ();
+	folder = getfolder (1);
     maildir = m_maildir (folder);
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
+    /* print some general debugging info */
+    if (debugsw)
+	print_debug(mp);
+
+    /* no messages in folder */
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
 
@@ -170,16 +175,8 @@ main (int argc, char **argv)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
 
-    if (publicsw == -1)
-	publicsw = (mp->msgflags & READONLY) ? 0 : 1;
-    if (publicsw && (mp->msgflags & READONLY))
-	adios (NULL, "folder %s is read-only, so -public not allowed",
-		folder);
-
-    /* print some general debugging info */
-    if (debugsw) {
-	print_debug(mp);
-    }
+    if (publicsw == 1 && is_readonly(mp))
+	adios (NULL, "folder %s is read-only, so -public not allowed", folder);
 
     /*
      * Make sure at least one sequence has been
@@ -214,15 +211,14 @@ main (int argc, char **argv)
 	}
 
 	/* print debugging info about SELECTED messages */
-	if (debugsw) {
+	if (debugsw)
 	    seq_printdebug (mp);
-	}
     }
 
-    m_replace (pfolder, folder);	/* update current folder         */
     seq_save (mp);			/* synchronize message sequences */
-    m_freefolder (mp);			/* free folder/message structure */
-    m_update ();			/* update the context file       */
+    context_replace (pfolder, folder);	/* update current folder         */
+    context_save ();			/* save the context file         */
+    folder_free (mp);			/* free folder/message structure */
     done (0);
 }
 
@@ -250,7 +246,14 @@ seq_printall (struct msgs *mp)
 static void
 seq_print (struct msgs *mp, char *seqname)
 {
-    printf ("%s: %s\n", seqname, empty(seq_list(mp, seqname)));
+    int i;
+
+    /* get the index of sequence */
+    i = seq_getnum (mp, seqname);
+
+    printf ("%s%s: %s\n", seqname,
+	(i == -1) ? "" : is_seq_private(mp, i) ? " (private)" : "",
+	empty(seq_list(mp, seqname)));
 }
 
 
@@ -266,19 +269,14 @@ print_debug (struct msgs *mp)
     printf ("mypath        = %s\n", mypath);
     printf ("defpath       = %s\n", defpath);
     printf ("ctxpath       = %s\n", ctxpath);
-    printf ("context flags = %s\n", sprintb (buf, (unsigned) ctxflags, DBITS));
+    printf ("context flags = %s\n", snprintb (buf, 100, (unsigned) ctxflags, DBITS));
     printf ("foldpath      = %s\n", mp->foldpath);
-    printf ("folder flags  = %s\n\n", sprintb(buf, (unsigned) mp->msgflags, FBITS));
+    printf ("folder flags  = %s\n\n", snprintb(buf, 100, (unsigned) mp->msgflags, FBITS));
     printf ("lowmsg=%d hghmsg=%d nummsg=%d curmsg=%d\n",
 	mp->lowmsg, mp->hghmsg, mp->nummsg, mp->curmsg);
     printf ("lowsel=%d hghsel=%d numsel=%d\n",
 	mp->lowsel, mp->hghsel, mp->numsel);
-#ifndef	MTR
-    printf ("lowoff=%d hghoff=%d\n", mp->lowoff, mp->hghoff);
-#else
-    printf ("lowoff=%d hghoff=%d msgbase=0x%x msgstats=0x%x\n",
-	mp->lowoff, mp->hghoff, mp->msgbase, mp->msgstats);
-#endif
+    printf ("lowoff=%d hghoff=%d\n\n", mp->lowoff, mp->hghoff);
 }
 
 
@@ -295,7 +293,7 @@ seq_printdebug (struct msgs *mp)
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
 	if (is_selected (mp, msgnum))
 	    printf ("%*d: %s\n", DMAXFOLDER, msgnum,
-		sprintb (buf, (unsigned) mp->msgstats[msgnum],
+		snprintb (buf, 100, (unsigned) mp->msgstats[msgnum],
 		seq_bits (mp)));
     }
 }
