@@ -299,7 +299,7 @@ mhl (int argc, char **argv)
     invo_name = r1bindex (argv[0], '/');
     if ((cp = getenv ("MHLDEBUG")) && *cp)
 	mhldebug++;
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -584,12 +584,12 @@ mhl_format (char *file, int length, int width)
 	    fprintf (stderr, "c1: name=\"%s\" text=\"%s\" ovtxt=\"%s\"\n",
 		    c1->c_name, c1->c_text, c1->c_ovtxt);
 	    fprintf (stderr, "\tnfs=0x%x fmt=0x%x\n",
-		    c1->c_nfs, c1->c_fmt);
+		    (unsigned int) c1->c_nfs, (unsigned int) c1->c_fmt);
 	    fprintf (stderr, "\toffset=%d ovoff=%d width=%d cwidth=%d length=%d\n",
 		    c1->c_offset, c1->c_ovoff, c1->c_width,
 		    c1->c_cwidth, c1->c_length);
 	    fprintf (stderr, "\tflags=%s\n",
-		    sprintb (buffer, (unsigned) c1->c_flags, LBITS));
+		    snprintb (buffer, BUFSIZ, (unsigned) c1->c_flags, LBITS));
 	}
 
 out: ;
@@ -720,7 +720,7 @@ parse (void)
     register char *cp;
     static char result[NAMESZ];
 
-    for (cp = result; c = *parptr; parptr++)
+    for (cp = result; c = *parptr; parptr++) {
 	if (isalnum (c)
 		|| c == '.'
 		|| c == '-'
@@ -730,7 +730,8 @@ parse (void)
 	    *cp++ = c;
 	else
 	    break;
-    *cp = 0;
+    }
+    *cp = '\0';
 
     return result;
 }
