@@ -52,7 +52,10 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    m_foil (NULL);	/* foil search of user profile */
+
+    /* foil search of user profile/context */
+    if (context_foil (NULL) == -1)
+	done (1);
 
     /* If no arguments, just incorporate new mail */
     if (argc == 1) {
