@@ -37,6 +37,7 @@ struct proc {
 
 static struct proc procs [] = {
      { "context",       &context },
+     { "mh-sequences",  &mh_seq },
      { "buildmimeproc", &buildmimeproc },
      { "faceproc",      &faceproc },
      { "fileproc",      &fileproc },
@@ -56,7 +57,6 @@ static struct proc procs [] = {
      { "sendproc",      &sendproc },
      { "showmimeproc",  &showmimeproc },
      { "showproc",      &showproc },
-     { "slocalproc",    &slocalproc },
      { "version",       &version },
      { "vmhproc",       &vmhproc },
      { "whatnowproc",   &whatnowproc },
@@ -84,7 +84,7 @@ main(int argc, char **argv)
     char *arguments[MAXARGS], *comps[MAXARGS];
 
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     }
@@ -135,8 +135,9 @@ main(int argc, char **argv)
 	if (components >= 0)
 	    advise(NULL, "-%scomponents ignored with -all",
 		   components ? "" : "no");
-      
-	m_getdefs ();
+
+	/* print all entries in context/profile list */
+	context_read();
 	for (np = m_defs; np; np = np->n_next)
 	    printf("%s:\t%s\n", np->n_name, np->n_field);
     } else {
@@ -144,11 +145,11 @@ main(int argc, char **argv)
 	    components = compp > 1;
 
 	for (i = 0; i < compp; i++)  {
-	    register char *value = m_find(comps[i]);
+	    register char *value;
 
+	    value = context_find (comps[i]);
 	    if (!value)
-		value = p_find(comps[i]);
-
+		value = p_find (comps[i]);
 	    if (value) {
 	        if (components)
 		    printf("%s:\t", comps[i]);
