@@ -35,7 +35,7 @@ main(int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -82,11 +82,11 @@ main(int argc, char **argv)
 	}
     }
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
 
     if (!folder)
-	folder = m_getfolder ();
+	folder = getfolder (1);
     maildir = m_maildir (folder);
 
     /* If no messages are given, print folder pathname */
@@ -99,10 +99,15 @@ main(int argc, char **argv)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
-    if ((mp = m_remsg (mp, 0, MAXFOLDER)) == NULL)
+    /*
+     * We need to make sure there is message space for "new".
+     * If not, then go ahead and add space for another 100 messages.
+     */
+    if ((mp->hghmsg >= mp->hghoff) &&
+	!(mp = folder_realloc (mp, 0, mp->hghmsg + 100)))
 	adios (NULL, "unable to allocate folder storage");
 
     mp->msgflags |= MHPATH;
@@ -120,7 +125,7 @@ main(int argc, char **argv)
 	    printf ("%s/%s\n", mp->foldpath, m_name (i));
 
     seq_save (mp);	/* synchronize message sequences */
-    m_freefolder (mp);	/* free folder/message structure */
-    m_update ();	/* update the context file       */
+    context_save ();	/* save the context file         */
+    folder_free (mp);	/* free folder/message structure */
     done (0);
 }
