@@ -120,7 +120,7 @@ main (int argc, char **argv)
 	snoop++;
 #endif
 
-    if ((cp = m_find (invo_name))) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -139,7 +139,7 @@ main (int argc, char **argv)
 		    adios (NULL, "-%s unknown", cp);
 
 		case HELPSW: 
-		    sprintf (buf, "%s [switches] [users ...]", invo_name);
+		    snprintf (buf, 80, "%s [switches] [users ...]", invo_name);
 		    print_help (buf, switches);
 		    done (1);
 		case VERSIONSW:
@@ -292,10 +292,6 @@ donote (char *cp, int ntflag)
 }
 
 
-#ifdef MF
-/* ARGSUSED */
-#endif	/* MF */
-
 static int
 checkmail (char *user, char *home, int datesw, int notifysw, int personal)
 {
@@ -303,25 +299,14 @@ checkmail (char *user, char *home, int datesw, int notifysw, int personal)
     char buffer[BUFSIZ];
     struct stat st;
 
-    sprintf (buffer, "%s/%s", mmdfldir[0] ? mmdfldir : home, mmdflfil[0] ? mmdflfil : user);
-#ifndef	MF
+    snprintf (buffer, BUFSIZ, "%s/%s", mmdfldir[0] ? mmdfldir : home, mmdflfil[0] ? mmdflfil : user);
     if (datesw) {
 	st.st_size = 0;
 	st.st_atime = st.st_mtime = 0;
     }
-#endif	/* MF */
     mf = (stat (buffer, &st) == NOTOK || st.st_size == 0) ? NONEOK
 	: st.st_atime <= st.st_mtime ? MMDFNEW : MMDFOLD;
 
-#ifdef MF
-    if (umincproc != NULL && *umincproc != NULL) {
-	sprintf (buffer, "%s/%s", uucpldir[0] ? uucpldir : home,
-		uucplfil[0] ? uucplfil : user);
-	mf |= (stat (buffer, &st) == NOTOK || st.st_size == 0) ? NONEOK
-	    : st.st_atime <= st.st_mtime ? UUCPNEW : UUCPOLD;
-    }
-#endif /* MF */
-
     if ((mf & UUCPOK) || (mf & MMDFOK)) {
 	if (notifysw & NT_MAIL) {
 	    printf (personal ? "You have " : "%s has ", user);
@@ -348,11 +333,9 @@ checkmail (char *user, char *home, int datesw, int notifysw, int personal)
 	status = 1;
     }
 
-#ifndef	MF
     if (notifysw)
 	if (datesw && st.st_atime)
 	    printf ("; last read on %s", dtime (&st.st_atime, 1));
-#endif	/* MF */
     if (notifysw)
 	printf ("\n");
 
@@ -377,12 +360,14 @@ remotemail (char *host, char *user, int rpop, int notifysw, int personal, int sn
 	ruserpass (host, &user, &pass);
 
 #if defined(RPOP) || defined(APOP)
+    /* open the POP connection */
     if (pop_init (host, user, pass, snoop, rpop) == NOTOK
 #else
+    /* open the POP connection */
     if (pop_init (host, user, pass, snoop) == NOTOK
 #endif
-	    || pop_stat (&nmsgs, &nbytes) == NOTOK
-	    || pop_quit () == NOTOK) {
+	    || pop_stat (&nmsgs, &nbytes) == NOTOK	/* check for messages  */
+	    || pop_quit () == NOTOK) {			/* quit POP connection */
 	advise (NULL, "%s", response);
 	return 1;
     }
