@@ -179,7 +179,7 @@ int sc_width (void);         /* from termsbr.c */
 void fsetup (char *);
 void setup (char *);
 FILE *msh_ready (int, int);
-int readids (int);
+void readids (int);
 int readid (int);
 void display_info (int);
 int expand (char *);
@@ -217,7 +217,7 @@ static int parse (char *, struct Cmd *);
 static int init_io (struct Cmd *, int);
 static int initaux_io (struct Cmd *);
 static void fin_io (struct Cmd *, int);
-static int finaux_io (struct Cmd *);
+static void finaux_io (struct Cmd *);
 static void m_init (void);
 static RETSIGTYPE intrser (int);
 static RETSIGTYPE pipeser (int);
@@ -253,7 +253,7 @@ main (int argc, char **argv)
 #endif
     invo_name = r1bindex (argv[0], '/');
     mts_init (invo_name);
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     }
@@ -382,7 +382,7 @@ main (int argc, char **argv)
 
     sc_width ();		/* MAGIC... */
 
-    if (vmh = vmh1 && vmh2) {
+    if ((vmh = vmh1 && vmh2)) {
 	rcinit (vmh1, vmh2);
 	pINI ();
 	SIGNAL (SIGINT, SIG_IGN);
@@ -541,7 +541,7 @@ msh (int scansw)
 	    case SHOWCMD: 
 	    case SCANCMD: 
 	    case SORTCMD: 
-		if ((cp = m_find (cmd_name)) != NULL) {
+		if ((cp = context_find (cmd_name)) != NULL) {
 		    ap = brkstring (cp = getcpy (cp), " ", "\n");
 		    ap = copyip (ap, vec);
 		}
@@ -695,7 +695,7 @@ fsetup (char *folder)
     maildir = m_maildir (folder);
     if (chdir (maildir) == NOTOK)
 	padios (maildir, "unable to change directory to");
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	padios (NULL, "unable to read folder %s", folder);
     if (mp->hghmsg == 0)
 	padios (NULL, "no messages in %s", folder);
@@ -758,40 +758,33 @@ setup (char *file)
     if ((msgp = read_file (msgp ? Msgs[msgp].m_stop : 0L, msgp + 1)) < 1)
 	padios (NULL, "no messages in %s", myname ? myname : file);
 
-    mp = (struct msgs  *) calloc ((size_t) 1, MHSIZE (mp, 1, msgp + 1));
-    if (mp == NULL)
+    if (!(mp = (struct msgs  *) calloc ((size_t) 1, sizeof(*mp))))
 	padios (NULL, "unable to allocate folder storage");
+    if (!(mp->msgstats = calloc ((size_t) 1, msgp + 3)))
+	padios (NULL, "unable to allocate message status storage");
 
     mp->hghmsg = msgp;
     mp->nummsg = msgp;
     mp->lowmsg = 1;
     mp->curmsg = 0;
-
     mp->foldpath = getcpy (myname ? myname : file);
-    mp->msgflags = 0;
+    clear_folder_flags (mp);
+
 #ifdef BPOP
     if (pmsh)
-	mp->msgflags |= READONLY;
+	set_readonly (mp);
     else {
 #endif /* BPOP */
 	stat (file, &st);
 	if (st.st_uid != getuid () || access (file, W_OK) == NOTOK)
-	    mp->msgflags |= READONLY;
+	    set_readonly (mp);
 #ifdef BPOP
     }
 #endif	/* BPOP */
+
     mp->lowoff = 1;
     mp->hghoff = mp->hghmsg + 1;
 
-#ifdef MTR
-    mp->msgstats = (short *)
-		calloc ((size_t) 1, MHSIZEX (mp, mp->lowmsg, mp->hghmsg));
-    if (mp->msgstats == NULL)
-	padios (NULL, "unable to allocate messages storage");
-    mp->msgstats = (mp->msgbase = mp->msgstats) - mp->lowoff;
-    if (mp->msgstats < (short *)0)
-	padios (NULL, "setup() botch -- you lose big");
-#endif /* MTR */
 #ifdef BPOP
     if (pmsh) {
 #ifndef	NNTP
@@ -958,8 +951,11 @@ msh_ready (int msgnum, int full)
 {
     register int msgp;
     int fd;
+    char *cp;
+#ifdef BPOP
+    char tmpfil[BUFSIZ];
     long pos1, pos2;
-    char *cp, tmpfil[BUFSIZ];
+#endif
 
     if (yp) {
 	fclose (yp);
@@ -1060,9 +1056,9 @@ check_folder (int scansw)
 	mtime = st.st_mtime;
 
 	low = mp->hghmsg + 1;
-	m_freefolder (mp);		/* free folder/message info */
+	folder_free (mp);		/* free folder/message structure */
 
-	if (!(mp = m_readfolder (fmsh)))
+	if (!(mp = folder_read (fmsh)))
 	    padios (NULL, "unable to re-read folder %s", fmsh);
 
 	hgh = mp->hghmsg;
@@ -1100,7 +1096,7 @@ check_folder (int scansw)
     if (msgp <= mp->hghmsg)
 	return 0;		/* XXX */
 
-    if ((mp = m_remsg (mp, 0, msgp)) == NULL)
+    if (!(mp = folder_realloc (mp, 0, msgp)))
 	padios (NULL, "unable to allocate folder storage");
 
     low = mp->hghmsg + 1, hgh = msgp;
@@ -1141,7 +1137,7 @@ scanstring (char *arg)
 {
     char *cp, **ap, *vec[MAXARGS];
 
-    if ((cp = m_find (cmd_name = "scan")) != NULL) {
+    if ((cp = context_find (cmd_name = "scan")) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, vec);
     }
@@ -1156,7 +1152,7 @@ scanstring (char *arg)
 }
 
 
-int
+void
 readids (int id)
 {
     register int cur, seqnum, i, msgnum;
@@ -1326,7 +1322,7 @@ quit (void)
     struct stat st;
     FILE *dp;
 
-    if (!(mp->msgflags & MODIFIED) || mp->msgflags & READONLY || fmsh) {
+    if (!(mp->msgflags & MODIFIED) || is_readonly(mp) || fmsh) {
 	    if (vmh)
 		rc2peer (RC_FIN, 0, NULL);
 	return;
@@ -1375,8 +1371,7 @@ quit (void)
     }
 
     for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++)
-	if (mp->msgstats[msgnum] & EXISTS
-		&& pack (tmpfil, md, msgnum) == NOTOK) {
+	if (does_exist(mp, msgnum) && pack (tmpfil, md, msgnum) == NOTOK) {
 	    mbx_close (tmpfil, md);
 	    unlink (tmpfil);
 	    unlink (map_name (tmpfil));
@@ -1446,7 +1441,7 @@ getargs (char *prompt, struct swit *sw, struct Cmd *cmdp)
 	for (cp = buffer; (i = getchar ()) != '\n';) {
 #ifndef BSD42
 	    if (interrupted && !told_to_quit) {
-		buffer[0] = NULL;
+		buffer[0] = '\0';
 		putchar ('\n');
 		break;
 	    }
@@ -1559,7 +1554,7 @@ parse (char *buffer, struct Cmd *cmdp)
 	return NOTOK;
     }
 
-    while (c = *cp++) {
+    while ((c = *cp++)) {
 	if (isspace (c)) {
 	    while (isspace (c))
 		c = *cp++;
@@ -1656,12 +1651,12 @@ expand (char *redirect)
     if (*redirect != '~')
 	return OK;
 
-    if (cp = strchr(pp = redirect + 1, '/'))
+    if ((cp = strchr(pp = redirect + 1, '/')))
 	*cp++ = 0;
     if (*pp == 0)
 	pp = mypath;
     else
-	if (pw = getpwnam (pp))
+	if ((pw = getpwnam (pp)))
 	    pp = pw->pw_dir;
 	else {
 	    padvise (NULL, "unknown user: %s", pp);
@@ -1743,7 +1738,7 @@ fin_io (struct Cmd *cmdp, int vio)
 }
 
 
-static int
+static void
 finaux_io (struct Cmd *cmdp)
 {
     switch (cmdp->direction) {
@@ -1793,7 +1788,7 @@ void
 m_reset (void)
 {
     write_ids ();
-    m_freefolder (mp);	/* free folder/message info */
+    folder_free (mp);	/* free folder/message structure */
     myname = NULL;
 #ifdef	BPOP
     if (pmsh) {
@@ -2065,7 +2060,7 @@ pQRY2 (void)
     i = 0;
     j = (k = windows[SCAN]) / 2;
     for (msgnum = mp->curmsg; msgnum <= mp->hghmsg; msgnum++)
-	if (mp->msgstats[msgnum] & EXISTS)
+	if (does_exist (mp, msgnum))
 	    i++;
     if (i-- > 0)
 	if (topcur)
@@ -2076,7 +2071,7 @@ pQRY2 (void)
     i = j = 0;
     n = 1;
     for (msgnum = mp->curmsg; msgnum >= mp->lowmsg; msgnum--)
-	if (mp->msgstats[msgnum] & EXISTS) {
+	if (does_exist (mp, msgnum)) {
 	    i = msgnum;
 	    if (j == 0)
 		j = msgnum;
@@ -2084,7 +2079,7 @@ pQRY2 (void)
 		break;
 	}
     for (msgnum = mp->curmsg + 1; msgnum <= mp->hghmsg; msgnum++)
-	if (mp->msgstats[msgnum] & EXISTS) {
+	if (does_exist (mp, msgnum)) {
 	    if (i == 0)
 		i = msgnum;
 	    j = msgnum;
@@ -2094,8 +2089,8 @@ pQRY2 (void)
     if (!topcur
 	    && lo > 0
 	    && hi > 0
-	    && mp->msgstats[lo] & EXISTS
-	    && mp->msgstats[hi] & EXISTS
+	    && does_exist (mp, lo)
+	    && does_exist (mp, hi)
 	    && (lo < mp->curmsg
 		    || (lo == mp->curmsg && lo == mp->lowmsg))
 	    && (mp->curmsg < hi
