@@ -80,10 +80,10 @@ forkcmd (char **args, char *pgm)
     copyip (args, vec + 1);
 
     if (fmsh) {
-	m_delete (pfolder);
-	m_replace (pfolder, fmsh);	/* update current folder   */
+	context_del (pfolder);
+	context_replace (pfolder, fmsh);/* update current folder   */
 	seq_save (mp);
-	m_update ();			/* update the context file */
+	context_save ();		/* save the context file   */
     }
     fflush (stdout);
     switch (child_id = fork ()) {
@@ -155,7 +155,7 @@ distcmd (char **args)
 	return;
     }
 
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, distswit)) {
 		case AMBIGSW: 
@@ -257,7 +257,7 @@ explcmd (char **args)
 	return;
     }
 
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, explswit)) {
 		case AMBIGSW: 
@@ -337,7 +337,7 @@ burst (struct Msg *smsgs, int msgnum, int inplace, int quietsw, int verbosw)
 {
     int i, j, ld3, wasdlm, msgp;
     long pos;
-    char c, cc, buffer[BUFSIZ];
+    char c, buffer[BUFSIZ];
     register FILE *zp;
 
     ld3 = strlen (delim3);
@@ -400,7 +400,7 @@ burst (struct Msg *smsgs, int msgnum, int inplace, int quietsw, int verbosw)
 	advise (NULL, "more than %d messages", MAXFOLDER);
 	return NOTOK;
     }
-    if ((mp = m_remsg (mp, 0, i)) == NULL)
+    if (!(mp = folder_realloc (mp, 0, i)))
 	adios (NULL, "unable to allocate folder storage");
 
     j = mp->hghmsg;
@@ -486,7 +486,7 @@ filecmd (char **args)
 	return;
     }
 
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-')
 	    switch (i = smatch (++cp, fileswit)) {
 		case AMBIGSW: 
@@ -558,7 +558,7 @@ filehak (char **args)
     int	result, vecp = 0;
     char *cp, *cwd, *vec[MAXARGS];
 
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, fileswit)) {
 		case AMBIGSW: 
@@ -648,7 +648,7 @@ foldcmd (char **args)
     if (args == NULL)
 	goto fast;
 
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, foldswit)) {
 		case AMBIGSW: 
@@ -758,10 +758,10 @@ foldcmd (char **args)
 	    return;
 	}
 
-	if (mp->lowmsg > 1 && (mp = m_remsg (mp, 1, mp->hghmsg)) == NULL)
+	if (mp->lowmsg > 1 && !(mp = folder_realloc (mp, 1, mp->hghmsg)))
 	    adios (NULL, "unable to allocate folder storage");
 	for (msgnum = mp->lowmsg, hole = 1; msgnum <= mp->hghmsg; msgnum++)
-	    if (mp->msgstats[msgnum] & EXISTS) {
+	    if (does_exist (mp, msgnum)) {
 		if (msgnum != hole) {
 		    Msgs[hole].m_bboard_id = Msgs[msgnum].m_bboard_id;
 		    Msgs[hole].m_top = Msgs[msgnum].m_top;
@@ -870,7 +870,7 @@ forwcmd (char **args)
 	return;
     }
 
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, forwswit)) {
 		case AMBIGSW: 
@@ -1128,7 +1128,7 @@ markcmd (char **args)
     char *cp, buf[BUFSIZ];
     char *seqs[NUMATTRS + 1], *msgs[MAXARGS];
 
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, markswit)) {
 		case AMBIGSW: 
@@ -1215,21 +1215,15 @@ markcmd (char **args)
 	printf ("invo_name=%s mypath=%s defpath=%s\n",
 		invo_name, mypath, defpath);
 	printf ("ctxpath=%s context flags=%s\n",
-		ctxpath, sprintb (buf, (unsigned) ctxflags, DBITS));
+		ctxpath, snprintb (buf, BUFSIZ, (unsigned) ctxflags, DBITS));
 	printf ("foldpath=%s flags=%s\n",
 		mp->foldpath,
-		sprintb (buf, (unsigned) mp->msgflags, FBITS));
+		snprintb (buf, BUFSIZ, (unsigned) mp->msgflags, FBITS));
 	printf ("hghmsg=%d lowmsg=%d nummsg=%d curmsg=%d\n",
 		mp->hghmsg, mp->lowmsg, mp->nummsg, mp->curmsg);
 	printf ("lowsel=%d hghsel=%d numsel=%d\n",
 		mp->lowsel, mp->hghsel, mp->numsel);
-#ifndef	MTR
-	printf ("lowoff=%d hghoff=%d\n",
-		mp->lowoff, mp->hghoff);
-#else	/* MTR */
-	printf ("lowoff=%d hghoff=%d msgbase=0x%x msgstats=0x%x\n",
-		mp->lowoff, mp->hghoff, mp->msgbase, mp->msgstats);
-#endif	/* MTR */
+	printf ("lowoff=%d hghoff=%d\n", mp->lowoff, mp->hghoff);
     }
 
     if (seqp == 0 && (addsw || deletesw)) {
@@ -1261,7 +1255,7 @@ markcmd (char **args)
 			empty(seq_list(mp, mp->msgattrs[i])));
 	} else {
 	    for (seqp = 0; seqs[seqp]; seqp++)
-		printf ("%s%s: %s\n", seqs[seqp], empty(seq_list(mp, seqs[seqp])));
+		printf ("%s: %s\n", seqs[seqp], empty(seq_list(mp, seqs[seqp])));
 	}
 
 #undef empty
@@ -1276,7 +1270,7 @@ markcmd (char **args)
 			    DMAXFOLDER, msgnum,
 			    Msgs[msgnum].m_bboard_id, Msgs[msgnum].m_top,
 			    Msgs[msgnum].m_start, Msgs[msgnum].m_stop,
-			    sprintb (buf, (unsigned) mp->msgstats[msgnum],
+			    snprintb (buf, BUFSIZ, (unsigned) mp->msgstats[msgnum],
 				seq_bits (mp)));
 		    if (Msgs[msgnum].m_scanl)
 			printf ("%s", Msgs[msgnum].m_scanl);
@@ -1353,7 +1347,7 @@ void
 mhncmd (char **args)
 {
     int msgp = 0, vecp = 1;
-    int i, msgnum;
+    int msgnum;
     char *cp, buf[BUFSIZ];
     char *msgs[MAXARGS], *vec[MAXARGS];
 
@@ -1362,7 +1356,7 @@ mhncmd (char **args)
 	return;
     }
 
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, mhnswit)) {
 		case AMBIGSW: 
@@ -1471,7 +1465,7 @@ packcmd (char **args)
 	return;
     }
 
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, packswit)) {
 		case AMBIGSW: 
@@ -1559,7 +1553,7 @@ packhak (char **args)
     int	result;
     char *cp, *file = NULL;
 
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, packswit)) {
 		case AMBIGSW: 
@@ -1644,7 +1638,7 @@ pickcmd (char **args)
     char *seqs[NUMATTRS], *vec[MAXARGS];
     register FILE *zp;
 
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-') {
 	    if (*++cp == '-') {
 		vec[vecp++] = --cp;
@@ -1834,7 +1828,7 @@ replcmd (char **args)
 	return;
     }
 
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, replswit)) {
 		case AMBIGSW: 
@@ -1924,7 +1918,7 @@ rmmcmd (char **args)
     int	msgp = 0, msgnum;
     char *cp, buf[BUFSIZ], *msgs[MAXARGS];
 
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, rmmswit)) {
 		case AMBIGSW: 
@@ -2010,13 +2004,13 @@ rmm (void)
     }
     if (mp->lowsel == mp->lowmsg) {
 	for (msgnum = mp->lowmsg + 1; msgnum <= mp->hghmsg; msgnum++)
-	    if (mp->msgstats[msgnum] & EXISTS)
+	    if (does_exist (mp, msgnum))
 		break;
 	mp->lowmsg = msgnum;
     }
     if (mp->hghsel == mp->hghmsg) {
 	for (msgnum = mp->hghmsg - 1; msgnum >= mp->lowmsg; msgnum--)
-	    if (mp->msgstats[msgnum] & EXISTS)
+	    if (does_exist (mp, msgnum))
 		break;
 	mp->hghmsg = msgnum;
     }
@@ -2065,7 +2059,7 @@ scancmd (char **args)
     static int s_optim = 0;
     static char *s_form = NULL, *s_format = NULL;
 
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, scanswit)) {
 		case AMBIGSW: 
@@ -2242,7 +2236,7 @@ scancmd (char **args)
 		switch (state = scan (zp, msgnum, 0, nfs, width,
 			msgnum == mp->curmsg,
 			is_unseen (mp, msgnum),
-			headersw ? (fmsh ? fmsh : mp->foldpath) : (char *)0,
+			headersw ? (fmsh ? fmsh : mp->foldpath) : NULL,
 			fmsh ? 0L : (long) (Msgs[msgnum].m_stop - Msgs[msgnum].m_start),
 			1)) {
 		    case SCNMSG:
@@ -2309,7 +2303,7 @@ showcmd (char **args)
     else
 	if (uleq (cmd_name, "prev"))
 	    mode = -1;
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-')
 	    switch (i = smatch (++cp, showswit)) {
 		case AMBIGSW: 
@@ -2479,7 +2473,7 @@ mhl_action (char *name)
 
     if ((msgnum = m_atoi (name)) < mp->lowmsg
 	    || msgnum > mp->hghmsg
-	    || !(mp->msgstats[msgnum] & EXISTS))
+	    || !does_exist (mp, msgnum))
 	return NULL;
     mhlnum = msgnum;
 
@@ -2614,16 +2608,17 @@ invalid: ;
 		    }
 		    for (dp = bp; istoken (*dp); dp++)
 			continue;
-		    c = *dp, *dp = NULL;
-		    if (*bp == NULL)
+		    c = *dp;
+		    *dp = '\0';
+		    if (!*bp)
 			goto invalid;
 		    if (passno > 1) {
-			if (result = !uleq (bp, "plain"))
+			if ((result = !uleq (bp, "plain")))
 			    goto out;
 			*dp = c;
 			for (dp++; isspace (*dp); dp++)
 			    continue;
-			if (result = !uprf (dp, "charset"))
+			if ((result = !uprf (dp, "charset")))
 			    goto out;
 			dp += sizeof "charset" - 1;
 			while (isspace (*dp))
@@ -2633,13 +2628,13 @@ invalid: ;
 			while (isspace (*dp))
 			    dp++;
 			if (*dp == '"') {
-			    if (bp = strchr(++dp, '"'))
-				*bp = NULL;
+			    if ((bp = strchr(++dp, '"')))
+				*bp = '\0';
 			}
 			else
 			    for (bp = dp; *bp; bp++)
 				if (isspace (*bp)) {
-				    *bp = NULL;
+				    *bp = '\0';
 				    break;
 				}
 			if ((result = !uleq (dp, chset))
@@ -2674,7 +2669,7 @@ out: ;
 			continue;
 		    for (dp = bp; istoken (*dp); dp++)
 			continue;
-		    *dp = NULL;
+		    *dp = '\0';
 		    result = !uleq (bp, "7bit")
 				&& !uleq (bp, "8bit")
 				&& !uleq (bp, "binary");
@@ -2687,7 +2682,7 @@ out: ;
 		    break;
 		}
 		while (state == FLDPLUS)
-		    state = m_getfld (state, name, buf, sizeof buf, fp);
+		    state = m_getfld (state, name, buf, sizeof(buf), fp);
 		break;
 
 	    default:
@@ -2724,14 +2719,14 @@ sortcmd (char **args)
     int msgp = 0, msgnum;
     char *cp, *datesw = NULL, *subjsw = NULL;
     char buf[BUFSIZ], *msgs[MAXARGS];
-    struct tws tb, *tw;
+    struct tws tb;
 
     if (fmsh) {
 	forkcmd (args, cmd_name);
 	return;
     }
 
-    while (cp = *args++) {
+    while ((cp = *args++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, sortswit)) {
 		case AMBIGSW: 
@@ -2931,7 +2926,7 @@ subsort (struct Msg *a, struct Msg *b)
 	register int i;
 
 	if (a->m_scanl && b->m_scanl)
-	    if (i = strcmp (a->m_scanl, b->m_scanl))
+	    if ((i = strcmp (a->m_scanl, b->m_scanl)))
 		return (i);
 
 	return twsort (&a->m_tb, &b->m_tb);
@@ -2951,7 +2946,7 @@ sosmash (char *subj, char *s)
 	cp = s;
 	dp = s;	/* dst pointer */
 	if (uleq (subj, "subject"))
-	    while (c = *cp) {
+	    while ((c = *cp)) {
 		if (! isspace(c)) {
 		    if(uprf(cp, "re:"))
 			cp += 2;
@@ -2963,7 +2958,7 @@ sosmash (char *subj, char *s)
 		}
 		cp++;
 	    }
-	while (c = *cp++) {
+	while ((c = *cp++)) {
 	    if (isalnum(c))
 		*dp++ = isupper(c) ? tolower(c) : c;
 
@@ -2983,10 +2978,10 @@ process (int msgnum, char *proc, int vecp, char **vec)
 
     if (fmsh) {
 	strcpy (tmpfil, m_name (msgnum));
-	m_delete (pfolder);
-	m_replace (pfolder, fmsh);	/* update current folder   */
+	context_del (pfolder);
+	context_replace (pfolder, fmsh);/* update current folder   */
 	seq_save (mp);
-	m_update ();			/* update the context file */
+	context_save ();		/* save the context file   */
 	goto ready;
     }
 
