@@ -78,7 +78,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -175,19 +175,19 @@ main (int argc, char **argv)
     }
     vec[vecp] = NULL;
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
     if (!msgp)
 	msgs[msgp++] = "all";
     if (!folder)
-	folder = m_getfolder ();
+	folder = getfolder (1);
     maildir = m_maildir (folder);
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -201,11 +201,8 @@ main (int argc, char **argv)
 
     if (seqp == 0)
 	listsw++;
-    if (publicsw == -1)
-	publicsw = mp->msgflags & READONLY ? 0 : 1;
-    if (publicsw && (mp->msgflags & READONLY))
-	adios (NULL, "folder %s is read-only, so -public not allowed",
-		folder);
+    if (publicsw == 1 && is_readonly(mp))
+	adios (NULL, "folder %s is read-only, so -public not allowed", folder);
 
     if (!pcompile (vec, NULL))
 	done (1);
@@ -257,10 +254,10 @@ main (int argc, char **argv)
 	printf ("%d hit%s\n", mp->numsel, mp->numsel == 1 ? "" : "s");
     }
 
-    m_replace (pfolder, folder);	/* update current folder         */
+    context_replace (pfolder, folder);	/* update current folder         */
     seq_save (mp);			/* synchronize message sequences */
-    m_freefolder (mp);			/* free folder/message structure */
-    m_update ();			/* update the context file       */
+    context_save ();			/* save the context file         */
+    folder_free (mp);			/* free folder/message structure */
     done (0);
 }
 
