@@ -29,7 +29,7 @@
 # define BPOPminc(a)  0
 #endif
 
-#ifndef	SMTP
+#ifndef	SMTPMTS
 # define BULKminc(a) (a)
 #else
 # define BULKminc(a)  0
@@ -101,7 +101,7 @@ main (int argc, char **argv)
 	host = pophost;
     if ((cp = getenv ("MHPOPDEBUG")) && *cp)
 	snoop++;
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     }
@@ -196,7 +196,7 @@ main (int argc, char **argv)
     if (!host)
 	adios (NULL, "usage: %s -host \"host\"", invo_name);
 
-#ifdef	SMTP
+#ifdef SMTPMTS
     if (bulksw)
 	do_bulk (host);
 #endif
@@ -218,10 +218,10 @@ main (int argc, char **argv)
 
     nfs = new_fs (form, format, FORMAT);
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
-    if (!folder && !(folder = m_find (inbox)))
-	folder = defalt;
+    if (!folder)
+	folder = getfolder (0);
     maildir = m_maildir (folder);
 
     if (stat (maildir, &st) == NOTOK) {
@@ -237,7 +237,7 @@ main (int argc, char **argv)
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
 #ifdef BPOP
@@ -249,10 +249,10 @@ main (int argc, char **argv)
     popi();
     pop_quit();
 
-    m_replace (pfolder, folder);	/* update current folder   */
+    context_replace (pfolder, folder);	/* update current folder   */
     seq_setunseen (mp, 0);		/* set the Unseen-Sequence */
     seq_save (mp);
-    m_update ();			/* update the context file */
+    context_save ();			/* save the context file   */
     done (0);
 
     /* NOTREACHED */
@@ -439,7 +439,7 @@ retr_action (char *rsp, int flag)
 	static char *cp;
 
 	if (flag == OK) {
-	    if ((mp = m_remsg (mp, 0, msgnum = mp->hghmsg + 1)) == NULL)
+	    if (!(mp = folder_realloc (mp, 0, msgnum = mp->hghmsg + 1)))
 		adios (NULL, "unable to allocate folder storage");
 
 	    cp = getcpy (m_name (mp->hghmsg + 1));
@@ -452,7 +452,8 @@ retr_action (char *rsp, int flag)
 
 	    fflush (fp);
 	    if (fstat (fileno (fp), &st) != NOTOK && st.st_size > 0) {
-		mp->msgstats[msgnum] = EXISTS;
+		clear_msg_flags (mp, msgnum);
+		set_exists (mp, msgnum);
 		set_unseen (mp, msgnum);
 		mp->msgflags |= SEQMOD;
 
@@ -513,10 +514,9 @@ msh (void)
 #endif
 
 
-#ifdef SMTP
+#ifdef SMTPMTS
 #include <zotnet/mts/mts.h>
-#include <mts/sendmail/smail.h>
-
+#include <mts/smtp/smtp.h>
 
 static int
 dselect (struct direct *d)
