@@ -110,7 +110,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -384,7 +384,7 @@ no_body: ;
     close (fdo);
     unlink (tmpfil);
 
-    m_update ();	/* update the context file */
+    context_save ();	/* save the context file */
     done (0);
 }
 
