@@ -45,12 +45,12 @@ main (int argc, char **argv)
 #endif
     invo_name = r1bindex (argv[0], '/');
     mts_init (invo_name);
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
