@@ -6,6 +6,7 @@
  */
 
 #include <h/mh.h>
+#include <fcntl.h>
 #include <h/signals.h>
 #include <errno.h>
 #include <signal.h>
@@ -19,12 +20,12 @@ static struct swit switches[] = {
     { "public",	0 },
 #define NPUBSW         3
     { "nopublic",  0 },
-#define SEQSW          4
-    { "sequence name", 0 },
-#define ZEROSW         5
+#define ZEROSW         4
     { "zero",	0 },
-#define NZEROSW        6
+#define NZEROSW        5
     { "nozero",	0 },
+#define SEQSW          6
+    { "sequence name", 0 },
 #define VERSIONSW      7
     { "version", 0 },
 #define HELPSW         8
@@ -34,12 +35,10 @@ static struct swit switches[] = {
 
 extern int errno;
 
-static char *tmpfilenam = NULL;
-
 /*
- * prototypes
+ * name of temporary file to store incoming message
  */
-static int folder_addmsg(struct msgs *, char *);
+static char *tmpfilenam = NULL;
 
 
 int
@@ -57,7 +56,7 @@ main (int argc, char **argv)
 #endif
     invo_name = r1bindex (argv[0], '/');
     mts_init (invo_name);
-    if ((cp = m_find (invo_name))) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -117,19 +116,22 @@ main (int argc, char **argv)
 		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	}
-	else
+	} else {
 	    adios (NULL, "usage: %s [+folder] [switches]", invo_name);
+	}
     }
 
     seqs[seqp] = NULL;	/* NULL terminate list of sequences */
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
-    if (!folder && !(folder = m_find (inbox)))
-	folder = defalt;
+
+    /* use default folder, if none given */
+    if (!folder)
+	folder = getfolder (0);
     maildir = m_maildir (folder);
 
+    /* check if folder exists */
     if (stat (maildir, &st) == NOTOK) {
 	if (errno != ENOENT)
 	    adios (maildir, "error on folder");
@@ -143,7 +145,7 @@ main (int argc, char **argv)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     SIGNAL (SIGHUP, SIG_IGN);
@@ -172,7 +174,7 @@ main (int argc, char **argv)
     }
 
     /* Link message into folder */
-    if ((msgnum = folder_addmsg(mp, tmpfilenam)) == -1)
+    if ((msgnum = folder_addmsg (&mp, tmpfilenam, 0, 1, 0)) == -1)
 	done (1);
 
     unlink (tmpfilenam);
@@ -186,51 +188,11 @@ main (int argc, char **argv)
 
     seq_setunseen (mp, 0);	/* add message to the Unseen-Sequence */
     seq_save (mp);		/* synchronize message sequences      */
-    m_freefolder (mp);		/* free folder/message structure      */
-    m_update ();		/* update the context file            */
+    context_save ();		/* save the context file              */
+    folder_free (mp);		/* free folder/message structure      */
     done (0);
 }
 
-
-/*
- * Link message into a folder.  Set the EXISTS and
- * UNSEEN bits.  Return the new number of the message.
- * If an error, return -1;
- */
-static int
-folder_addmsg(struct msgs *mp, char *msgfile)
-{
-    int msgnum;
-
-    msgnum = mp->hghmsg;
-    do {
-	msgnum++;
-	mp->hghmsg++;
-	if (msgnum > mp->hghoff) {
-	    if (!(mp = m_remsg (mp, 0, mp->hghoff + MAXFOLDER))) {
-		advise (NULL, "unable to allocate folder storage");
-		return -1;
-	    }
-	}
-
-	set_exists (mp, msgnum);
-	set_unseen (mp, msgnum);
-	errno = 0;
-    } while (link (msgfile, m_name (msgnum)) == NOTOK && errno == EEXIST);
-
-    if (errno != 0) {
-	advise (NULL, "can't file message %d", msgnum);
-	return -1;
-    }
-
-    if (mp->lowmsg == 0)
-	mp->lowmsg = msgnum;
-    mp->msgflags |= SEQMOD;
-
-    return msgnum;
-}
-
-
 /*
  * Clean up and exit
  */
