@@ -5,10 +5,6 @@
  * $Id$
  */
 
-#ifndef BSD42
-# undef TTYD
-#endif
-
 #include <h/mh.h>
 #include <h/signals.h>
 #include <h/rcvmail.h>
@@ -17,14 +13,12 @@
 #include <signal.h>
 #include <fcntl.h>
 
-#ifndef	TTYD
-# include <utmp.h>
-# ifndef UTMP_FILE
-#  ifdef _PATH_UTMP
-#   define UTMP_FILE _PATH_UTMP
-#  else
-#   define UTMP_FILE "/etc/utmp"
-#  endif
+#include <utmp.h>
+#ifndef UTMP_FILE
+# ifdef _PATH_UTMP
+#  define UTMP_FILE _PATH_UTMP
+# else
+#  define UTMP_FILE "/etc/utmp"
 # endif
 #endif
 
@@ -81,19 +75,16 @@ main (int argc, char **argv)
     int md, vecp = 0;
     char *cp, *user, buf[100], **ap;
     char **argp, *arguments[MAXARGS], *vec[MAXARGS];
-
-#ifndef	TTYD
     char tty[BUFSIZ];
     struct utmp ut;
     register FILE *uf;
-#endif	/* not TTYD */
 
 #ifdef LOCALE
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
     mts_init (invo_name);
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     }
@@ -162,20 +153,17 @@ main (int argc, char **argv)
 	exit (RCV_MBX);
 
     user = getusr();
-#ifndef	TTYD
     if ((uf = fopen (UTMP_FILE, "r")) == NULL)
 	exit (RCV_MBX);
+
     while (fread ((char *) &ut, sizeof(ut), 1, uf) == 1)
 	if (ut.ut_name[0] != 0
 		&& strncmp (user, ut.ut_name, sizeof(ut.ut_name)) == 0) {
 	    strncpy (tty, ut.ut_line, sizeof(ut.ut_line));
 	    alert (tty, md);
 	}
-    fclose (uf);
-#else /* TTYD */
-    alert (user, md);
-#endif /* TTYD */
 
+    fclose (uf);
     exit (RCV_MOK);
 }
 
@@ -232,9 +220,7 @@ message_fd (char **vec)
     if (dup2 (fd, 1) == NOTOK || dup2 (fd, 2) == NOTOK)
 	_exit (-1);
     closefds (3);
-#ifdef BSD42
-    setpgrp (0, getpid ());
-#endif
+    setpgid ((pid_t) 0, getpid ());	/* put in own process group */
     execvp (vec[0], vec);
     _exit (-1);
 }
@@ -253,7 +239,7 @@ header_fd (void)
 
     rewind (stdin);
     nfs = new_fs (form, format, SCANFMT);
-    scan (stdin, 0, 0, nfs, width, 0, 0, 0, 0L, 0);
+    scan (stdin, 0, 0, nfs, width, 0, 0, NULL, 0L, 0);
     if (newline)
         write (fd, "\n\r", 2);
     write (fd, scanl, strlen (scanl));
@@ -264,8 +250,6 @@ header_fd (void)
 }
 
 
-#ifndef	TTYD
-
 static void
 alert (char *tty, int md)
 {
@@ -304,25 +288,3 @@ alert (char *tty, int md)
     close (td);
 }
 
-#else /* TTYD */
-
-static void
-alert (char *user, int md)
-{
-    int i, td;
-    char buffer[BUFSIZ];
-
-    if ((td = ttyw ("notify", NULL, NULL, user)) == NOTOK)
-	return;
-    SIGNAL (SIGPIPE, SIG_IGN);
-
-    lseek (md, (off_t) 0, SEEK_SET);
-    while ((i = read (md, buffer, sizeof(buffer))) > 0)
-	if (write (td, buffer, i) != i)
-	    break;
-
-    close (td);
-}
-
-#endif /* TTYD */
-
