@@ -52,7 +52,6 @@ static void opnfolds (struct st_fold *, int);
 static void clsfolds (struct st_fold *, int);
 static void remove_files (int, char **);
 static int m_file (char *, struct st_fold *, int, int);
-static int addmsg (struct msgs **, char *, int);
 
 
 int
@@ -73,7 +72,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -140,7 +139,7 @@ main (int argc, char **argv)
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 		case NRPRCSW: 
-		    rmmproc = (char *)0;
+		    rmmproc = NULL;
 		    continue;
 	    }
 	if (*cp == '+' || *cp == '@') {
@@ -153,7 +152,7 @@ main (int argc, char **argv)
 	}
     }
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
     if (foldp == 0)
 	adios (NULL, "no folder specified");
@@ -179,14 +178,14 @@ main (int argc, char **argv)
     if (!msgp)
 	msgs[msgp++] = "cur";
     if (!folder)
-	folder = m_getfolder ();
+	folder = getfolder (1);
     strcpy (maildir, m_maildir (folder));
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
 
     /* read source folder */
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
@@ -210,6 +209,18 @@ main (int argc, char **argv)
 	}
     }
 
+    /*
+     * This is a hack.  If we are using an external rmmproc,
+     * then save the current folder to the context file,
+     * so the external rmmproc will remove files from the correct
+     * directory.  This should be moved to folder_delmsgs().
+     */
+    if (rmmproc) {
+	context_replace (pfolder, folder);
+	context_save ();
+	fflush (stdout);
+    }
+
     /* If -nolink, then "remove" messages from source folder */
     if (!linkf) {
 	folder_delmsgs (mp, 0);
@@ -222,8 +233,9 @@ main (int argc, char **argv)
 	seq_setcur (mp, mp->hghsel);
     seq_save (mp);	/* synchronize message sequences */
 
-    m_replace (pfolder, folder);	/* update current folder   */
-    m_update ();			/* update the context file */
+    context_replace (pfolder, folder);	/* update current folder   */
+    context_save ();			/* save the context file   */
+    folder_free (mp);			/* free folder structure   */
     done (0);
 }
 
@@ -259,7 +271,7 @@ opnfolds (struct st_fold *folders, int nfolders)
 
 	if (chdir (nmaildir) == NOTOK)
 	    adios (nmaildir, "unable to change directory to");
-	if (!(mp = m_readfolder (fp->f_name)))
+	if (!(mp = folder_read (fp->f_name)))
 	    adios (NULL, "unable to read folder %s", fp->f_name);
 	mp->curmsg = 0;
 
@@ -333,133 +345,8 @@ m_file (char *msgfile, struct st_fold *folders, int nfolders, int preserve)
     struct st_fold *fp, *ep;
 
     for (fp = folders, ep = folders + nfolders; fp < ep; fp++) {
-	if ((msgnum = addmsg (&fp->f_mp, msgfile, preserve)) == -1)
+	if ((msgnum = folder_addmsg (&fp->f_mp, msgfile, 1, 0, preserve)) == -1)
 	    return 1;
     }
     return 0;
 }
-
-
-/*
- * Link message into a folder.  Return the new number
- * of the message.  If an error occurs, return -1.
- */
-
-static int
-addmsg (struct msgs **mpp, char *msgfile, int preserve)
-{
-    int in, out, linkerr, msgnum;
-    char *nmsg, newmsg[BUFSIZ];
-    struct msgs *mp;
-    struct stat st1, st2;
-
-    mp = *mpp;
-
-    /* Preserve the numbering of the message */
-    if (preserve && (msgnum = m_atoi (msgfile)) > 0) {
-	nmsg = msgfile;
-	if (msgnum >= mp->hghoff) {
-	    if ((mp = m_remsg (mp, 0, msgnum + MAXFOLDER)))
-		*mpp = mp;
-	    else
-		adios (NULL, "unable to allocate folder storage");
-	}
-	if (!(mp->msgstats[msgnum] & EXISTS)) {
-	    mp->msgstats[msgnum] |= EXISTS;
-#if 0
-	    mp->msgstats[msgnum] &= ~DELETED;
-#endif
-	    mp->nummsg++;
-	}
-	set_selected (mp, msgnum);
-	if (msgnum > mp->hghmsg)
-	    mp->hghmsg = msgnum;
-    } else {
-	/* Else assign it next highest number available */
-	if (mp->hghmsg >= mp->hghoff) {
-	    if ((mp = m_remsg (mp, 0, mp->hghoff + MAXFOLDER)))
-		*mpp = mp;
-	    else
-		adios (NULL, "unable to allocate folder storage");
-	}
-
-	msgnum = ++mp->hghmsg;	/* get next number available */
-	nmsg = m_name (msgnum);
-	mp->nummsg++;
-	mp->msgstats[msgnum] |= EXISTS;
-	set_selected (mp, msgnum);
-    }
-
-    if (mp->lowmsg == 0)
-	mp->lowmsg = msgnum;
-    if (mp->lowsel == 0 || msgnum < mp->lowsel)
-	mp->lowsel = msgnum;
-    if (msgnum > mp->hghsel)
-	mp->hghsel = msgnum;
-
-    sprintf (newmsg, "%s/%s", mp->foldpath, nmsg);
-
-    /*
-     * Now link message into new folder
-     */
-    if (link (msgfile, newmsg) == NOTOK) {
-	linkerr = errno;
-
-#ifdef EISREMOTE
-	if (linkerr == EISREMOTE)
-	    linkerr = EXDEV;
-#endif /* EISREMOTE */
-
-	/*
-	 * Check if the file in our desired location is the
-	 * same as the source file.  If so, then just continue,
-	 * else print error message and return.
-	 */
-	if (linkerr == EEXIST) {
-	    if (stat (msgfile, &st2) == OK && stat (newmsg, &st1) == OK
-		&& st2.st_ino == st1.st_ino) {
-		return msgnum;
-	    } else {
-		advise (NULL, "message %s already exists", newmsg);
-		return -1;
-	    }
-	}
-
-	/*
-	 * If link failed because we are trying to link
-	 * across devices, then check if there is a message
-	 * already in the desired location.  If so, then return
-	 * error, else just copy the message.
-	 */
-	if (linkerr == EXDEV) {
-	    if (stat (newmsg, &st1) == OK) {
-		advise (NULL, "message %s:%s already exists", newmsg);
-		return -1;
-	    } else {
-		if ((in = open (msgfile, O_RDONLY)) == NOTOK) {
-		    advise (msgfile, "unable to open message %s");
-		    return -1;
-		}
-		fstat (in, &st1);
-		if ((out = creat (newmsg, (int) st1.st_mode & 0777)) == NOTOK) {
-		    advise (newmsg, "unable to create");
-		    close (in);
-		    return -1;
-		}
-		cpydata (in, out, msgfile, newmsg);
-		close (in);
-		close (out);
-		return msgnum;
-	    }
-	}
-
-	/*
-	 * Else, some other type of link error,
-	 * so just return error.
-	 */
-	advise (newmsg, "error linking %s to", msgfile);
-	return -1;
-    }
-
-    return msgnum;
-}
