@@ -138,7 +138,7 @@ int
 main (int argc, char **argv)
 {
     int	i, isdf = 0;
-    int anot = 0, inplace = 0;
+    int anot = 0, inplace = 1;
     int nedit = 0, nwhat = 0;
     char *cp, *cwd, *dp, *maildir, *file = NULL;
     char *folder = NULL, *msg = NULL, *dfolder = NULL;
@@ -156,7 +156,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     }
@@ -325,7 +325,7 @@ main (int argc, char **argv)
 
     cwd = getcpy (pwd ());
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
     if (file && (msg || folder))
 	adios (NULL, "can't mix files and folders/msgs");
@@ -373,14 +373,14 @@ try_it_again: ;
     if (!msg)
 	msg = "cur";
     if (!folder)
-	folder = m_getfolder ();
+	folder = getfolder (1);
     maildir = m_maildir (folder);
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -394,11 +394,10 @@ try_it_again: ;
     if (mp->numsel > 1)
 	adios (NULL, "only one message at a time!");
 
-    m_replace (pfolder, folder);	/* update current folder */
-    if (mp->lowsel != mp->curmsg)
-	seq_setcur (mp, mp->lowsel);
-    seq_save (mp);
-    m_update ();			/* update the context file */
+    context_replace (pfolder, folder);	/* update current folder   */
+    seq_setcur (mp, mp->lowsel);	/* update current message  */
+    seq_save (mp);			/* synchronize sequences   */
+    context_save ();			/* save the context file   */
 
 go_to_it: ;
     msg = file ? file : getcpy (m_name (mp->lowsel));
