@@ -376,14 +376,9 @@ insert (struct mailname *np)
 	return 0;
 
     for (mp = &mq; mp->m_next; mp = mp->m_next) {
-#ifdef BERK
-	if (uleq (np->m_mbox, mp->m_next->m_mbox))
-	    return 0;
-#else	/* not BERK */
 	if (uleq (np->m_host, mp->m_next->m_host)
 		&& uleq (np->m_mbox, mp->m_next->m_mbox))
 	    return 0;
-#endif	/* BERK */
     }
     if (!ccme && ismymbox (np))
 	return 0;
