@@ -37,7 +37,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -80,10 +80,10 @@ main (int argc, char **argv)
 	    adios (NULL, "usage: %s [+folder] [switches]", invo_name);
     }
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
     if (!folder) {
-	folder = m_getfolder ();
+	folder = getfolder (1);
 	defolder++;
     }
     if (strcmp (m_mailpath (folder), pwd ()) == 0)
@@ -98,10 +98,10 @@ main (int argc, char **argv)
 	if (cp > newfolder)
 	    *cp = '\0';
 	else
-	    strcpy (newfolder, (cp = m_find (inbox)) ? cp : defalt);
+	    strcpy (newfolder, getfolder(0));
+    } else {
+	strcpy (newfolder, getfolder(0));
     }
-    else
-	strcpy (newfolder, (cp = m_find (inbox)) ? cp : defalt);
 
     if (interactive) {
 	cp = concat ("Remove folder \"", folder, "\"? ", NULL);
@@ -110,11 +110,11 @@ main (int argc, char **argv)
 	free (cp);
     }
 
-    if (rmf (folder) == OK && strcmp (m_find (pfolder), newfolder)) {
+    if (rmf (folder) == OK && strcmp (context_find (pfolder), newfolder)) {
 	printf ("[+%s now current]\n", newfolder);
-	m_replace (pfolder, newfolder);	/* update current folder */
+	context_replace (pfolder, newfolder);	/* update current folder */
     }
-    m_update ();	/* update the context file */
+    context_save ();	/* save the context file */
     done (0);
 }
 
@@ -134,7 +134,7 @@ rmf (char *folder)
 
 	case NOTOK: 
 	    sprintf (cur, "atr-%s-%s", current, m_mailpath (folder));
-	    if (!m_delete (cur)) {
+	    if (!context_del (cur)) {
 		printf ("[+%s de-referenced]\n", folder);
 		return OK;
 	    }
@@ -185,6 +185,10 @@ rmf (char *folder)
 
     closedir (dd);
 
+    /*
+     * Remove any relevant private sequences
+     * or attributes from context file.
+     */
     rma (folder);
 
     chdir ("..");
@@ -197,8 +201,8 @@ rmf (char *folder)
 
 
 /*
- * Remove any private sequences or attributes
- * for this folder from the context.
+ * Remove any private sequences or attributes for
+ * this folder from the profile/context list.
  */
 
 static void
@@ -210,21 +214,25 @@ rma (char *folder)
 
     alen = strlen ("atr-");
     plen = strlen (cp = m_mailpath (folder)) + 1;
+    context_read ();
 
-    m_getdefs ();
+    /*
+     * Search context list for keys that look like
+     * "atr-something-foldername", and remove them.
+     */
     for (np = m_defs, pp = NULL; np; np = np->n_next) {
 	if (ssequal ("atr-", np->n_name)
 		&& (j = strlen (np->n_name) - plen) > alen
 		&& *(np->n_name + j) == '-'
 		&& strcmp (cp, np->n_name + j + 1) == 0) {
 	    if (!np->n_context)
-		admonish (NULL, "bug: m_delete(key=\"%s\")", np->n_name);
+		admonish (NULL, "bug: context_del(key=\"%s\")", np->n_name);
 	    if (pp) {
 		pp->n_next = np->n_next;
 		np = pp;
-	    }
-	    else
+	    } else {
 		m_defs = np->n_next;
+	    }
 	    ctxflags |= CTXMOD;
 	} else {
 	    pp = np;
