@@ -29,7 +29,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -65,19 +65,19 @@ main (int argc, char **argv)
 	    msgs[msgp++] = cp;
     }
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
     if (!msgp)
 	msgs[msgp++] = "cur";
     if (!folder)
-	folder = m_getfolder ();
+	folder = getfolder (1);
     maildir = m_maildir (folder);
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -89,11 +89,24 @@ main (int argc, char **argv)
 	    done (1);
     seq_setprev (mp);		/* set the previous-sequence      */
 
+    /*
+     * This is hackish.  If we are using a external rmmproc,
+     * then we need to update the current folder in the
+     * context so the external rmmproc will remove files
+     * from the correct directory.  This should be moved to
+     * folder_delmsgs().
+     */
+    if (rmmproc) {
+	context_replace (pfolder, folder);
+	context_save ();
+	fflush (stdout);
+    }
+
     folder_delmsgs (mp, 1);	/* "remove" the SELECTED messages */
 
     seq_save (mp);		/* synchronize message sequences  */
-    m_freefolder (mp);			/* free folder structure   */
-    m_replace (pfolder, folder);	/* update current folder   */
-    m_update ();			/* update the context file */
+    context_replace (pfolder, folder);	/* update current folder   */
+    context_save ();			/* save the context file   */
+    folder_free (mp);			/* free folder structure   */
     done (0);
 }
