@@ -72,7 +72,7 @@ main (int argc, char **argv)
 #endif
     invo_name = r1bindex (argv[0], '/');
     mts_init (invo_name);
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -152,7 +152,7 @@ main (int argc, char **argv)
 	}
     }
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
     nfs = new_fs (form, format, FORMAT);	/* must be before chdir() */
 
@@ -176,14 +176,14 @@ main (int argc, char **argv)
 
 #ifndef	JLR
 	if (hdrflag) {
-	    printf ("Folder %-32s%s\n\n", file, dtimenow (1));
+	    printf ("FOLDER %s\t%s\n", file, dtimenow (1));
 	}
 #endif /* JLR */
 
 	m_unknown (in);
 	for (msgnum = 1; ; ++msgnum) {
 	    state = scan (in, msgnum, -1, nfs, width, 0, 0,
-		    hdrflag ? file : (char *) 0, 0L, 1);
+		    hdrflag ? file : NULL, 0L, 1);
 	    if (state != SCNMSG && state != SCNENC)
 		break;
 	}
@@ -198,14 +198,14 @@ main (int argc, char **argv)
     if (!msgp)
 	msgs[msgp++] = "all";
     if (!folder)
-	folder = m_getfolder ();
+	folder = getfolder (1);
     maildir = m_maildir (folder);
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -217,15 +217,15 @@ main (int argc, char **argv)
 	    done(1);
     seq_setprev (mp);			/* set the Previous-Sequence */
 
-    m_replace (pfolder, folder);	/* update current folder         */
+    context_replace (pfolder, folder);	/* update current folder         */
     seq_save (mp);			/* synchronize message sequences */
-    m_update ();			/* update the context file       */
+    context_save ();			/* save the context file         */
 
     /*
      * Get the sequence number for each sequence
      * specified by Unseen-Sequence
      */
-    if ((cp = m_find (usequence))) {
+    if ((cp = context_find (usequence))) {
 	char *dp;
 
 	dp = getcpy(cp);
@@ -263,7 +263,7 @@ main (int argc, char **argv)
 
 #ifndef JLR
 	    if (hdrflag) {
-		printf ("Folder %-32s%s\n\n", folder, dtimenow (1));
+		printf ("FOLDER %s\t%s\n", folder, dtimenow(1));
 	    }
 #endif /* JLR */
 
@@ -278,7 +278,7 @@ main (int argc, char **argv)
 
 	    switch (state = scan (in, msgnum, 0, nfs, width,
 			msgnum == mp->curmsg, unseen,
-			hdrflag ? folder : (char *) 0, 0L, 1)) {
+			hdrflag ? folder : NULL, 0L, 1)) {
 		case SCNMSG: 
 		case SCNENC: 
 		case SCNERR: 
@@ -306,7 +306,7 @@ main (int argc, char **argv)
     seq_save (mp);	/* because formatsbr might have made changes */
 #endif
 
-    m_freefolder (mp);	/* free folder/message structure */
+    folder_free (mp);	/* free folder/message structure */
     if (clearflag)
 	clear_screen ();
 
