@@ -66,13 +66,11 @@ int
 scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
       int unseen, char *folder, long size, int noisy)
 {
-    int compnum, encrypted, state;
-    register int i;
-    register char *cp;
-    register struct comp *cptr;
-    register char *tmpbuf;
-    register char **nxtbuf;
-    register struct comp **savecomp;
+    int i, compnum, encrypted, state;
+    char *cp, *tmpbuf, **nxtbuf;
+    char *saved_c_text;
+    struct comp *cptr;
+    struct comp **savecomp;
     char *scnmsg;
     FILE *scnout;
     char name[NAMESZ];
@@ -295,52 +293,50 @@ finished:
 	advise("read", "unable to"); /* "read error" */
 	return SCNFAT;
     }
-    {
-	char *saved_c_text;
 
-	if (bodycomp) {
-	    /* Save and restore buffer so we don't trash our dynamic pool! */
-	    saved_c_text = bodycomp->c_text;
-	    bodycomp->c_text = tmpbuf;
-	}
+    /* Save and restore buffer so we don't trash our dynamic pool! */
+    if (bodycomp) {
+	saved_c_text = bodycomp->c_text;
+	bodycomp->c_text = tmpbuf;
+    }
 
-	if (size)
-	    dat[2] = size;
-	else if (outnum > 0)
-	    dat[2] = ftell(scnout);
+    if (size)
+	dat[2] = size;
+    else if (outnum > 0)
+	dat[2] = ftell(scnout);
 
-	if ((datecomp && !datecomp->c_text) || (!size && !outnum)) {
-	    struct stat st;
+    if ((datecomp && !datecomp->c_text) || (!size && !outnum)) {
+	struct stat st;
 
-	    fstat (fileno(inb), &st);
-	    if (!size && !outnum)
-		dat[2] = st.st_size;
-	    if (datecomp) {
-		if (! datecomp->c_text) {
-		    if (datecomp->c_tws == NULL)
-			datecomp->c_tws = (struct tws *)
-			    calloc((size_t) 1, sizeof(*datecomp->c_tws));
-		    if (datecomp->c_tws == NULL)
-			adios (NULL, "unable to allocate tws buffer");
-  		    *datecomp->c_tws = *dlocaltime ((time_t *) &st.st_mtime);
-		    datecomp->c_flags = -1;
-		} else {
-		    datecomp->c_flags = 0;
-		}
+	fstat (fileno(inb), &st);
+	if (!size && !outnum)
+	    dat[2] = st.st_size;
+	if (datecomp) {
+	    if (! datecomp->c_text) {
+		if (datecomp->c_tws == NULL)
+		    datecomp->c_tws = (struct tws *)
+			calloc((size_t) 1, sizeof(*datecomp->c_tws));
+		if (datecomp->c_tws == NULL)
+		    adios (NULL, "unable to allocate tws buffer");
+		*datecomp->c_tws = *dlocaltime ((time_t *) &st.st_mtime);
+		datecomp->c_flags = -1;
+	    } else {
+		datecomp->c_flags = 0;
 	    }
 	}
-
-#ifndef JLR
-	fmt_scan (fmt, scanl, slwidth, dat);
-#else /* JLR */
-	fmt = fmt_scan (fmt, scanl, slwidth, dat);
-	if (!fmt)
-	    fmt = fmt_top;		/* reset for old format files */
-#endif /* JLR */
-
-	if (bodycomp)
-	    bodycomp->c_text = saved_c_text;
     }
+
+    fmt_scan (fmt, scanl, slwidth, dat);
+
+#if 0
+    fmt = fmt_scan (fmt, scanl, slwidth, dat);
+    if (!fmt)
+	fmt = fmt_top;		/* reset for old format files */
+#endif
+
+    if (bodycomp)
+	bodycomp->c_text = saved_c_text;
+
     if (noisy)
 	fputs (scanl, stdout);
 
