@@ -156,7 +156,7 @@ one_shot: ;
 
     nparts = 1, pos = start;
     while (fgets (buffer, sizeof buffer - 1, in)) {
-	register long	len;
+	long len;
 
 	if ((pos += (len = strlen (buffer))) > CPERMSG)
 	    nparts++, pos = len;
@@ -213,7 +213,7 @@ one_shot: ;
 
 	pos = 0;
 	for (;;) {
-	    register long len;
+	    long len;
 
 	    if (!fgets (buffer, sizeof buffer - 1, in)) {
 		if (partno == nparts)
@@ -516,7 +516,7 @@ annoaux (int fd)
 	    admonish (maildir, "unable to change directory to");
 	return;
     }
-    if (!(mp = m_readfolder (folder))) {
+    if (!(mp = folder_read (folder))) {
 	if (debugsw)
 	    admonish (NULL, "unable to read folder %s");
 	return;
@@ -577,7 +577,7 @@ annoaux (int fd)
     free (cp);
 
 oops: ;
-    m_freefolder (mp);	/* free folder/message info */
+    folder_free (mp);	/* free folder/message structure */
 }
 
 
