@@ -80,7 +80,7 @@ main (int argc, char **argv)
 	if (uleq (invo_name, "prev"))
 	    mode = PREV;
     }
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -187,7 +187,7 @@ main (int argc, char **argv)
     }
     procp = vecp;
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
 
     if (draftsw || file) {
@@ -222,14 +222,14 @@ main (int argc, char **argv)
     }
 
     if (!folder)
-	folder = m_getfolder ();
+	folder = getfolder (1);
     maildir = m_maildir (folder);
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -240,12 +240,17 @@ main (int argc, char **argv)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
 
+    /*
+     * Set the UNSEEN bit for all the SELECTED messages,
+     * since we will use that as a tag to know which messages
+     * to remove from the "unseen" sequence.
+     */
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
 	if (is_selected(mp, msgnum))
 	    set_unseen (mp, msgnum);
 
-    seq_setprev (mp);	/* set the Previous-Sequence */
-    seq_setunseen (mp, 1);/* unset the Unseen-Sequence */
+    seq_setprev (mp);		/* set the Previous-Sequence */
+    seq_setunseen (mp, 1);	/* unset the Unseen-Sequence */
 
     if (mp->numsel > MAXARGS - 2)
 	adios (NULL, "more than %d messages for show exec", MAXARGS - 2);
@@ -254,11 +259,10 @@ main (int argc, char **argv)
 	if (is_selected(mp, msgnum))
 	    vec[vecp++] = getcpy (m_name (msgnum));
 
-    m_replace (pfolder, folder);	/* update current folder   */
-    if (mp->hghsel != mp->curmsg)
-	seq_setcur (mp, mp->hghsel);
+    seq_setcur (mp, mp->hghsel);	/* update current message  */
     seq_save (mp);			/* synchronize sequences   */
-    m_update ();			/* update the context file */
+    context_replace (pfolder, folder);	/* update current folder   */
+    context_save ();			/* save the context file   */
 
     if (headersw && vecp == 2)
 	printf ("(Message %s:%s)\n", folder, vec[1]);
@@ -381,7 +385,7 @@ is_mime (char *msgnam)
 	chset = "us-ascii";
 
     for (state = FLD;;)
-	switch (state = m_getfld (state, name, buf, sizeof buf, fp)) {
+	switch (state = m_getfld (state, name, buf, sizeof(buf), fp)) {
 	    case FLD:
 	    case FLDPLUS:
 	    case FLDEOF:
@@ -391,7 +395,7 @@ is_mime (char *msgnam)
 
 		    cp = add (buf, NULL);
 		    while (state == FLDPLUS) {
-			state = m_getfld (state, name, buf, sizeof buf, fp);
+			state = m_getfld (state, name, buf, sizeof(buf), fp);
 			cp = add (buf, cp);
 		    }
 		    bp = cp;
@@ -435,8 +439,9 @@ invalid: ;
 		    }
 		    for (dp = bp; istoken (*dp); dp++)
 			continue;
-		    c = *dp, *dp = NULL;
-		    if (*bp == NULL)
+		    c = *dp;
+		    *dp = '\0';
+		    if (!*bp)
 			goto invalid;
 		    if (passno > 1) {
 			if ((result = !uleq (bp, "plain")))
@@ -446,7 +451,7 @@ invalid: ;
 			    continue;
 			if ((result = !uprf (dp, "charset")))
 			    goto out;
-			dp += sizeof "charset" - 1;
+			dp += sizeof("charset") - 1;
 			while (isspace (*dp))
 			    dp++;
 			if (*dp++ != '=')
@@ -455,12 +460,12 @@ invalid: ;
 			    dp++;
 			if (*dp == '"') {
 			    if ((bp = strchr(++dp, '"')))
-				*bp = NULL;
+				*bp = '\0';
 			}
 			else
 			    for (bp = dp; *bp; bp++)
 				if (isspace (*bp)) {
-				    *bp = NULL;
+				    *bp = '\0';
 				    break;
 				}
 			if ((result = !uleq (dp, chset))
@@ -487,14 +492,14 @@ out: ;
 	        if (uleq (name, ENCODING_FIELD)) {
 		    cp = add (buf, NULL);
 		    while (state == FLDPLUS) {
-			state = m_getfld (state, name, buf, sizeof buf, fp);
+			state = m_getfld (state, name, buf, sizeof(buf), fp);
 			cp = add (buf, cp);
 		    }
 		    for (bp = cp; isspace (*bp); bp++)
 			continue;
 		    for (dp = bp; istoken (*dp); dp++)
 			continue;
-		    *dp = NULL;
+		    *dp = '\0';
 		    result = !uleq (bp, "7bit")
 				&& !uleq (bp, "8bit")
 				&& !uleq (bp, "binary");
@@ -507,7 +512,7 @@ out: ;
 		    break;
 		}
 		while (state == FLDPLUS)
-		    state = m_getfld (state, name, buf, sizeof buf, fp);
+		    state = m_getfld (state, name, buf, sizeof(buf), fp);
 		break;
 
 	    default:
