@@ -15,8 +15,6 @@
  *  Under MMDF-I, users should (symbolically) link
  *  /usr/local/nmh/lib/slocal to $HOME/bin/rcvmail.
  *
- *  Under stand-alone MH, post will automatically run this during local
- *  delivery.
  */
 
 #include <h/mh.h>
@@ -129,7 +127,7 @@ static struct pair hdrs[NVEC + 1] = {
     { "Resent-To",       NULL, P_ADR },
     { "Resent-cc",       NULL, P_ADR },
 
-    { NULL, NULL, NULL }
+    { NULL, NULL, 0 }
 };
 
 static struct pair vars[] = {
@@ -139,7 +137,7 @@ static struct pair vars[] = {
     { "reply-to", NULL, P_CHK },
     { "info",     NULL, P_NIL },
 
-    { NULL, NULL, NULL }
+    { NULL, NULL, 0 }
 };
 
 extern char **environ;
@@ -163,6 +161,7 @@ static void get_sender (char *, char **);
 static int copy_message (int, char *, int);
 static void adorn (char *, char *, ...);
 static int suppress_duplicates (int, char *);
+static char *trim (char *);
 
 
 int
@@ -179,7 +178,11 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (*argv, '/');
-    m_foil (NULL);		/* foil search of user profile */
+
+    /* foil search of user profile/context */
+    if (context_foil (NULL) == -1)
+	done (1);
+
     mts_init (invo_name);
 
     while ((cp = *argp++)) {
@@ -282,11 +285,7 @@ main (int argc, char **argv)
 
     if (geteuid() == 0) {
 	setgid (pw->pw_gid);
-
-#ifdef BSD42
 	initgroups (pw->pw_name, pw->pw_gid);
-#endif /* BSD42 */
-
 	setuid (pw->pw_uid);
     }
     
@@ -346,14 +345,14 @@ main (int argc, char **argv)
 	home = pw->pw_dir;
 
     if (debug) {
-	fprintf (stderr, "addr=\"%s\"\n", addr);
-	fprintf (stderr, "user=\"%s\"\n", user);
-	fprintf (stderr, "info=\"%s\"\n", info);
-	fprintf (stderr, "sender=\"%s\"\n", sender);
-	fprintf (stderr, "envelope=\"%s\"\n", envelope ? envelope : "");
-	fprintf (stderr, "mbox=\"%s\"\n", mbox);
-	fprintf (stderr, "home=\"%s\"\n", home);
-	fprintf (stderr, "ddate=\"%s\"\n", ddate);
+	fprintf (stderr, "addr=\"%s\"\n", trim(addr));
+	fprintf (stderr, "user=\"%s\"\n", trim(user));
+	fprintf (stderr, "info=\"%s\"\n", trim(info));
+	fprintf (stderr, "sender=\"%s\"\n", trim(sender));
+	fprintf (stderr, "envelope=\"%s\"\n", envelope ? trim(envelope) : "");
+	fprintf (stderr, "mbox=\"%s\"\n", trim(mbox));
+	fprintf (stderr, "home=\"%s\"\n", trim(home));
+	fprintf (stderr, "ddate=\"%s\"\n", trim(ddate));
 	fprintf (stderr, "now=%02d:%02d\n\n", now->tw_hour, now->tw_min);
     }
 
@@ -437,8 +436,7 @@ usr_delivery (int fd, char *delivery, int su)
 	}
 	if (debug) {
 	    for (i = 0; vec[i]; i++)
-		fprintf (stderr, "vec[%d]: \"%s\" ", i, vec[i]);
-	    fprintf (stderr, "\n");
+		fprintf (stderr, "vec[%d]: \"%s\"\n", i, trim(vec[i]));
 	}
 
 	field   = vec[0];
@@ -587,8 +585,8 @@ usr_delivery (int fd, char *delivery, int su)
 static int
 split (char *cp, char **vec)
 {
-    register int i;
-    register char *s;
+    int i;
+    char *s;
 
     s = cp;
     for (i = 0; i <= NVEC;) {
@@ -625,12 +623,12 @@ split (char *cp, char **vec)
 static int
 parse (int fd)
 {
-    register int i, state;
+    int i, state;
     int fd1;
-    register char *cp, *dp, *lp;
+    char *cp, *dp, *lp;
     char name[NAMESZ], field[BUFSIZ];
-    register struct pair *p, *q;
-    register FILE  *in;
+    struct pair *p, *q;
+    FILE  *in;
 
     if (parsed++)
 	return OK;
@@ -712,12 +710,12 @@ parse (int fd)
 	p->p_flags &= ~P_CHK;
 	if (debug)
 	    fprintf (stderr, "vars[%d]: name=\"%s\" value=\"%s\"\n",
-		    p - vars, p->p_name, p->p_value);
+		    p - vars, p->p_name, trim(p->p_value));
     }
     if (debug)
 	for (p = hdrs; p->p_name; p++)
 	    fprintf (stderr, "hdrs[%d]: name=\"%s\" value=\"%s\"\n",
-		p - hdrs, p->p_name, p->p_value ? p->p_value : "");
+		p - hdrs, p->p_name, p->p_value ? trim(p->p_value) : "");
 
     return OK;
 }
@@ -729,8 +727,8 @@ parse (int fd)
 static void
 expand (char *s1, char *s2, int fd)
 {
-    register char c, *cp;
-    register struct pair *p;
+    char c, *cp;
+    struct pair *p;
 
     if (!globbed)
 	glob (fd);
@@ -763,7 +761,7 @@ glob (int fd)
 {
     char buffer[BUFSIZ];
     struct stat st;
-    register struct pair *p;
+    struct pair *p;
 
     if (globbed++)
 	return;
@@ -782,7 +780,7 @@ glob (int fd)
     if (debug)
 	for (p = vars; p->p_name; p++)
 	    fprintf (stderr, "vars[%d]: name=\"%s\" value=\"%s\"\n",
-		    p - vars, p->p_name, p->p_value);
+		    p - vars, p->p_name, trim(p->p_value));
 }
 
 
@@ -945,7 +943,7 @@ static int
 usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 {
     pid_t child_id;
-    int bytes, i, status;
+    int i, bytes, seconds, status;
     struct stat st;
 
     if (verbose) {
@@ -979,9 +977,7 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 	    }
 #endif /* TIOCNOTTY */
 
-#ifdef BSD42
-	    setpgrp (0, getpid ());
-#endif /* BSD42 */
+	    setpgid ((pid_t) 0, getpid ());	/* put in own process group */
 
 	    *environ = NULL;
 	    m_putenv ("USER", pw->pw_name);
@@ -996,10 +992,16 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 	    if (!setjmp (myctx)) {
 		SIGNAL (SIGALRM, alrmser);
 		bytes = fstat (fd, &st) != NOTOK ? (int) st.st_size : 100;
-		if (bytes <= 0)
-		    bytes = 100;
-
-		alarm ((unsigned) (bytes * 60 + 300));
+		if (bytes <= 100) {
+		    /* give at least 5 minutes */
+		    seconds = 300;
+		} else if (bytes >= 90000) {
+		    /* a half hour is long enough */
+		    seconds = 1800;
+		} else {
+		    seconds = (bytes / 60) + 300;
+		}
+		alarm ((unsigned int) seconds);
 		status = pidwait (child_id, OK);
 		alarm (0);
 #ifdef MMDFI
@@ -1049,7 +1051,7 @@ static void
 get_sender (char *envelope, char **sender)
 {
     int i;
-    register char *cp;
+    char *cp;
     char buffer[BUFSIZ];
 
     if (envelope == NULL) {
@@ -1064,9 +1066,9 @@ get_sender (char *envelope, char **sender)
 	cp -= 24;
 	if (cp < buffer)
 	    cp = buffer;
-    }
-    else
+    } else {
 	cp = buffer;
+    }
     *cp = 0;
 
     for (cp = buffer + strlen (buffer) - 1; cp >= buffer; cp--)
@@ -1087,9 +1089,9 @@ get_sender (char *envelope, char **sender)
 static int
 copy_message (int qd, char *tmpfil, int fold)
 {
-    register int i, first = 1, fd1, fd2;
+    int i, first = 1, fd1, fd2;
     char buffer[BUFSIZ];
-    register FILE *qfp, *ffp;
+    FILE *qfp, *ffp;
 
     strcpy (tmpfil, m_tmpfil (invo_name));
 
@@ -1219,6 +1221,44 @@ fputs_error:
     return NOTOK;
 }
 
+/*
+ * Trim strings for pretty printing of debugging output
+ */
+
+static char *
+trim (char *cp)
+{
+    char buffer[BUFSIZ*4];
+    char *bp, *sp;
+
+    if (cp == NULL)
+	return NULL;
+
+    /* copy string into temp buffer */
+    strcpy (buffer, cp);
+    bp = buffer;
+
+    /* skip over leading whitespace */
+    while (isspace(*bp))
+	bp++;
+
+    /* start at the end and zap trailing whitespace */
+    for (sp = bp + strlen(bp) - 1; sp >= bp; sp--) {
+	if (isspace(*sp))
+	    *sp = 0;
+	else
+	    break;
+    }
+
+    /* replace remaining whitespace with spaces */
+    for (sp = bp; *sp; sp++)
+	if (isspace(*sp))
+	    *sp = ' ';
+
+    /* now return a copy */
+    return getcpy(bp);
+}
+
 
 static void
 adorn (char *what, char *fmt, ...)
@@ -1340,4 +1380,3 @@ suppress_duplicates (int fd, char *file)
     fclose (in);
     return OK;
 }
-
