@@ -75,7 +75,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     }
@@ -157,21 +157,21 @@ main (int argc, char **argv)
 	    msgs[msgp++] = cp;
     }
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
     if (!msgp)
 	msgs[msgp++] = "all";
     if (!datesw)
 	datesw = "date";
     if (!folder)
-	folder = m_getfolder ();
+	folder = getfolder (1);
     maildir = m_maildir (folder);
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -270,10 +270,10 @@ main (int argc, char **argv)
     }
     rename_msgs (mp, dlist);
 
-    m_replace (pfolder, folder);	/* update current folder         */
+    context_replace (pfolder, folder);	/* update current folder         */
     seq_save (mp);			/* synchronize message sequences */
-    m_freefolder (mp);			/* free folder/message structure */
-    m_update ();			/* update the context file       */
+    context_save ();			/* save the context file         */
+    folder_free (mp);			/* free folder/message structure */
     done (0);
 }
 
