@@ -95,7 +95,7 @@ WhatNow (int argc, char **argv)
     struct stat st;
 
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -274,7 +274,7 @@ editfile (char **ed, char **arg, char *file, int use,
 
     /* set initial editor */
     if (!reedit) {
-	if (*ed == NULL && (*ed = m_find ("editor")) == NULL)
+	if (*ed == NULL && (*ed = context_find ("editor")) == NULL)
 	    *ed = sysed;
     } else {
 	if (!*ed) {		/* no explicit editor */
@@ -282,7 +282,7 @@ editfile (char **ed, char **arg, char *file, int use,
 	    if ((cp = r1bindex (*ed, '/')) == NULL)
 		cp = *ed;
 	    cp = concat (cp, "-next", NULL);
-	    if ((cp = m_find (cp)) != NULL)
+	    if ((cp = context_find (cp)) != NULL)
 		*ed = cp;
 	}
     }
@@ -319,7 +319,7 @@ editfile (char **ed, char **arg, char *file, int use,
 #endif /* not HAVE_LSTAT */
     }
 
-    m_update ();	/* update the context file */
+    context_save ();	/* save the context file */
     fflush (stdout);
 
     switch (pid = vfork ()) {
@@ -363,12 +363,10 @@ editfile (char **ed, char **arg, char *file, int use,
 			&& (!reedit || (status & 0x00ff)))
 		    if (!use && (status & 0xff00) &&
 			    (rename (file, cp = m_backup (file)) != NOTOK)) {
-			advise (NULL, "problems with edit--draft left in %s",
-				cp);
+			advise (NULL, "problems with edit--draft left in %s", cp);
+		    } else {
+			advise (NULL, "problems with edit--%s preserved", file);
 		    }
-		    else
-			advise (NULL, "problems with edit--%s preserved",
-				file);
 		status = -2;	/* maybe "reedit ? -2 : -1"? */
 		break;
 #ifdef ATTVIBUG
@@ -380,7 +378,7 @@ editfile (char **ed, char **arg, char *file, int use,
 #ifdef HAVE_LSTAT
 	    if (altmsg
 		    && mp
-		    && (!mp->msgflags & READONLY)
+		    && !is_readonly(mp)
 		    && (slinked
 		           ? lstat (linkpath, &st) != NOTOK
 				&& S_ISREG(st.st_mode)
@@ -393,7 +391,7 @@ editfile (char **ed, char **arg, char *file, int use,
 #else /* HAVE_LSTAT */
 	    if (altmsg
 		    && mp
-		    && (!mp->msgflags & READONLY)
+		    && !is_readonly(mp)
 		    && stat (linkpath, &st) != NOTOK
 		    && st.st_nlink == 1
 		    && (unlink (altpath) == NOTOK
@@ -453,7 +451,7 @@ sendfile (char **arg, char *file, int pushsw)
 
 #ifdef MIME
     /* Translate MIME composition file, if necessary */
-    if ((cp = m_find ("automimeproc"))
+    if ((cp = context_find ("automimeproc"))
 	    && (uleq (cp, "1"))
 	    && !getenv ("NOMHNPROC")
 	    && mhnfile (file)
@@ -461,7 +459,7 @@ sendfile (char **arg, char *file, int pushsw)
 	return 0;
 
     /* For backwards compatibility */
-    if ((cp = m_find ("automhnproc"))
+    if ((cp = context_find ("automhnproc"))
 	    && !getenv ("NOMHNPROC")
 	    && mhnfile (file)
 	    && (i = editfile (&cp, NULL, file, NOUSE, NULL, NULL, NULL)))
@@ -479,7 +477,7 @@ sendfile (char **arg, char *file, int pushsw)
 	return 1;
     }
 
-    m_update ();	/* update the context file */
+    context_save ();	/* save the context file */
     fflush (stdout);
 
     for (i = 0; (child_id = vfork()) == NOTOK && i < 5; i++)
@@ -612,84 +610,69 @@ static struct swit  sendswitches[] = {
     { "alias aliasfile", 0 },
 #define	DEBUGSW           1
     { "debug", -5 },
-
-#define	ENCRSW            2
-#ifndef	TMA
-    { "encrypt", -7 },
-#else
-    { "encrypt", 0 },
-#endif
-
-#define	NENCRSW           3
-#ifndef	TMA
-    { "noencrypt", -9 },
-#else
-    { "noencrypt", 0 },
-#endif
-
-#define	FILTSW            4
+#define	FILTSW            2
     { "filter filterfile", 0 },
-#define	NFILTSW           5
+#define	NFILTSW           3
     { "nofilter", 0 },
-#define	FRMTSW            6
+#define	FRMTSW            4
     { "format", 0 },
-#define	NFRMTSW           7
+#define	NFRMTSW           5
     { "noformat", 0 },
-#define	FORWSW            8
+#define	FORWSW            6
     { "forward", 0 },
-#define	NFORWSW           9
+#define	NFORWSW           7
     { "noforward", 0 },
-#define	MIMESW           10
+#define	MIMESW            8
     { "mime", MIMEminc(-4) },
-#define	NMIMESW          11
+#define	NMIMESW           9
     { "nomime", MIMEminc(-6) },
-#define	MSGDSW           12
+#define	MSGDSW           10
     { "msgid", 0 },
-#define	NMSGDSW          13
+#define	NMSGDSW          11
     { "nomsgid", 0 },
-#define	SPSHSW           14
+#define	SPSHSW           12
     { "push", 0 },
-#define	NSPSHSW          15
+#define	NSPSHSW          13
     { "nopush", 0 },
-#define	SPLITSW          16
+#define	SPLITSW          14
     { "split seconds", MIMEminc(-5) },
-#define	UNIQSW           17
+#define	UNIQSW           15
     { "unique", -6 },
-#define	NUNIQSW          18
+#define	NUNIQSW          16
     { "nounique", -8 },
-#define	VERBSW           19
+#define	VERBSW           17
     { "verbose", 0 },
-#define	NVERBSW          20
+#define	NVERBSW          18
     { "noverbose", 0 },
-#define	WATCSW           21
+#define	WATCSW           19
     { "watch", 0 },
-#define	NWATCSW          22
+#define	NWATCSW          20
     { "nowatch", 0 },
-#define	WIDTHSW          23
+#define	WIDTHSW          21
     { "width columns", 0 },
-#define SVERSIONSW       24
+#define SVERSIONSW       22
     { "version", 0 },
-#define	SHELPSW          25
+#define	SHELPSW          23
     { "help", 4 },
-#define	MAILSW           26
+#define	MAILSW           24
     { "mail", -4 },
-#define	SAMLSW           27
+#define	SAMLSW           25
     { "saml", -4 },
-#define	SSNDSW           28
+#define	SSNDSW           26
     { "send", -4 },
-#define	SOMLSW           29
+#define	SOMLSW           27
     { "soml", -4 },
-#define	CLIESW           30
+#define	CLIESW           28
     { "client host", -6 },
-#define	SERVSW           31
+#define	SERVSW           29
     { "server host", -6 },
-#define	SNOOPSW          32
+#define	SNOOPSW          30
     { "snoop", -5 },
-#define SDRFSW           33
+#define SDRFSW           31
     { "draftfolder +folder", -6 },
-#define SDRMSW           34
+#define SDRMSW           32
     { "draftmessage msg", -6 },
-#define SNDRFSW          35
+#define SNDRFSW          33
     { "nodraftfolder", -3 },
     { NULL, 0 }
 };
@@ -725,12 +708,12 @@ sendit (char *sp, char **arg, char *file, int pushed)
 
     if (arg)
 	copyip (arg, vec);
-    if ((cp = m_find (sp)) != NULL) {
+    if ((cp = context_find (sp)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     if (arg)
 	copyip (vec, ap);
     argp = arguments;
@@ -809,8 +792,6 @@ sendit (char *sp, char **arg, char *file, int pushed)
 		case SAMLSW: 
 		case SSNDSW: 
 		case SOMLSW: 
-		case ENCRSW: 
-		case NENCRSW: 
 		case SNOOPSW: 
 		    vec[vecp++] = --cp;
 		    continue;
@@ -840,7 +821,9 @@ sendit (char *sp, char **arg, char *file, int pushed)
 	advise (NULL, "usage: %s [switches]", sp);
 	return;
     }
-    if ((cp = m_find ("Aliasfile"))) {	/* allow Aliasfile: profile entry */
+
+    /* allow Aliasfile: profile entry */
+    if ((cp = context_find ("Aliasfile"))) {
 	char *dp = NULL;
 
 	for (ap = brkstring(dp = getcpy(cp), " ", "\n"); ap && *ap; ap++) {
@@ -849,17 +832,8 @@ sendit (char *sp, char **arg, char *file, int pushed)
 	}
     }
 
-#ifdef TMA
-    if ((cp = getenv ("KDS")) == NULL || *cp == NULL)
-	if ((cp = m_find ("kdsproc")) && *cp)
-	    m_putenv ("KDS", cp);
-    if ((cp = getenv ("TMADB")) == NULL || *cp == NULL)
-	if ((cp = m_find ("tmadb")) && *cp)
-	    m_putenv ("TMADB", m_maildir (cp));
-#endif /* TMA */
-
     if ((cp = getenv ("SIGNATURE")) == NULL || *cp == 0)
-	if ((cp = m_find ("signature")) && *cp)
+	if ((cp = context_find ("signature")) && *cp)
 	    m_putenv ("SIGNATURE", cp);
 #ifdef UCI
 	else {
@@ -918,7 +892,7 @@ whomfile (char **arg, char *file)
     int vecp;
     char *vec[MAXARGS];
 
-    m_update ();	/* update the context file */
+    context_save ();	/* save the context file */
     fflush (stdout);
 
     switch (pid = vfork ()) {
