@@ -52,7 +52,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -126,7 +126,9 @@ main (int argc, char **argv)
 	else
 	    vec[vecp++] = msg = cp;
     }
-    if ((cp = m_find ("Aliasfile"))) {	/* allow Aliasfile: profile entry */
+
+    /* allow Aliasfile: profile entry */
+    if ((cp = context_find ("Aliasfile"))) {
 	char *dp = NULL;
 
 	for (ap = brkstring(dp = getcpy(cp), " ", "\n"); ap && *ap; ap++) {
