@@ -46,10 +46,6 @@ static char *localname   = "";
 static char *localdomain = "";
 static char *systemname  = "";
 
-#ifdef MF
-static char *UUCPchan = "";
-#endif
-
 char *mmdfldir = MAILSPOOL;
 char *mmdflfil = "";
 char *uucpldir = "/usr/spool/mail";
@@ -61,39 +57,14 @@ char *mmdlm2 = "\001\001\001\001\n";
 static int MMailids = 0;
 static char *mmailid = "0";
 
-#ifdef MF
-char *umincproc = nmhetcdir(/uminc);
-#else
-char *umincproc = NULL;
-#endif
 
 /*
  * MTS specific variables
  */
-
-#ifdef MHMTS
-char *Mailqdir = "/usr/spool/netmail";
-char *TMailqdir = "/usr/tmp";
-int Syscpy = 1;
-static char *syscpy = "1";
-char *Overseer = "root";
-char *Mailer = "root";
-char *Fromtmp = "/tmp/rml.f.XXXXXX";
-char *Msgtmp = "/tmp/rml.m.XXXXXX";
-char *Errtmp = "/tmp/rml.e.XXXXXX";
-int Tmpmode = 0600;
-static char *tmpmode = "0600";
-char *Okhosts = nmhetcdir(/Rmail.OkHosts);
-char *Okdests = nmhetcdir(/Rmail.OkDests);
-#endif /* MHMTS */
-
-#ifdef MMDFMTS
-#endif /* MMDFMTS */
-
-#ifdef SENDMTS
+#if defined(SENDMTS) || defined(SMTPMTS)
 char *hostable = nmhetcdir(/hosts);
 char *sendmail = SENDMAILPATH;
-#endif /* SENDMTS */
+#endif
 
 /*
  * SMTP/POP stuff
@@ -144,9 +115,6 @@ static struct bind binds[] = {
     { "localname", &localname },
     { "localdomain", &localdomain },
     { "systemname", &systemname },
-#ifdef MF
-    { "uucpchan", &UUCPchan },
-#endif
     { "mmdfldir", &mmdfldir },
     { "mmdflfil", &mmdflfil },
     { "uucpldir", &uucpldir },
@@ -154,27 +122,12 @@ static struct bind binds[] = {
     { "mmdelim1", &mmdlm1 },
     { "mmdelim2", &mmdlm2 },
     { "mmailid", &mmailid },
-    { "umincproc", &umincproc },
 
-#ifdef MHMTS
-    { "mailqdir", &Mailqdir },
-    { "tmailqdir", &TMailqdir },
-    { "syscpy", &syscpy },
-    { "overseer", &Overseer },
-    { "mailer", &Mailer },
-    { "fromtmp", &Fromtmp },
-    { "msgtmp", &Msgtmp },
-    { "errtmp", &Errtmp },
-    { "tmpmode", &tmpmode },
-    { "okhosts", &Okhosts },
-    { "okdests", &Okdests },
+#if defined(SENDMTS) || defined(SMTPMTS)
+    { "hostable", &hostable },
 #endif
 
-#ifdef MMDFMTS
-#endif /* MMDFMTS */
-
 #ifdef SENDMTS
-    { "hostable", &hostable },
     { "sendmail", &sendmail },
 #endif
 
@@ -200,11 +153,6 @@ static struct bind binds[] = {
 };
 
 
-/*
- * I'd like to use m_getfld() here, but not all programs
- * loading mts.o may be MH-style programs...
- */
-
 /*
  * Read the configuration file for the nmh interface
  * to the mail transport system (MTS).
@@ -213,10 +161,9 @@ static struct bind binds[] = {
 void
 mts_init (char *name)
 {
-    register char *bp, *cp;
-    char buffer[BUFSIZ];
-    register struct bind *b;
-    register FILE *fp;
+    char *bp, *cp, buffer[BUFSIZ];
+    struct bind *b;
+    FILE *fp;
     static int inited = 0;
 
     if (inited++ || (fp = fopen (mtsconf, "r")) == NULL)
@@ -242,37 +189,35 @@ mts_init (char *name)
     }
 
     fclose (fp);
-
     MMailids = atoi (mmailid);
     Everyone = atoi (everyone);
-
-#ifdef MHMTS
-    Syscpy = atoi (syscpy);
-    sscanf (tmpmode, "0%o", &Tmpmode);
-#endif /* MHMTS */
 }
 
+
 #define	QUOTE	'\\'
 
+/*
+ * Convert escaped values, malloc some new space,
+ * and copy string to malloc'ed memory.
+ */
+
 static char *
 tailor_value (char *s)
 {
-    register int i, r;
-    register char *bp;
+    int i, r;
+    char *bp;
     char buffer[BUFSIZ];
     size_t len;
 
-    for (bp = buffer; *s; bp++, s++)
-	if (*s != QUOTE)
+    for (bp = buffer; *s; bp++, s++) {
+	if (*s != QUOTE) {
 	    *bp = *s;
-	else
+	} else {
 	    switch (*++s) {
-#define	grot(y,z) case y: *bp = z; break;
-		grot ('b', '\b');
-		grot ('f', '\f');
-		grot ('n', '\n');
-		grot ('t', '\t');
-#undef grot
+		case 'b': *bp = '\b'; break;
+		case 'f': *bp = '\f'; break;
+		case 'n': *bp = '\n'; break;
+		case 't': *bp = '\t'; break;
 
 		case 0: s--;
 		case QUOTE: 
@@ -291,6 +236,8 @@ tailor_value (char *s)
 		    *bp = toascii (i);
 		    break;
 	    }
+	}
+    }
     *bp = 0;
 
     len = strlen (buffer) + 1;
@@ -367,32 +314,6 @@ SystemName (void)
     return buffer;
 }
 
-char *
-UucpChan (void)
-{
-#ifdef MF
-    static char buffer[BUFSIZ] = "";
-#endif
-
-#ifndef	MF
-    return NULL;
-#else
-    if (buffer[0])
-	return buffer;
-
-    mts_init ("mts");
-    if (*UUCPchan)
-	return strcpy (buffer, UUCPchan);
-
-#ifdef uucpchan
-    strcpy (buffer, uucpchan);
-#else /* uucpchan */
-    strcpy (buffer, "uucp");
-#endif /* uucpchan */
-    return buffer;
-#endif
-}
-
 
 static char username[BUFSIZ];
 static char fullname[BUFSIZ];
@@ -458,9 +379,11 @@ getusr (void)
     if ((cp = getenv ("SIGNATURE")) && *cp)
 	strcpy (fullname, cp);
     if (strchr(fullname, '.')) {		/*  quote any .'s */
-	  char tmp[BUFSIZ];
-      sprintf (tmp, "\"%s\"", fullname);/* should quote "'s too */
-      strcpy (fullname, tmp);
+	char tmp[BUFSIZ];
+
+	/* should quote "'s too */
+	sprintf (tmp, "\"%s\"", fullname);
+	strcpy (fullname, tmp);
     }
 
     return username;
