@@ -10,7 +10,6 @@
  */
 char *LocalName(void);
 char *SystemName(void);
-char *UucpChan(void);
 
 /*
  * Mailboxes
@@ -37,11 +36,6 @@ extern char *mmdlm2;
 #define	isdlm1(s) (strcmp (s, mmdlm1) == 0)
 #define	isdlm2(s) (strcmp (s, mmdlm2) == 0)
 
-/*
- * Filters
- */
-extern char *umincproc;
-
 /*
  * Read mts.conf file
  */
@@ -58,27 +52,10 @@ int lkfclose(FILE *, char *);
 /*
  * MTS specific variables
  */
-#ifdef MHMTS
-extern char *Mailqdir;
-extern char *TMailqdir;
-extern int Syscpy;
-extern char *Overseer;
-extern char *Mailer;
-extern char *Fromtmp;
-extern char *Msgtmp;
-extern char *Errtmp;
-extern int Tmpmode;
-extern char *Okhosts;
-extern char *Okdests;
-#endif /* MHMTS */
-
-#ifdef MMDFMTS
-#endif /* MMDFMTS */
-
-#ifdef SENDMTS
+#if defined(SENDMTS) || defined (SMTPMTS)
 extern char *hostable;
 extern char *sendmail;
-#endif /* SENDMTS */
+#endif
 
 /*
  * SMTP/POP stuff
